% Author: Dr. Jean-Baptiste Pichancourt, research scientist at INRAE, department of maths & numerical science, Complex systems lab., France
% jean-baptiste.pichancourt@inrae.fr 
% Year: 2020
% Licence GPLv3

function OUTPUT = Analyses(Physics, Biology, Forestry, Economics, Social, Outputs, Repmax)

%   Physics
Tmax = Physics(1,1);
Lat = Physics(2,1);
Long = Physics(3,1);
Clim = Physics(4,1);
Land = Physics(5,1);
Farea = Physics(6,1);
Nforestpatches = Physics(7,1);
Fregrowth = Physics(8,1);
Fsurroundings = Physics(9,1);
SoilElements = Physics(10:13,1);
SoilDepth = Physics(14,1);

%   Biology
Timbermin = Biology(1, 1);
Timbermax = Biology(2, 1);
LMAmin = Biology(3, 1);
LMAmax = Biology(4, 1);
Seedmin = Biology(5, 1);
Seedmax = Biology(6, 1);
nLHT = Biology(7, 1);

%   Forestry
Plantmax = Forestry(1, 1);
Nplant = Forestry(2, 1);
ThinDivmax = Forestry(3, 1);
ThinFreqmax = Forestry(4, 1);
Forestry_Analysis = Forestry(5, 1);
Efficient_manager =  Forestry(6, 1);
Efficient_monitor =  Forestry(7, 1);
silviculture = Forestry(8, 1);

%   Economy
Pselltimber = Economics(1, 1);
Eplanting = Economics(2 : 4, 1);

%   Social
NumberHH = Social(1, 1);
SizeHH = Social(2, 1);
Access = Social(3, 1);

%%%%%%%%%%%%%%  Definition of condition specific parameters and variables %%%%%%

%%   Call a set of parameters
Parameters; s = 5; %s comes from Parameters: try to do better to call it from Parameters for a parfor loop

%% Definition of specific variables and definitions per type of analysis
if Forestry_Analysis == 1  
  
  Random = 0;
  Repmax = 1;
  spmax = 1;    
  nTimber = nLHT;  nSeed = nLHT;  nLMA = nLHT;
  Nspecies = nTimber * nSeed * nLMA;  
  %   Populate all necessary matrices and vectors that match when, what and how many LHTs syndromes to plant
  [LHTs, Nspecies, LHTby, hsg, hmat, hbymin, smax, S, height] = Dimensions(Timbermin, Timbermax, nTimber, LMAmin, LMAmax, nLMA, Seedmin, Seedmax, nSeed); 
  %   Set up the matrix (Hmatrix) that provides all the combinations of harvesting species (1 row = 1 combination of species to thin)
   Hmatrix = zeros(ThinDivmax * ThinFreqmax, 2);
   for j = 1 : ThinDivmax * ThinFreqmax
       Hmatrix(j, 1) = mod(floor((j - 1) / (ThinFreqmax)), ThinDivmax) + 1 ;
       Hmatrix(j, 2) = mod(j - 1 + ThinFreqmax * ThinDivmax, ThinFreqmax) + 1 ;        
   end
   ForestryMax = size(Hmatrix, 1);
  %  Display specific variables and definitions per type of analysis
  disp(sp)
  disp(["- Number of species in the forest:", num2str(Nspecies)])  
  disp(["- Number of basic timber density classes:", num2str(nTimber)])
  disp(["- Number of seed size classes:", num2str(nSeed)])
  disp(["- Number of LMA/SLA classes:", num2str(nLMA)])  
  
elseif Forestry_Analysis == 2
  
  Climmax = 1;
  Random = 0;
  Repmax = 1;
  spmax = 1;
  nTimber = nLHT; nSeed = nLHT; nLMA = nLHT;  
  %   Populate all necessary matrices and vectors that match when, what and how many syndromes of tree life-history traits to manage
  [LHTs, Nspecies, LHTby, hsg, hmat, hbymin, smax, S, height] = Dimensions(Timbermin, Timbermax, nTimber, LMAmin, LMAmax, nLMA, Seedmin, Seedmax, nSeed); 
  %   Set up the matrix (Hmatrix) that provides all the combinations of harvesting species (1 row = 1 combination of species to thin)
  Hmatrix = ones(2^Nspecies, Nspecies);
  p = 1;
  for c = 0 : Nspecies - 1      
      Hmatrix(p + 1: 2 * p, Nspecies - c : Nspecies) = [zeros(p, 1), Hmatrix(1 : p, Nspecies - c + 1 : Nspecies)];
      p = 2 * p;
  endfor
  ForestryMax = size(Hmatrix, 1);    
  % Display specific variables and definitions per type of analysis
  disp(sp)
  disp(["- Number of species in the forest:", num2str(Nspecies)])  
  disp(["- Number of basic timber density classes:", num2str(nTimber)])
  disp(["- Number of seed size classes:", num2str(nSeed)])
  disp(["- Number of LMA/SLA classes:", num2str(nLMA)])    
        
elseif Forestry_Analysis == 3
   
  Climmax = 1; 
  Random = 0;
  Repmax = 1;
  spmax = 0;
  %   Matrix containing all the possible number of species, based on the number of PFT.
  for nTimber_temp = 2 : nLHT
    for  nSeed_temp = 2 : nLHT
      for nLMA_temp = 2 : nLHT
        spmax = 1 + spmax;
        specieslistnumber(spmax, 1) = spmax;
        specieslistnumber(spmax,2) = nTimber_temp;
        specieslistnumber(spmax,3) = nSeed_temp;
        specieslistnumber(spmax,4) = nLMA_temp;
      endfor %nLMAmax
    endfor % nSeedmax
  endfor % nTimber
  ForestryMax = 2;   % Here only two types of forests are compared, the one with no management at all on species vs another one with all the species managed.

elseif Forestry_Analysis == 4
  
  Random = 1;
  Repmax = Repmax;
  spmax = 1; 
  nTimber = nLHT; nSeed = nLHT; nLMA = nLHT;
  %   Populate all necessary matrices and vectors that match when, what and how many syndromes of tree life-history traits to manage
  [LHTs, Nspecies, LHTby, hsg, hmat, hbymin, smax, S, height] = Dimensions(Timbermin, Timbermax, nTimber, LMAmin, LMAmax, nLMA, Seedmin, Seedmax, nSeed); 
  %   Set up the matrix (Hmatrix) that provides all the combinations of harvesting species (1 row = 1 combination of species to thin)
  Hmatrix = ones(1, Nspecies);
  ForestryMax = size(Hmatrix, 1);
  % Display specific variables and definitions per type of analysis
  disp(sp)
  disp(["- Number of species in the forest:", num2str(Nspecies)])  
  disp(["- Number of basic timber density classes:", num2str(nTimber)])
  disp(["- Number of seed size classes:", num2str(nSeed)])
  disp(["- Number of LMA/SLA classes:", num2str(nLMA)])
  
endif 

%%   Detection level (resolution at which managers are distinguishing the species     
Detectionlevel = 1; % Perfect detection, if not then Detectionlevel = mod(floor((i - 1) / (Climmax * Detectionlevelmax)), Detectionlevelmax) + 1;
rLHT = nLHT - Detectionlevel + 1;  %  Currently works only for firewood
PFTr = (LMAmax - LMAmin) / (rLHT - 1);
        
%%%%%%%%%%%%%%%%%%% Calculation of results for different conditions %%%%%%%%%%%%

%%   Definition of matrices for outputs 
OUTPUT = zeros(Tmax + 1, 18, ForestryMax, spmax, Repmax);
STR = zeros(ForestryMax, spmax, Repmax);

for Rep = 1 : Repmax  %%  Loop replicates for sensitivity analysis  %%  
 
  for sp = 1 : spmax    %%  Loop number of species   %%
    
    %% Specific variables for analysis 3 that change with variable sp
    if Forestry_Analysis == 3
      
       nTimber = specieslistnumber(sp, 2);
       nSeed = specieslistnumber(sp, 3);
       nLMA = specieslistnumber(sp, 4);
       Nspecies = nTimber * nSeed * nLMA;
       disp(sp)
       disp(["- Number of species in the forest:", num2str(Nspecies)])  
       disp(["- Number of basic timber density classes:", num2str(nTimber)])
       disp(["- Number of seed size classes:", num2str(nSeed)])
       disp(["- Number of LMA/SLA classes:", num2str(nLMA)])   
       
       %%   Populate all necessary matrices and vectors that match when, what and how many LHTs syndromes to plant
       [LHTs, Nspecies, LHTby, hsg, hmat, hbymin, smax, S, height] = Dimensions(Timbermin, Timbermax, nTimber, LMAmin, LMAmax, nLMA, Seedmin, Seedmax, nSeed); 
        %   Hmatrix provides all the combinations of harvesting species (1 row = 1 combination of species to thin)
        Hmatrix = ones(2, Nspecies);
        Hmatrix(2, :) = 0;
        
    endif

    %%   Dimensions of the Output matrix of outputs
    %MAT0 = zeros(2,1);
    %D0 = zeros(2,1);
   
    for i = 1 : ForestryMax    %%  Loop Forestry management strategies          
                
        %%   Populate the specific management strategy  for i 
        m = mod(floor((i - 1) / (1)), ForestryMax) + 1;   % m = mod(floor((i - 1) / (Climmax * Landmax * Detectionlevelmax)), ForestryMax) + 1;
         
       %% Specific conditions per forestry strategy 
      if Forestry_Analysis == 1
            
          %%   Populate the Duration of management
          c = clock;
          ystart = c(1, 1);
          yend   = ystart + max(Tmax);
          tlimit = yend - ystart;
           
          %%  Populate thinning decisions
          display(Hmatrix(m, 2))
          ThinV = zeros(tlimit, 1);
          ThinV(1, 1) = 1;
          for x = 1 : floor(tlimit / f)
              if 1 + x * f < tlimit
                  ThinV(1 + x * f, 1) = Hmatrix(m, 2);
              elseif x + f >= tlimit
                  break
              endif
          endfor    
      
          %%   Populate the planting decisions (saplings/m2)
            if sum(Density,1) == 0
              
                N(2, :) = 0;
                
            elseif sum(Density,1) > 0
                
                Timberby    = LHTby(1, 1);
                LMAby       = LHTby(1, 2);
                Seedby      = LHTby(1, 3);
                
                for x = 1 : size(Timber, 2)
                  
                    pTimber = (Timber(1, x) - Timbermin) / Timberby + 1;
                    pLMA = (LMA(1, x) - LMAmin) / LMAby + 1;
                    pSeed = log(Seed(1, x) / Seedmin) / log(Seedby) + 1;
                    j = round(pSeed + nSeed * (pLMA - 1) + nSeed * nLMA * (pTimber - 1));
                    N(2, j) = Density(1, x);
                    
                endfor  
                
            endif  

         % Definition de str
         str = 1;         
        
      elseif Forestry_Analysis == 2 || 3 || 4      
        
         N = InitialForest2(smax + 1, Nspecies);  %   Initial Planting decisions (saplings/m2)          
         Hselection = Hmatrix(m, :);   %  Forestry plan
         Nspecies_managed = sum(Hmatrix(m, :))   % Number of species managed
         Perc_species = Nspecies_managed / Nspecies * 100;
         str = regexprep(mat2str(Hmatrix(m, :)), '[^\w'']', '');    % Vector containing information of the tree species in the forest that are not managed (0) and the one that are managed (1). for instance 000010 means that species 1:4 and 6 are not managed and species 5 is managed using forestry practices.
         STR(i, :,sp, Rep) = Hmatrix(m, :)
         
         disp(["- Disturbance scenario ", num2str(m), ": ", num2str(perc_species), "% of species independently controlled for forestry purposes ", "(", str,")"])    
               
      endif             
        
         %%  Run the time series of the consequences of management on the multi-species forest dynamics       
         OUTPUT = Chronicle(Access, Clim, Detectionlevel, Efficient_manager, Efficient_monitor, Eplanting, Farea, hbymin, height, hmat, hsg, Hselection, Clim, Lat, LMA, LMAmax, LMAmin, Long, N, Nforestpatches, nLMA, Nspecies, Nspecies, Nspecies_managed, NumberHH, OUTPUT, Perc_species, LHTs, Pharvest, Pselltimber, Random, Rep, rLHT, S, s, SizeHH, smax, SoilElements, T, Tmax, TD)
        
    endfor  % i = 1:ForestryMax

  endfor % sp = 1:spmax

endfor % Rep

%%%%%%%%%%%%%%%%%%%% Statistics, Save & Plot  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
          
if Forestry_Analysis == 1  
  
  Plot_Analysis_1(OUTPUT, Clim, Land)
  
elseif Forestry_Analysis == 2  
  
  Plot_Analysis_2(OUTPUT, Clim, Land)
  
elseif Forestry_Analysis == 3  
  
  Plot_Analysis_3(OUTPUT, Clim, Land)
  
elseif Forestry_Analysis == 4
  
  Plot_Analysis_4(OUTPUT, Clim, Land)
  
endif

toc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
