%============================================================================================%
% Function that estimates i) the canopy openness (Dimensionless 0-1) at a given height z in the forest (dEdz)
% and ii) the contribution of a group of trees from a particular PFTsyndrome to canopy openness (dEdN)
% This function is used to predict i) the quantity of light available for leaves or seed germination at a given height z 
% and ii) for predicting which dominant species to thin.
% Here, we use a simple model of canopy openness developped by Falster et al., 2011. 
%==========================================================================

function [dEdz,dEdN] = CanOpen(PFTs,N,hsg,hbymin,smax,S,s,n)

Parameters
%   maximum dimension related to the maximum height hmax observed at time t
Ederiv_out = zeros(smax,smax,n);
%   Start function
for i = 1:n      %  loop over all the species planted
    for sh=1:S(i,1)  %  loop over every tree height classes
        for z = 1:sh     %  loop over every sub-height classes: mid-point rule for further integration of E 
            xe = [hsg(i,1)+.5*hbymin,hsg(i,1)+.5*hbymin+hbymin*[1:sh-1]];     % mid-point rule
            if sum(N(z:sh,i),1) == 0
                break
            end
            %   Fraction (Q) of leaf area above height z  for an individual of height h
            Q  = (1-(xe(z)/xe(sh))^n0)^2;
            %   Number of individuals of size z
            Nh = N(sh,i);
            %   Call variables from other functions            
            [~,~,~,~,~,~,~,~,~,LA,~,~,~,~] = Allometry(PFTs(i,:),xe(sh),s,0);
            %   Leaf area at height z (E) for individuals of height h
            Ederiv = Q*LA*Nh*hbymin;   %*hby because mid-point rule
            Ederiv_out(sh,z,i)=Ederiv;
        end
    end
end
%   Contribution of each PFTS at each size to the total canopy openness
%dEdNdz = exp(-cext.*squeeze(sum(Ederiv_out,1))')./n;
%   Contribution of each PFTS to the total canopy openness
dEdN = exp(-cext.*squeeze(sum(sum(Ederiv_out,1),2))');
%   Canopy openness at height z given all the individuals of all the PFTS present (dEdz)
dEdz(:,1) = exp(-cext*(sum(sum(Ederiv_out,1),3)))';
end


