function OUTPUT = Chronicle(Access, Clim, Detectionlevel, Efficient_manager, Efficient_monitor, Eplanting, Farea, hbymin, height, hmat, hsg, Hselection, Clim, Lat, LMA, LMAmax, LMAmin, Long, N, Nforestpatches, nLMA, nLHTs, Nspecies, Nspecies_managed, NumberHH, OUTPUT, Perc_species, LHTs, Pharvest, Pselltimber, Random, Rep, rLHT, S, s, SizeHH, smax, SoilElements, T, Tmax, TD)
        
%% Environmental conditions and time series
[ClimSeries, D, D0, MAT0, Water] = Environment(Clim, Land, Landmax, Lat, Long, SoilElements, Tmax)
 
%%  Initial conditions at time t0
T = 0;  %   Period since last harvesting of timber (initial condition)
TDmean = sum(sum(N(3 : smax + 1, :), 1) .* (LHTs(:, 1))', 2)/(sum(sum(N(3 : smax + 1, :), 1)));    %   Initial conditions for live trees        
N = zeros(smax + 1, nLHTs);        
Nsnags = zeros(smax * 5, nLHTs);      
BNdebris = zeros(smax, nLHTs, 6);  %   Initial dead biomass at every size classes 
Phi_net   = zeros(smax, nLHTs);  %   state initial condition of leave transpiration = 0 for calculating the first leaf temperature
Phi_netSg = zeros(1, nLHTs);
X = zeros(7, 1);   %   7 soil compartments for carbon sequestration:

%%   Time series of Forest Ecosystem dynamics  
for y = 1 : tlimit  
  
    tic    
    display(["Year ", num2str(y)])
    
    % Estimate the percentage and vertical structure of canopy openness T a forest level per m2
    [dEdz, dEdN] = CanOpen(LHTs, N, hsg, hbymin, smax, S, s, size(LHTs, 1)); 
    
    % Different choises of forestry practices 
    if Forestry_Analysis == 1
        if y > 1
            [Supply, Ntimber, N] = Thinning(dEdN, dEdz, N, S, Ssize, LMA, TD, LHTs, Hselection);
        endif
        
    elseif Forestry_Analysis == 2 || 3 || 4
        
        %  Harvesting & management practices at the begenning of the year
        T = T + 1; %   Period since last harvesting of timber (add one year)           
        [Benefit, Stimber, Ntimber, N, BNdebris, Pharvest, T] = Harvesting(Access, Pselltimber, Hselection, Farea, LHTs, s, height, nLHTs, TDmean, N, BNdebris, T, Random);
                        
        %  Post harvesting sylvicultural practices                              
        if silviculture == 1
          
            [~, N, BNdebris] = Silviculture(Farea, Nforestpatches, SoilElements, dEdN, Efficient_manager, Efficient_monitor, Hselection, Eplanting, Pharvest, LHTs, s, height, N, BNdebris, Random);
                               
        endif
        
        %  Fuelwood collection: here fuelwood comes after timber harvesting and sylviculture as timber extraction is considered more important for livelihoods. could be reversed if fuelwood more important than timber for livelihoods.
        Hrestrictionfire = Hselection - 1;
        Hrestrictionfire(Hrestrictionfire == -1) = 1;
        [Sfuel, Nfuelalive, BNdebris, N] = ThinningFirewood(NumberHH, SizeHH, Access, Farea, Nforestpatches, LHTs, N, height, s, nLMA, rLHT, LMAmin, LMAmax, Detectionlevel, BNdebris, Hrestrictionfire);
        
        %  Total supply & details per species
        Nsupply = cat(3, Ntimber, Nfuelalive);
        Supply = [sum(sum(Stimber)), sum(sum(Sfuel))]';            

    endif

    %%   Model of Multi-species Forest Ecosystem Dynamics (FED): run consequences of forestry practices during the current year y           
    [AGOC, SOC, N, Nsnags, BNsnags, BNdebris, X, Water, ~, ~, Hmean, LAI, PFTmean, H, Phi_net, Phi_netSg] = FED(LHTs, Climate, MAT(y, Clim), MAT0(Clim), D(y, Clim), D0(Clim), Water, y, SoilElements, SoilDepth, N, Nsnags, BNdebris, X, height, hsg, hbymin, hmat, smax, S, s, Phi_net, Phi_netSg, l);
    
    %%  Output matrix: Forest-level variables
    OUTPUT(y+1, 1, i, sp, rep) = Nspecies;  % Number of species in the forest
    OUTPUT(y+1, 2, i, sp, rep) = Nspecies_managed; % Number of species managed in the forest   
    OUTPUT(y+1, 3, i, sp, rep) = Perc_species; %  Percentage of species managed
    OUTPUT(y+1, 4, i, sp, rep) = H;       %   Forest Organic Carbon: Carbon accumulated in the forest (excluding the litter that is a transitory stock)
    OUTPUT(y+1, 5, i, sp, rep) = AGOC * 10;       %   above-ground organic carbon: typically range between 25-250 Mg/ha (i.e., 2.5-25 kg/m2 * 10) with recomended value ~ 138 Mg/ha for wet forests in Asia(IPCC)
    OUTPUT(y+1, 6, i, sp, rep) = SOC * 10;       %   Soil Organic Carbon: Carbon accumulated in the Litter (conversion 10*kg/m2 = 1Mg/ha)
    if y > 1
        OUTPUT(y+1, 7, i, sp, rep) = (OUTPUT(y + 1, 5, i, sp, rep) - OUTPUT(y, 5, i, sp, rep));   %   Productivity = Carbon sequestration rate above ground between two consecutive years
        OUTPUT(y+1, 8, i, sp, rep) = (OUTPUT(y + 1, 6, i, sp, rep) - OUTPUT(y, 6, i, sp, rep));   %   Carbon sequestration rate in the soil between two consecutive years
    endif
    OUTPUT(y+1, 9, i, sp, rep) = OUTPUT(y + 1, 7, i, sp, rep) / 0.514 + OUTPUT(y + 1, 8, i, sp, rep);  %  Total forest productivity = Carbon sequestration rate above ground, in the roots and in the soil between two consecutive years
    OUTPUT(y+1, 10, i, sp, rep) = PFTmean(1, 1);   %   Average timber density of trees produced in the forest [kg.m-3]
    OUTPUT(y+1, 11, i, sp, rep) = 1 / PFTmean(2, 1);   %   Average SLA=1/LMA of leaves produced by trees in the forest [m2.kg-1] (SLA: Specific Leaf Area, LMA: Leaf mass per area)
    OUTPUT(y+1, 12, i, sp, rep) = PFTmean(3, 1);  %   Average size of the seeds produced by trees the forest [kg]
    OUTPUT(y+1, 13, i, sp, rep) = LAI;   %   Leaf area index of the forest
    OUTPUT(y+1, 14, i, sp, rep) = Hmean;   %   Average hight of the forest
    OUTPUT(y+1, 15, i, sp, rep) = Water;   %   Water supply in the soil
    OUTPUT(y+1, 16, i, sp, rep) = Supply(1, 1);  %   Number of trees and seedlings thinned (reminder: the total number of sedlings per month can be very high, better to separate size classes)
    OUTPUT(y+1, 17, i, sp, rep) = Supply(2, 1);
    OUTPUT(y+1, 18, i, sp, rep) = Benefit;   %  Dollars from harvesting $    
    
    toc
          
endfor    % y = 1:ymax     