%============================================================================================%
% PPM: DEMOGRAPHI TRANSITION MATRIX
%      Estimate the size-structure transition matrix of the species
%==========================================================================
% function  DM = DTM(Gout,Sout,Fout,Ssg,hby,sh)
function  DM = DTM(Gout,Sout,Fout,Ssg,Ssb,Germ,S)
    
% 	Populate initial conditions	
	s=S+1;
    DM = zeros(s,s);
    DM(1,1) = Ssb*(1-Germ);
    DM(2,1) = Ssb*Germ*Ssg;
% 	Creates the Usher/Leslie/Lefkovitch-type transition matrix		
	for i = 2:s 		
	% 	transition rates in the matrix: p(x,y) = s(x)*g(x,y)   (g(x,y) = 1)
        if Gout(i-1,1)<1
            G=Gout(i-1,1);
            DM(i,i)  = Sout(i-1,1)*(1-G); 
        elseif Gout(i,1)>=1
            G=1;
            DM(i,i)  = 0;
        end
        if i < s 
            kn        = i+ceil(Gout(i-1,1));
            if kn>s
               kn=1;
            end
            DM(kn,i)  = Sout(i-1,1).*G;         %  assumption: growing Gout(k,1)/hby centimeters is equivalent of having a probability of Gout(k,1)/hby to transit from sizeclass sn to sn+1            
        end
        
        if i>1
            % 	Fertility cells in the matrix: F(x) assuming reproduction spread across the year
		DM(1,i)  = sqrt(Sout(i-1,1)).*Fout(i-1,1).*sqrt(Ssb).*(1-Germ); %*sqrt(Ssb);
        DM(2,i)  = sqrt(Sout(i-1,1)).*Fout(i-1,1).*sqrt(Ssb).*Germ.*Ssg; %*sqrt(Ssb);
        end
	end	% for
    
end