function [AGOC,SOC,N,Nsnags,BNsnags,BNdebris,X,Water,dEdN,dEdz,Hmean,LAI,PFTmean,...
    H,Phi_net,Phi_netSg] = FED (PFTs,Climate,MAT,MAT0,D,D0,Water,y,SoilElements,Sdepth,...
    N,Nsnags,BNdebris,X,height,hsg,hbymin,hmat,smax,S,s,Phi_net,Phi_netSg,Lowland)

%format short G

%    Populates necessary parameters and soil conditions
Parameters;
[~,thetamax,thetamin,Ksat,tauS,~,~] = Soil(SoilElements);
n      = size(N,2);
dmax   = [31,29,31,30,31,30,31,31,30,31,30,31];    %   number of days per month within a year (Feb assumed 29 days always

%   Total carbon biomass of trees alive per PFTS
Bt = zeros(1,n);

%%  Forest Carbon Sequestration (FCS): includes Soil carbon sequestration of remaining dead material after
[~,SOC,X] = FCS(sum(sum(BNdebris,1),2),MAT,MAT0,D,D0,X);
%   All the debris non-harvested from the previous year go into the soil for carbon.
%   After this new debris will be created from snags that could be used for
%   firewood with the next year.
BNdebris = zeros(size(N,1) - 1,size(N,2),6);

for mth = 1:12   % dimension is the number of hours for 1 year, i.e. 365*24
    
    if Lowland == 2
        Water = 100000;
    end
    %   Canopy openness
    
    [dEdz,dEdN] = CanOpen(PFTs,N(2:smax+1,:),hsg(:,1),hbymin,smax,S(:,1),s,n);
    
    
    %   Populate Hourly climate variables for the month
    CO2amth  = zeros(dmax(mth)*24,1);
    PPFDmth  = zeros(dmax(mth)*24,1);
    PPFDsmth = zeros(dmax(mth)*24,1);
    Tempmth  = zeros(dmax(mth)*24,1);
    Rainmth  = zeros(dmax(mth)*24,1);
    VPmth    = zeros(dmax(mth)*24,1);
    for hr = 1:dmax(mth)*24
        CO2amth(hr,1)  = Climate((y-1)*365*24+(sum(dmax(1:mth-1)))*24+hr,1);
        PPFDmth(hr,1)  = Climate((y-1)*365*24+(sum(dmax(1:mth-1)))*24+hr,2);
        PPFDsmth(hr,1) = Climate((y-1)*365*24+(sum(dmax(1:mth-1)))*24+hr,3);
        Tempmth(hr,1)  = Climate((y-1)*365*24+(sum(dmax(1:mth-1)))*24+hr,4);
        Rainmth(hr,1)  = Climate((y-1)*365*24+(sum(dmax(1:mth-1)))*24+hr,5);
        VPmth(hr,1)    = Climate((y-1)*365*24+(sum(dmax(1:mth-1)))*24+hr,6);
    end
    Climate_mth = [CO2amth,PPFDmth,PPFDsmth,Tempmth,Rainmth,VPmth];
    
    %%  Colonization by seeds from other PFTS of the surounding forest (simplification: let say potentially all the PFTS)
    %Seedcolo = (rand(1,1).*10.*min(PFTs(:,3))./PFTs(:,3)')./12;
    %N(1,:) = N(1,:) + Seedcolo;  % the probability of colonization is inversely proportional to the seed mass (given seed mass/number trade-off)
    
    %%   Tree vital rates: growth, survival fertility
    [~,Sx,Gxy,Fx,Tl,Tfr,Tb,Wupout1,Phi_net] = PhysioDemo(dEdz,Climate_mth,Water,PFTs,N,smax,n,Phi_net,hsg(:,1),hmat(:,1),hbymin,0,s);
    Nfed  = N;
   
    
    %[~,Sx,Gxy,Fx,Tl,Tfr,Tb,Wupout1,Phi_net] = IVM(dEdz,Climate_mth,Water,PFT(:,nn),N,smax,n,Phi_net,hsg(:,nn),hmat(:,nn),hbymin,0,s);
    T = [sum(sum(Tl)),sum(sum(Tb)),sum(sum(Tfr))]';    
    %%   Seedling survival
    [Ssg,~,~,~,~,~,~,Wupout2,Phi_netSg]  = PhysioDemo(dEdz,Climate_mth,Water,PFTs,N,1,n,Phi_netSg,hsg(:,1),hmat(:,1),hbymin,1,s);
    %[Ssg,~,~,~,~,~,~,Wupout2,Phi_netSg]  = IVM(dEdz,Climate_mth,Water,PFT(:,nn),N,1,n,Phi_netSg,hsg(:,nn),hmat(:,nn),hbymin,1,s);
    Wupout = Wupout1 + cat(1,Wupout2,zeros(size(Wupout1,1)-1,size(Wupout1,2)));
    
    %%   Seed vital rates: seed survival and germination rates
    Ssize=zeros(n,1);
    for i = 1:n
        Ssize(i,1) = PFTs(i,3);
    end
    
    [Germ,Ssb] = SeedBank(dEdz(1,1),Ssize,12);
    
    %   Biomass alive
    vec = ones(n,1)*(hbymin*(1:smax-1));
    hsgt = (hsg(:,1)+.5.*hbymin)*ones(1,smax);
    hsize = cat(2,zeros(n,1),vec);
    height  = (hsgt + hsize)';
    [dBt,dBl,dBbr,dBtr,dBs,dBb,dBh,dBfr,dBcr,~,~,~,~,~]   = Allometry(PFTs,height,s,0);
    dB = cat(3,dBt,dBl,dBbr,dBtr,dBs,dBb,dBh,dBfr,dBcr);
    
    %%  SNAG and DEBRIS production (Snag = standing dead tree)
    %   Production of new snags
    dNsnags  = N(2:size(N,1),:).*(1 - Sx);
    
    [Nsnags,BNsnags,BNdebris] = Snag(Nsnags,dNsnags,BNdebris,dB,T,PFTs,height);
    %%   Demographic matrix & Population projection
   
    %display(Fx(:,i)) 
        
          
    for i = 1:n
        M      = DTM(Gxy(:,i),Sx(:,i),Fx(:,i),Ssg(:,i),Ssb(i,1),Germ(i,1),S(i,1));          
        N(1:1+S(i,1),i) = M(:,:)*N(1:1+S(i,1),i);  % Number of individuals of the new species
    end
    
    %%   Calculate the total carbon biomass for trees alive in a month [kg]
    Bt(1,:)  = sum(N(2:smax+1,:).*dBt(1:smax,:),1);
    AGOC = sum(sum(N(2:smax+1,:).*(dBl(1:smax,:) + dBbr(1:smax,:) + dBtr(1:smax,:)),1));
    
    %%   Calculate the quantity of water available for the next month given water uptake, rainfall, runoff
    
    NWup           = real(sum(sum(N(2:size(N,1),:).*Wupout,1)));   %   Water uptake
    Rainfall       = sum(Rainmth);  %   Monthly Rainfall [mm]
    VM = (Water/Sdepth)*10^-3; %   1mm/m2 = 1L/m2 = 1kg/m2 = 10^-3m3/m2, Volumetric soil moisture [m3/m3], mm of water == kg of water/m2
    if VM < thetamax           %   thetamax: max soil water capacity
        theta = VM;
    elseif VM >= thetamax
        theta = thetamax;
    end
    Se             = (theta-thetamin)/(thetamax-thetamin);         %   Effective soil water saturation [Dimensionless]
    Conductivity   = (Ksat)*Se^((2+3/tauS)*tauS);                  %   Unsaturated water conductivity [m.s-1] (Campbell, 1974; Mualem,1976)
    Infiltration   = real(((Conductivity/Sdepth)*dmax(mth)*3600)*Water); %   Water infiltrated in the soil [mm]
    Water          = real(Water + Rainfall - Infiltration - NWup); %   Water balance [mm]
    Water(Water<0) = 0;                                            %   Water cannot be < 0
    Water(Water>thetamax*Sdepth*10^3) = thetamax*Sdepth*10^3;        %   Water cannot be > max soil capacity
    
end	% 1 year (12 months)

    
    
    
%%  Structural parameters of the forest, including:
%       Plant functional Diversity (Shannon Index H)
%       Average height of the forest Hmean
%       Leaf area index LAI
%       Average PFT values for timber density, LMA and seed size
[Hmean,LAI,PFTmean,H,~] = Fstructure(PFTs,N,S,hbymin,hsg,s,2);                   

end%Function

%%  MANUAL & REFERENCES %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%  INTRODUCTION
% In the forest ecosystem dynamic (FED) model, the defined dynamic will
% respond to the different Ω planted and to the competitive environment
% through a set of biological sub-models. First each Ω defines the
% allometric relationship for the biomass and plant architecture. Then
% combined with the climate and soil conditions, Ω defines the plant
% physiology and then the plant vital rates (survival, growth, fertility,
% germination). All the vital rates from individuals within each Ω, sizes
% and life-stages (seed, plant) are then integrated into an integral
% projection model defined at a community level33-35,37. The total alive
% above ground carbon biomass can then be counted as AGOC.  The carbon from
% the dead biomass (i.e, from biomass turnover and dead individuals) is
% then processed and stocked in the soil using a carbon sequestration model.
% We only accounted for the soil organic carbon from humus 1 and 2 soil
% layers as it is the most stable layer of soil organic carbon (SOC).
% Practitioners can then measure the total carbon stock of the forest
% (TOC = AGOC + SOC) to inform a decision. The PFD of the forest42,43 is
% measured using the Shannon index H', based on the number of trees
% belonging to different height categories and unique PFT syndromes. The
% details of the forest ecosystem dynamic model are detailed in the
% supplementary online material.
%
%%  INPUTS:   PFT = vector containg the plant functional trait values for
%               every PFT syndrome
%           Climate = type of IPCC scenario: arid-hot == 1, wet-hot == 2
%           Water = quantity of water in the soil [mm] at year y
%           y = year (from 1 to ymax)
%           Stype = granulometry of the soil
%           Sdepth = depth of the soil
%           N = Population vector including seed bank and trees at
%               different size classes grouped by PFT syndrome at year y
%           hsg = vector containing height of seedlings for different PFT
%               syndromes
%           hbymin =
%           hmat = vector containing height at maturity for every PFT
%               syndrome
%           smax =
%           S =
%           Phi_net =
%           Phi_netSg =
%           j =
%           ThinMonth1 = thinning the first month
%
%%  OUTPUTS:  Bt = Total biomass of carbon in the trees
%           Bdead = Total biomass of dead tree material accumulated
%           N = Population vector at year y+1 including seed bank and trees
%               at different size classes grouped by PFT syndrome
%           Water = quantity of water in the soil [mm] at year y+1
%           Phi_net =
%           Phi_netSg =
%           dEdN = vector containg the contribution of every PFT syndrome
%               to canopy openness on the ground
%           dEdz = vector containing the canopy openness at every height
%               classes z
%
%%  EXAMPLE:
%
%%  REFERENCES
%   CORNWELL, W. K., CORNELISSEN, J. H. C., ALLISON, S. D., BAUHUS, J., EGGLETON, P., PRESTON, C. M., SCARFF, F., WEEDON, J. T., WIRTH, C. and ZANNE, A. E. (2009), Plant traits and wood fates across the globe: rotted, burned, or consumed?. Global Change Biology, 15: 2431�2449. doi: 10.1111/j.1365-2486.2009.01916.x