

function [N, Trees, Community, State, Private, Open, Psell] = Governance(Households, Land, Infrastructures, Biodiversity, Economy, Social, tlimit)

% Introduction 
    %% Decision model: defined the probability behaviour of stakeholders to make
        % a chain of decisions from creating a specific institutional arrangement
        % to probability of choosing a specific spatial structure, amanagement 
        % and harvest for the forests.
    %% REGULATORY SERVICES: CARBON SEQUESTRATION MARKET
        % Probability to participate to carbon market programs/willingness to
        % sell carbon credits : IncomeAdd: continuous
        % variable indicating the importance of other Amenities: Likert ordinal
        % (1-5) 1: strongly disagree, 2 disagree, 3 neither/or, 4 agree, 5
        % strongly agree IncomeAdd: Likert ordinal (1-5) CO2attitude: Likert
        % ordinal sum 4 questions (1-20) 
        % Gender: 0 female, 1 male 
        % Credit: continuous $/acre/yr ($3-$60): concider move $/tonne/acre/yr
        % Contractlength: 15-50years (commitment requirement) TenureY: past
        % tenure duration [yr] average 20yr Barriers: Likert ordinal (1-5)
        % barriers posed to participation Reside: binary (0-1) whether or not
        % live on the land (PS: people don't like the idea of third party
        % inspections close to their house and interested to compensate the
        % driving costs if far):
        % DistanceF: dummy = 1 if live far from the forest
        % IncomeExt: Household Income from a regular job and/or a business
        % IncomeHH: Total annual cash income of the household
        % PeopleHH: Number of people in the household
        % Migration: Migration into the area within past 5 years (dummy)
   
        % PercentRice: Percentage income from rice paddy fields
        % AlT: Total land area owned by a household [ha] (20 Ropani = 1 ha), average is 11.11+-0.69 Ropani ~ 0.5ha. 
        % FUGCM: Executive committee member in FUG from the respondent's house (1 = yes, 0 = no)
        % ACF: Area of the community forest [ha]
        % AT: total land of the landowner Ai: area of the land 
            % ATmixt: percentage of the total land occupied by mixt forest 
            % Timberprod: Timber production objective, 1 if yes, 0 if no 
            % ATpine: The percentage of land occupied by pine plantation 
            % TenureY: past tenure duration [yr] with forest: average 20yr 
            % dbh: diameter of the trees [cm] 
            % SBA: Stand Basal Area [m2/ha] 
            % Coop: Binary, 1 if respondent consider cooperation with neighboring or was contacted by a neighbor in the past 5 yesrs landowner; 0 otherwise. 
            % Invest: Ordinal 5 categories - higher value indicates higher importance of financial investment as a reason for owning forestland.
            % Landpay: Ordinal 5 categories - 1 strongly disagree with the statement " land must provide a return to cover expenses associated with
%   ownership," 2 if disagree, 3 if neutral, 4 if agree, 5 if strongly
%   agree. 
            % Amenity: Continuous - higher value indicates amenity-oriented reasons for owning forestland. 
            % IncomeHH: Household income ($)
            % Nneighbours: number of private individuals owning bordering parcels
            % Nonconsumpt: Non-consumptive recreation on neighbouring parcels (0-1): average 0.278 
            % Patparty: Past participation in land management activities with neighbours (0-1) average 0.169 
            % AffectNeighbours: affect for how own management affects neighbours (0-1) 
            % STP: Sold timber in the past (0-1) 
            % PSP: Permanent structure present (0-1) 
            % Huntown: Hunt on own parcel in last year (0-1) 
            % Huntneighbour: Hunt or fish on neighbouring parcel(s) (0-1) Distance of the forest patch from the residence (km)
% TFP: TIMBER FOREST PRODUCTS (Harvesting trees for sawtimber or pulp)
    % Parameters
        % Profres: Continuous-higher value [1 - 5] indicates higher
        % importance of professional advice and research in landowner
        % decision making.
        % Locorg: Local organization that set community governance (yes = 1, no = 0)
        % Eqdist: Equitable wealth distribution between members of the community (yes = 1, no =0)
        % Attitude: 1 if the household scored more than 39 points  in the  attitude  index; 0 otherwise
        % Awareness: 1 if the household scored more than 7 points in the  awareness  index; 0 otherwise
        % Wealth: 1 if the household possess land and receives an annual income above 5000 rupees (~$161 in 1995); 0 otherwise 
        % TimeCF: Time to reach the community forest from respondent's house (mn)
        % SizeHH: Household size (number of people sharing the same kitchen for more or less 6 months in a year
        % Rsex: sex of the respondent (1 = female)
        % DistanceMarket: Distance between nearest market and respondent's house (km)
        % Afi: area of a given forest patch i [ha]
        
%% Inputs
    % Governance = 1: community tenure, 2:state tenure, 3: nipf tenure, 4: no tenure or dual tenure creating a situation of open access
            
    % Households caracteristics
        DensityHH0 = Households(1,1);
        NumberHH0 = Households(2,1); 
        SizeHH = Households(3,1);   % SizeHH = 2.5; number of members within the household (% 1 household = Europe<Japan<Canada<USA: ~2.5 [2.4-2.6], Brazil: 3.3, Nepal: 4.7, Latin America: 4.8, India: 4.9, Asia: 5.1, Sub-Saharan Africa: 5.3, NearEast/NorthAfrica: 5.7
        DistanceHH = Households(4,1); % distance of forest from household [km] (fixed at 2km: see agrawal ~ 1.5km)
        IncomeHH = Households(5,1);  % IncomeHH: annual income of household (mean = 43932Tk. Bangladesh (~ $ in 2004)
        AgeHH = Households(6,1);   % AgeHH: age of household head
        PoorHH = Households(7,1);  % PoorHH: Proportion of households that have landholdings below 1 acre
        EducHH = Households(8,1); % EducHH: is education level of the head of Household (years of school including Uni)
        MaleHighschoolGrad = Households(9,1); % Proportion of male with high school graduate
        FemaleHighschoolGrad = Households(10,1); % Proportion of male with high school graduate
        DistanceMarket = Households(11,1); % Traveling time to market [mn] 18.5 for 1.5km
        BrahminHH = Households(12,1);
        FarmHH = Households(13,1);
        ObjectivesForestHH = Household(14,1);  % Number of objectives to fulfill with forests. 
    % Social structure around the forest
        Governance = Social(1,1); % Who own the land: Governance = 1: community-owned, 2:State-owned, 3:NIPF-owned, 4:dual-owned or open-access
        SubGovernance = Social(2,1); 
            % if Governance == 1: Choose:   % 1:TCF = Traditional community forest 
                                            % 2:PFM = Participatory Forest management
                                            % 3:CPF = Community parcel forest
                                            % 4:CFP = Community forestry plantation outside the community forest
                                            % 5:PFP = Private forest plantation outside the commnunity forest
            
            % if Governance == 3: Choose    % 1:SZF = State zones forest
                                            % 2:SCF = State Concession Forest (Gradient from Centralized to Decentralized)
                                                   
            % if Governance == 3: Choose    % 1:IFL = Individualistic forest land 
                                            % 2:PNC = Private/Neighbor cooperation
                                            % 3:PSC = Private/state cooperation
                                            % 4:PNSC = Private/Neighbor/state coop
            
            
        FUGCM = Social(2,1); % D.1.1. FUGCM = 1 Executive committee member in FUG from the respondent's house (1 = yes, 0 = no)
        Shareholding = Social(3,1);   % Shareholding = 1: dummy [0-1] for whether stakeholders have shares on the community forest (i.e., clearly defined tenure)
        Pshareholders = Social(4,1);  % = 0.81 in average in Japan. Proportion of shareholders in the community forest
        Gini = Social(5,2); % Gini index/ratio of private forest ownership [0-1]: estimate the statistical dispersion/inequality among individuals in private ownership supplementing the community forest: Gini -> 1 (HH have a collective ownership only), Gini ->0 (perfect equality: HH have private forests only)
                            % the Gini coef?cient measures the distribution of forest land area ownership by comparing total forest land area to cumulative percent of private forest land owners
        AffectNeighbours = Social(6,2);
        Nneighbours = Social(7,2);        
        Pastparty = Social(8,2);
        CoopNeighbours = Social(9,2);
        PESInitiator = Social(10,2); % Initiator of the contract for PES: 1=owner, 2=environmental org/agency (1 is good, 2 is bad)
        CancelContract = Social(11,2); % Present owner can cancel PES contract
        Restrictmanage = Social(12,2); % Restriction on forest use: 1 = small patches of forest protected, 2: Nature management plan, 3: No sylvicultural practices allowed (Best is 1, 3 is worst)
        
    % Economic system and services around the forest
        AgroLandcash = Economy(1,1); % = 0.5 % prop_landcash: Proportion of agricultural land in the community used for commercial purposes  indicates engagement with the agrarian output market
        GTFF = Economy(2,1); % GTFF: dummy variable indicating whether the farmer had been contributing to Tree Farming Funds (TFFs) or not. yes = 10% (with 10% of the revenues from the final harvesting of the existing plots is to be deposited in TFF to allow implementation of more participatory forest programs.
        TreeCuttingRight = Economy(3,1); %  0:no, 1:yes - right to cut and sell timber trees that you plant on state-owned, community/private-managed forests
        AccessFees = Economy(4,1); % 0: no, 1:low, 2:high  access fees to be elligible to enter the state-owned/community-private managed forest
        DependforestHH = Economy(5,1);  % DependforestHH: percentage of household income from forest
        IncomeTimber = Economy(6,1); % 1/0:yes/no - to get income from timber (reason for owning forest) 
        IncomeAgri = Economy(7,1); % 1/0:yes/no - have income from agriculture (reason for owning forest)
        Bioenergy = Economy(8,1); % 1/0:yes/no - To abtain firewood (reason for owning forest)
        Sapproduct = Economy(9,1); % 1/0:yes/no - to make mappple syrop or other sap products (reason for owning forest)
        Recreation = Economy(10,1); % 1/0:yes/no - Personal recreation (reason for owning forest)
        RecreationAccess = Economy(11,1); % 1/0:yes/no - Contract with state requires recreational access to non-motorized activities
        PlacetoLive = Economy(12,1); % 1/0:yes/no - As a place to live (reason for owning forest)
        Scenary = Economy(13,1); % 1/0:yes/no - Enjoy the scenary (reason for owning forest)
        Nodevelop = Economy(14,1); % 1/0:yes/no - Protect land from development (reason for owning forest)
        wildlife = Economy(15,1); % 1/0:yes/no - Provide wildlife habitat (reason for owning forest) 
        Privacy = Economy(16,1); % 1/0:yes/no - have privacy (reason for owning forest)
        EnvProtec = Economy(17,1); % 1/0:yes/no - Protect the environment (reason for owning forest)
        Bequest = Economy(18,1); % 1/0:yes/no - Pass on to my children (reason for owning forest)
        Purchased = Economy(19,1); % 1/0:yes/no - Acquisition of forest by purchase (if 1: reduces probability signing joint cooperation)
        Tradition = Economy(20,1); % 1/0:yes/no - Preserve family and traditions (reason for owning forest)
        Invest = Economy(21,1); % 1/0:yes/no - as financial investment (reason for owning forest)
        Nature = Economy(22,1); % 1/0:yes/no - leave land unmanaged, letting nature takes its course (reason for owning forest)
        PES = Economy(23,1); % [$US] One-time payment for ecosystem services per hectar (1 ha = 2.47105 acre)
        Enlargeforest = Economy(24,1); % Binary: 1:yes, 0:n0 - owner's intension of enlarging the productive forestland in the short/mid term
        TimberRights = Economy(25,1); % 1/0:yes/no - 1 if landowner is required to convey rights (bullshit: better be 0)
        ObjectiveTimber = Economy(26,1); % 1/0:yes/no - 1 if main objective of this forest is timber.
        minTreeDensity = Economy(27,1); % [tree/ha]: min timber tree density/ha on forest land required by the state [usually required in conservation areas ~ 400-1000/ha].                   
        PtimberTree = Economy(28,1); % Proportion of trees that must be tall very heavy timber (i.e., the larger timber density class + two heaviest seed mass lasses)
        TreeCuttingObligation = Economy(29,1); % 1/0:yes/no - 1 if Conservation program requires obligation for harvesting timber
        Taxgain = Economy(30,1); % $/year [0-2000]: tax deduction for accepting coordinating conservation management between neighboors
        Harvloss = Economy(31,1); % $/year [0-800]: loss of harvest due to coordinated conservation management between neighbors
        PincomeAgri = Economy(32,1); % Proportion of total income from agriculture
        PincomeTimber = Economy(32,1); % Proportion of total income from timber
    
    % Physical Land caracteristics of forest and around
        AlT = Land(1,1); 
        AfT = Land(2,1); 
        AagrT = Land(3,1);
        Aforestry = Land(4,1);
        Gravelsoil = Land(5,1); % = 0 
        SandySoil = Land(6,1); % = 0
        LoamSoil = Land(7,1); % = 
        Altitude = Land(8,1);  % Altitude: altitude of the forest [m] 
        Walktime = Land(9,1); % from household to forest: = 18.5mn According to Wikipedia's page on walking, the average adult walking speed is 80 m/min, therefore it would take 1500/80 = 18.5 minutes to walk 1.5 kilometre.  
        Ncomplant = Land(10,1); % Number of community plantations created outside the protected community forest                                
        TFAT = Land(11,1); % TFAT: is dummy variable indicating whether or not trees were felt after completion of a 10 year tenure rotation period. If felt, TFAT = 1 (24.8%) and 0 otherwise
        SizeRice = Land(12,1);  % = 0.71 [ha];Increase the value to SizeRice = 2, in order to reduce probability of signing a JFM.
        PaddyHH = Land(13,1);   % PaddyHH: average paddy field area per household [ha]
        Nforestpatches = Land(14,1); % Total number of forest patches 
        DistanceBetweenForests = Land(15,1); % Average distance between forests [km]
        Pfastree = Land(15,1); % Proportion of total fast-growing tree land owned
        SW = Land(16,1); % Softwood: Binary
        MX = Land(17,1); % mixedwood: Binary
        HW = Land(18,1); % hardwood: Binary       
        
        
    % Access to structural and functional infrastructures for the forest management
        AccessRoads = Infrastructures(1,1); % 1:yes, 0:no - Road access inside the forest
        AccessAssistance = Infrastructures(2,1); % 1:yes, 0:no - access to technical assistance on site
        AccessServicesInputs = Infrastructures(3,1); % 1:yes, 0:no - access to agroforestry extension services
        AccessMachinery = Infrastructures(4,1); % Binary 1:yes, 0:no - logistic ressources access to to forestry activities (machinery)
        RAFD = Infrastructures(5,1); % RAFD: dummy variable indicating whether the farmer had received any advice from Forest Department officials or not; yes = 59.8%
        FDPT = Infrastructures(6,1); % FDPT: dummy variable indicating whether the farmer had received any training from Forest Department officials or not; yes = 56.4%
        FRMP = Infrastructures(7,1); % 1/0:yes/no - Access to a "forest ressource management plan" (FRMP)
     
    % Incentives on State land
        PFDL = IncentivesS(4,1); % PFDL: dummy variable indicating whether participatory forestry disrupted the interests of any local people or not; yes = 16.5%
        SSP = IncentivesS(5,1);  % SSP: dummy variable indicating whether the farmer is satisfied with the species planted or not; yes = 76.4%
        
        % EBRH: a dummy variable indicating whether the farmer thinks that he would receive aspired benefits after final harvesting of trees or not; yes = 76.4%
        % APC: a dummy variable indicating whether the contractual agreement period on the farmer's plot was completed or not; yes = 35.5%         
        % SizeRice: size of the rice field [ha]
        % SizeRubber: Size of the complex rubber agroforest [ha]
        % DensityHH0 = 10; %  Define the Baseline density of household per 10 ha (10 ha ~ 25 acres = average owned by nipf owners in USA)
        % NumberHH0 = 4; number of households considered (4 households)     
        
% OUTPUT
    % Community = (Access,Efficient_monitor,Efficient_manager,Pcss,Psell)';
        % Access: proportion of community members that have access to forest ressource
        % Pcss: probability to join a carbon sequestration scheme
    % State = (Access,Pcons,Efficient_monitor,Efficient_manager,Pcss,Psell)';
    
        % Pcss: probability to join a carbon sequestration scheme
    % Private = (Access,Pcons,Efficient_monitor,Efficient_manager, Pcss, Psell)';
        % PconsAfT: Proportion of the landowner forest land subject to conservation      
        % Pcss: probability to join a carbon sequestration scheme
    % Open access = (Access, Pcons, Efficient_monitor,Efficient_manager, Pcss, Psell)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%      
    
    
    % CoopNipfState = [ConveyTimberRights, HarvestTimber, RecreationAccess]'
    %               increase restrictions: CoopNipfState = [0,0,0]' < [0,0,1]' < [0,1,1] < [1,1,1]

%%  DEPENDENCE OF HOUSEHOLDS ON FORESTS ON FUELWOOD: used for cooking, water heating or space heating.
   % Harvesting trees for biomass energy (Joshi & Mehmood,
    % 2011) Reduces the cost of other maintenance operations (e.g.,
    % ripping, furrowing, bedding, small diameter trees, weed control ...
    
    % Asumption Pcons = continuous between 0-1, while in Joshi & Mehmood
    % Pcons = Wild (binary: 0 = no wild life management, 1 = wild life
    % management) 
    % Age: 1 >60yrs old, 0 <= 60yrs old 
    % EducHH: 1 has bachelor
    % degree US, Bacaloreat (continental Europe), 0 if not
    % FearEviction: fear of eviction (dummy, 1 == threat, 0 if not)
    % NumberNTFP: Number of different types of NTFPs collected by each family (e.g. items, leaves, food, fuel, fodder, fruits, medecine ...)
    % LED: Local employment days (number of days employed in local works in a year
    % LivelihoodIndex: Affluence index [1-5] (livelihood status value) The afluence index is constructed by considering 12 indicators, each indicator having 5 categories with points 1 to 5 to be attached to each such component according to some pre-de?ned criterion. As the index rises, it implies better living conditions 
    % Marketaccess: binary    
    
    % Country: India, State: West Bengal (Datta & Sarkar, 2012)
        if AgeHH > 60
            Age = 1
        else
            Age = 0
        end
        % Tagrinc: Total agricultural income ([$0 - $9230] average: $232.8)    
        Tagrinc = PincomeAgri*IncomeHH;  
        DependforestHH1 = 1/(1 + exp(-(FearEviction*0.733373 + NumberNTFP*0.293361 - LED*0.013617 - LivelihoodIndex*0.063495)));
    % Country: Nepal, Region: West (Chhetri, 2010)
        %DependforestHH1 =  
        %Pntfp = 
    % Country: Rwanda, Nyungwe Forest Reserve (Masozera & Alavalapati, 2004)
        DependforestHH2 = 1/(1 + exp(-(SizeHH*0.208 - AgeHH*0.056 - Tagrinc*0.0000331 - Marketaccess*0.328)));
    % Country: Ethiopia, Region: Tigray islands (Babulo et al., 2008)
        DependforestHH3;
    % Average:
        DependforestHH = mean([DependforestHH1 DependforestHH2 DependforestHH3]);
 
%% NIP axis: defines the level of constrains on conservation of biodiversity & ecosystem services, under payment or other benefits.
                
     for Axis = 1 
         if Tenure == 1  % NIP ownership          
            
            %% Amenities: baseline  and carbon sequestration - Probability for owning forest land for Amenity reason 
                % Country: USA, (Ma & Kittredge, 2011) using Likert Ordinal 5 categories for every parameter.
                    Amenity = - IncomeTimber*0.02 + IncomeAgri*0.21 + Bioenergy*0.47 ...
                            + Sapproduct*0.35 + Recreation*0.54 + PlacetoLive*0.59 ...
                            + Scenary*0.75 + Nodevelop*0.76 + wildlife*0.76 + Privacy*0.71 ...
                            + EnvProtec*0.72 + Bequest*0.51 + Tradition*0.6 + Invest*0.08 ...
                            + Nature*0.3; 
                        
            %% Conservation - Baseline probability of managing land for conservation purposes (simplify as sparing land: including selling giving conservation easements). 
                % Country: USA, State: West Virginia (Joshi & Arano, 2009):
                    Pspare1 = 1/(1 + exp(-(4.14 - AgeHH*0.05 - (DistanceHH*0.621371)*0.01 - Amenity/1.83*0.21)));
                % Country: USA, State: (Ma & Kittredge, 2011)
                    Pspare2 = 1/(1 + exp(-(- Age3050*0.999 - Age5165*0.998 - Age65plus*0.988 + AccessRoads*0.135 + CoopNeighbours*0.213 + Green*0.064))); % Engaged owners: Probability that the objective is freezing land for conservation = 0.156 
                %   Average
                    Sparing = mean([Pspare1 Pspare2]);
                    
            %% Baseline Sylvicultural activity: Probability of engaging in Silvicultural activities
                % Country: USA, State: West Virginia (Joshi et al., 2009)
                    Psilvi1 = 1/(1 + exp(-(5.44 + EducHH*0.97 + IncomeHH*0.31 - log(AfT)*0.42 + Purchased*0.95 - ObjectiveTimber*0.5 - Amenity/1.83*0.2 + FRMP*1.62)));  % Probability that the objective is selling timber 0.028 for Owners engaged in management programs, 0.164 for Owners unengaged in management programs
                % Country: India, Province: Andhra Pradesh (Alavalapati et al., 1995) - adoption of farm forestry
                    Psilvi2 = 1/(1 + exp(-(Wealth*1.3123 + Aware*1.4153 + Attitude*1.4827)));
                % Average - 
                    Psilvi = mean([Psilvi1  Psilvi2]);    
        
           %% Efficiency in management in a community parcel system                    
                Efficient_manager = 1;
                
           %% Incomeuse - Probability for owning forest land for incomeuse(Ma & Kittredge, 2011) using Likert Ordinal 5 categories for every parameter.
                IncomeUse = IncomeTimber*0.74 + IncomeAgri*0.72 + Bioenergy*0.52 ...
                    + Sapproduct*0.55 + Recreation*0.06 + PlacetoLive*0.00 ...
                    - Scenary*0.13 - Nodevelop*0.16 - wildlife*0.17 - Privacy*0.16 ...
                    - EnvProtec*0.26 + Bequest*0.16 + Tradition*0.11 + Invest*0.38 ...
                    - Nature*0.45; 
           %% Woodfire - Probability of selling woodfire (bioenergy)
                if Age > 60
                    Age60 = 1;
                else
                    Age60 = 0;
                end                 
                % modification from original paper: -0.66*continuous measure Pot rather than 0-1
                Pbioenergy = 1/ (1 + exp(-(0.71*(log(AfT/2.47)) + 0.01*(ATmixt + ATpine) - 0.66*Pot - Age60*0.41 + 0.42*Pcons + EducHH*0.24)));
                Pwoodfire = Nthin * Pbioenergy;
                
           %% Timber - Probability of selling timber individually                
                % Country: USA, State: West Virginia (Joshi & Arano, 2009)
                Sell1 = 1/(1 + exp(-(4.37 - Age*0.06 + EducHH*1.58 - Prof*1.39 + TenureY - Timber*0.65 + (Amenity*0.06)/1.83 + Planif*1.56)));
                % Country: USA, State: Massachusetts (Ma & Kittredge, 2011)
                Sell2 = 1/(1 + exp(-(0.164*AT + EducHH*0.445 + AccessRoads*0.234 + IncomeUse*0.234)));  % Probability that the objective is selling timber 0.028 for Owners engaged in management programs, 0.164 for Owners unengaged in management programs
                % Country: India, State: Andhra Pradesh (Alavalapati et al., 1995)
                Sell3 = 1/(1 + exp(-(Wealth*1.3123 + Awareness*1.4153 + Attitude*1.4827)));
                Ptimber = mean([Sell1 + Sell2 Sell3]);     
           %% What type of forest to plant
                % Majumdar et al., 2006: Effect of Urbanization on the Forest Land Use Change in Alabama: A Discrete Choice Appproach    
           
                    % PGI:Number of persons/Km around each FIA plot within 100 Km
                        % radius of each FIA plot (mean 136): lanowners closer to
                        % population centers prefer hardwood (negative value for PGI*Csw and PGI*Cmx
                    % VOL:Average volume in cubic feet per acre for the FIA plots (mean 1027.2)
                    % SW:Initial forest type dummy for Softwood forest (mean 0.35)
                    % MX:Initial forest type dummy for Mixed forest (mean 0.44)
                    % HW:Initial forest type dummy for Hardwood forest (mean 0.2)
                    % IncomeHH2: Real (1982=100) per capita personal income by county in $ (mean 111.95)
                    % RET:Growing stock removals in cubic feet per acre of county land area (mean 37.53)
                    % Slope:Slope in percent for FIA plot (mean 9.93)
                    % PD:Number of persons per unit of land area by county (mean 73.8) assume that 
        
                    Vol = 1027.2;
                    Slope = 9.93;
                    Pgi = 136;
                    RET = 37.53;
                    PD = 73.28;
                    IncomeHH2 = 111.95;
                    taus = 0.85;
                    tauk = 0.85;
                    sigmals = 0.87;
                    sigmams = 0.87;
        
                    sum1 = exp(0.401*HW - 0.9931*SW - 0.002*Pgi) + exp(- 2.3806*MX - 1.266*SW) + exp(-1.9815*MX - 0.2388*HW - 0.0045*Pgi); 
                    Iis = log(exp(0.0011*Pgi*0 + sigmams*log(sum1)) + exp(- 0.0172*RET*0 + sigmams*log(sum1)) + exp(0.0019*PD*0 + sigmams*log(sum1)) + exp(-0.4266*IncomeHH2*0 + sigmams*log(sum1)) + exp(0.0011*Pgi*1 + sigmams*log(exp(0))) + exp(- 0.0172*RET*1 + sigmams*log(exp(0))) + exp(0.0019*PD*1 + sigmams*log(exp(0))) + exp(-0.4266*IncomeHH2*1 + sigmams*log(exp(0))));
                    Iil = log(sum1);
        
                    sumPis = exp(-0.5714*1*SW + 0.0217*Slope*1 + 0.0009*Vol*1 + taus*0) + exp(-0.5714*0*SW + 0.0217*Slope*0 + 0.0009*Vol*0 + taus*Iis);
                    PiNH = exp(-0.5714*1*SW + 0.0217*Slope*1 + 0.0009*Vol*1 + taus*0)/sumPis;        
                    PiH = exp(-0.5714*0*SW + 0.0217*Slope*0 + 0.0009*Vol*0 + taus*Iis)/sumPis;
        
                    sumPils = exp(0.0011*Pgi*0 - 0.0172*RET*0 + 0.0019*PD*0 -0.4266*IncomeHH2*0 + Iil) + exp(0.0011*Pgi*1 - 0.0172*RET*1 + 0.0019*PD*1 -0.4266*IncomeHH2*1 + log(exp(0)));
                    PiH_F = exp(0.0011*Pgi*0 - 0.0172*RET*0 + 0.0019*PD*0 - 0.4266*IncomeHH2*0 + Iil)/sumPils;
                    PiH_NF = exp(0.0011*Pgi*1 - 0.0172*RET*1 + 0.0019*PD*1 - 0.4266*IncomeHH2*1 + log(exp(0)))/sumPils;
        
                    Pmx1 = PiH*PiH_F*exp(0.401*HW - 0.9931*SW - 0.002*Pgi)/sum1;        
                    Phw2 = PiH*PiH_F*exp(- 2.3806*MX - 1.266*SW)/sum1;
                    Psw3 = PiH*PiH_F*exp(-1.9815*MX - 0.2388*HW - 0.0045*Pgi)/sum1;       
        
                    Total = PiNH + PiH_NF + Psw1 + Phw2 + Pmx3;  %should equal to 1, PiH_NF ~ 0
        
                    Psw = Psw1 / (Psw1 + Phw1 + Pmx1); % Probability of planting softwood
                    Pmx = Pmx1 / (Psw1 + Phw1 + Pmx1); % Probability of planting mixed-wood
                    Phw = Phw1 / (Psw1 + Phw1 + Pmx1); % Probability of planting hard-wood
                    
         elseif Tenure == 2 %% Community ownership
                %% Parcelization: Transforming collective into individual parcellization of the community land with users precluded from selling or renting the land (shareholders + non-sharholders if necerary). 
                    % Individualized management corresponds to the institution of divided use of common-property forests, 
                    % in which land is parceled out to individual users for what amounts to indefinite
                    % periods of time, but users are precluded from selling or renting the land 
                            
                    % Probability Choice of individualized management on community land (Probit)
                        % Country: Japan, Prefecture: Gunma, 45 community forest (iraichi) vs 16 individual forest parcels (previously iraichi) (Kijima et al., 2000)                    
                            Pparcels = normcdf(Aforestry*0.01,0,1);
                    
                    % Proportion of individualized area [0-1] (Tobit model)
                        % Country: Japan, Prefecture: Gunma, 45 community forest (iraichi) vs 16 individual forest parcels (previously iraichi) (Kijima et al., 2000)                    
                            Propind = 1.27 + Aforestry*0.003 - DistanceHH*0.18 - Gini*2.02;                    
                            if Propind <= 0
                                Propind = 0;                        
                            end
                            for i = 0:1/NumberHH:1
                                if Propind <= i
                                    Nparcelles = i*NumberHH; % number of parcelles used to divide the community forest
                                end    
                            end
                    
                %% Sell stumpage to private sector: Vertical integration Probability of vertical integration of the community through to stage 2 or more - stage 1: stumpage (manage forest only), Stage 2: roundwood (harvest),+ eventually sawwood/lumber (Milling),secondary wood products 
                    % Country: Mexico, State: Oaxaca (Antinori & Rausser, 2008), only pstage3 available no pstage2
                        Z = - Roads*0.4 + MechaKnowledge*3.8 + ParastatalHistory*3.07 + AT*1.06 + ForestQuality*2.08 + HoursCity*0.5;
                        mu1 = 19.05; % Threshold 1: transition from stumpage to roundwood
                        mu2 = 21.87; % Threshold 2: transition from roundwood to lumber 
                        mu3 = 24.34; % Threshold 3: transition from lumber to secondary wood products                
                    
                    %% Community monitors, manages and harvest timber    
                    if integration >= 2                    
                        % Country: Mexico, State: Oaxaca (Antinori & Rausser, 2008), only pstage3 available no pstage2
                            Pstage2 = 1/(1 + exp(Z-mu2)) - 1/(1 + exp(Z-mu1));
                            Pstage3 = 1/(1 + exp(Z-mu3)) - 1/(1 + exp(Z-mu2)) - 1/(1 + exp(Z-mu1));
                            Pstage4 = 1 - 1/(1 + exp(Z-mu3));
                            Ptimber = Pcfp * (Pstage2 + Pstage3 + Pstage4);                        
                        % Harvesting intensity, 0:no harvest, 1:medium intensity, 2:high intensity
                            Iharvest = 1; %   
                        
                    %% Community do not harvest timber: "move from Make decision to Sell decision" ("sell-or-make decision"): Probability of moving from stumpage to roundwood and lease private company harvest.
                    elseif integration == 1
                        % Country: Mexico, State: Oaxaca (Antinori & Rausser, 2008), only pstage3 available no pstage2
                            Z = - Roads*0.4 + MechaKnowledge*3.8 + ParastatalHistory*3.07 + AT*1.06 + ForestQuality*2.08 + HoursCity*0.5;
                            mu1 = 19.05; % Threshold 1
                            Pstage1 = 1/(1 + exp(Z-mu1));
                            Ptimber = Pcfp * Pstage1;                
                        % Harvesting intensity, 0:no harvest, 1:medium intensity, 2:high intensity
                            AccessRoads = 1;
                            Iharvest = 2; 
                    end
            
        elseif Tenure == 3 %% State ownership
               %% Parcelization: Chinese litterature
               
        elseif Tenure == 4 %% No clear ownership
        
        end 
    end %% axis 1     

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     
%% Community-centric axis: Community axis defines the level of cooperation for monitoring, management, conservation, sharing, access rights         
    for Axis = 2 %%        
        %% Creating a community forestry plantation (CFP) rather than individual private forest, used for timber extraction and fuelwood, in order to reduce pressure on natural community forest   
            
            % D.4.1. - Probability of creating a CFP or NIPFP             
                % Country: India, State: Bihar (Baker 1998) - probability
                % of a community forestry plantation rather than private
                % plantations
                    Pcfp = exp(-(-6.3693 + 12.045*Locorg - 4.983*Eqdist))/(1 + exp(-(-6.3693 + 12.045*Locorg - 4.983*Eqdist))); %here assume Eqdist = 0 and Locorg = 1
                
            % D.4.2 - Usufruct access proportion (of members) to forest for timber and ntfp (firewood ...)
                % Country: India, State: Himachal Pradesh (West Himalaya) (Naidu, 2011): "fractional" logit model
                    traditional_d = 0;
                    jfm_d = 1;
                    change the model below to account for fractional effect (pi = zi/sum(z)), grazing + fodder + fuel 
                    Access = 1/(1 + exp(-(-3.939 + Prop_poor*9.194 + prop_landcash*6.414 - traditional_d*1.488 - jfm_d*5.817))); % was +3.939 but suspect wrong (ask author)
                    %Access = B_fuelwood = 0.5*B_above_total;  % 0 - 50%: + reduction by 40% of the consumption by installing efficient stove devices. mainly high density wood (> 800kg/m3)
            % D.4.M - Efficiency in monitoring and management
                    Monitor = 1;
                    Manage = 0; 
            
        if Tenure == 1 %% NIP ownership: Private/Neighbours cooperation (PNC)
                    % Access rate for neighbors for resource extraction
                            Access = 0;
                    % D.1.2.1 - Probability of cooperation between Neighbours, including cooperation for sylvicultural activities (here for fast-growing plantations, but assumed the same for any type of forest) 
                        % Country: USA, States: (Vokoun et al., 2010)
                            if Amenity < 3.7 % Amenity/2 
                                Nonconsumpt = 0;
                            else
                                Nonconsumpt = 1;
                            end
                            Pcoop1 = 1/(1 + exp(-(-2.962 + Nneighbours*8.65E-2 + IncomeHH*4.88E-6 + Nonconsumpt*0.632 + Pastparty*0.677 + AffectNeighbours*0.436)));
                        % Country: Spain, Region: Galicia (Rodriguez-Vincente & Marey-Perez, 2009): 
                            Pcoop2 = 1/(1 + exp(-(3.873 + 1.425*Enlargeforest + 2.38*AccessMachinery + 2.46*FarmHH)));
                        
                            
                            % Macro probability
                            Pcoop = mean([Pcoop1  Pcoop2]);
                    % D.1.2.2 - Probability of engaging in Sylvicultural activities
                            % Assume that the probability increases N times the number
                            % of neighboors (NumberHH) ingaged in the cooperation (Pcoop)
                        % Country: USA, State: West Virginia (Joshi et al., 2009)
                            Psilvi = Pcoop*NumberHH*(1/(1 + exp(-(5.44 + EducHH*0.97 + IncomeHH*0.31 - log(AfT)*0.42 + Purchased*0.95 - ObjectiveTimber*0.5 - Amenity/1.83*0.2 + FRMP*1.62))));  % Probability that the objective is selling timber 0.028 for Owners engaged in management programs, 0.164 for Owners unengaged in management programs
                            Psilvi(Psylvi>1) = 1;
                            % Probability of cooperation/synchronization between neighboring NIPF landowners
                    % D.1.2.3 - Probability of synchronizing harvests    
                        % Country: USA, State: Virginia (Vokoun et al., 2010)
                            HarvestSynchro = 1/(1 + exp(-(-2.08 + IncomeHH*6.44E-6 + STP*0.63 - PSP*0.57 - Huntown*0.435 - Nneighbours*5.66E-3 + Huntneighbour*0.703))); 
                            
                    % D.1.2.M - Efficiency in monitoring and management
                            Monitor = Pcoop;
                            Manage = 1;
                            
                                   
        elseif Tenure == 2 %% Community ownership (Traditional Community Forest TCF), Multiple-Use Community forest (Native forest under communal regime)
            % Conservation: Probability that community members are involved in organized conservation in the Community forest land, (do not take into account sacred groves).            
                % Country: Nepal, Region: West (Chhetri, 2010)
                    % NumberHH: number of user households (size of community Forest User Groups FUG) ~ 226 households [52 - 385]
                    NumberHH = NumberHH0*; 
                    Pconsact = 1/(1 + exp(-(NumberHH*0.034 + FUGCM*1.369 - (AlT*20)*0.061  - (AfT*20)*0.042)));
            % Access: Usufruct access proportion (of members) to forest for timber and ntfp (firewood ...)
                    % = Probability of participation in resource utilization:
                % Country: Nepal, Region: West (Chhetri, 2010)
                
                    Access1 = 1/(1 + exp(-(Rsex*1.039 + SizeHH*0.273 - TimeCF*0.055 - DistanceMarket*0.187)));
                % Country: India, State: Himachal Pradesh (West Himalaya) (Naidu, 2011)
                    % Parameters
                        % jfm_d: Dummy variable for co-management regime set up by the Forest Department (in conjunction with NGOs and/or aid agencies)
                        % traditional_d: Dummy variable that takes the value 1 if traditional community management regime exists in the community and zero otherwise
                        traditional_d = 1;
                        jfm_d = 0;                        
                    % VARIABLES
                        % PoorHH: proportion of poors
                    % Model:
                        Access2 = 1/(1 + exp(-(-3.939 + PoorHH*9.194 + AgroLandcash*6.414 - traditional_d*1.488 - jfm_d*5.817))); % was +3.939 but suspect wrong (ask author)       
                % Country: India, States: 27 (Murali, 2002) - Murali KS, Murthy IK, Ravindranath NH (2002a) Joint forest management in India and its ecological impacts. Environ Manag Health 13(5):512528 
                    % Access = 0.75*B_above_total; % 0 - 50%: mainly high density wood [> 800kg/m3]
                % Average
                    AccessNS = mean([Access1 Access2]);
            % Monitoring efficiency:
                Monitor = 1;
            % Management efficiency:                    
                Manage = 0;
            
                
            %   Community-owned - Privatly managed parcels    
                % Country: Japan, Prefecture: Gunma, 45 community forest (iraichi) vs 16 individual forest parcels (previously iraichi) (Kijima et al., 2000)                    
                    AccessS = 1; % Access (allocation) for shareholders
                    NonShareholders = 1 - Pshareholders;
                    Access = Shareholders*AccessS + NonShareholders*AccessNS;
            
        elseif Tenure == 3 %% State ownership
                    % Access: Usufruct access proportion (of members) to forest for timber and ntfp (firewood ...)
                        % Country: India, State: Himachal Pradesh (West Himalaya) (Naidu, 2011): "fractional" logit model
                            % PARAMETERS
                                % prop_landcash: Proportion of agricultural land in the community used for commercial purposes  indicates engagement with the agrarian output market
                                % PoorHH: Proportion of households that have landholdings below 1 acre
                                % jfm_d: Dummy variable for co-management regime set up by the Forest Department (in conjunction with NGOs and/or aid agencies)
                                % traditional_d: Dummy variable that takes the value 1 if traditional community management regime exists in the community and zero otherwise
                                traditional_d = 0;
                                jfm_d = 1;
                            % Equation
                                Access = Ppfm*1/(1 + exp(-(-3.939 + PoorHH*9.194 + AgroLandcash*6.414 - traditional_d*1.488 - jfm_d*5.817))) + (1 - Ppfm)*1/(1 + exp(-(-3.939 + PoorHH*9.194 + AgroLandcash*6.414 - traditional_d*1.488))); % was +3.939 but suspect wrong (ask author)
                    % Monitoring efficiency:
                        Monitor = Pdecentralized;
                    % Management efficiency:                    
                        Mmanage = Pcentralized;
                            
        elseif Tenure == 4 %% No clear ownership
                   % Access: Probability reporting access to fuelwood to co-operatives on state forests
                        % Parameters: 
                            % SNTFP: Income from Selling of Non-timber forest products
                            % SCC: Income from Selling of cash crops
                            % SL: Income from Selling of livestock
                        % Country: Burkina Faso, Province: Sissili (Coulibaly-Lingani et
                            % al., 2009): Forest management units (FMU) are blocks of forest
                            % handed to co-operatives by the State for sustainable exploitation
                            % of timber and non-timber products: mainly fuelwood, honey and
                            % biodiversity conservation, + unprotected forest lands in the
                            % vicinity of Villages that provide resources for local people,
                            % depending on traditional user rights and tenure.  "Respondents
                            % considered that there were ambiguities in the rights of control 
                            % and ownership of the forested lands and the resources they offer.
                            % The forests are located on lands that are characterized by the 
                            % overlap of multiple traditional and modern rights. Prevailing 
                            % land law does not recognize customary land rights; all land is 
                            % considered State property, and anyone seeking access to land must
                            % apply for use rights. On the other hand, local communities do not
                            % recognize this State ownership and regard themselves as the true 
                            % owners of their land, by virtue of their ancestral rights. While 
                            % the State's monopoly of land ownership is theoretical, the 
                            % traditional rules are still observed by the local communities 
                            % under the leadership of indigenous ethnic group elders. The forest
                            % law, Code Forestier adopted in 1997, specifies the access rights
                            % of users and the guiding principles for usufructuary rights and practices.
                            % This law precludes livestock grazing from managed forest, thereby 
                            % limiting access to forest pastures by livestock herders. 
                            % Respondents mentioned that the lack of official recognition of traditional
                            % forest access rights has contributed to tenure instability. 
                            % It has also encouraged a short-term mentality in the use of forest
                            % resources, for example through illegal harvesting of wood, non-wood
                            % forest products and charcoal processing, which compromises the 
                            % sustainability of forest resources."        
                            Access = 1/(1 + exp(-(8.736*Ageclass25_45 - Ethni_Nuni*0.39 - Ethni_Mossi*0.541 + Ethni_Sissala*2.122 + Ethni_Dagara*1.133 - Ethni_Fulani*1.196 + Farmer*0.659 + Herder*1.244 - FarmerHerder*0.305 - DiverseIncome*0.184 + SNTFP*1.238 + SCC*1.177 + SL*1.065)));  
        end 
        
    end %% Axis 2    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% State-centric axis: defines the level of regulations on resource extraction, on conservation of biodiversity & ecosystem services, under payment or other benefits.    
    for Axis = 3                              
        if Tenure == 1 %% NIP ownership, Private/State: co-operation (PSC): level 1) management agreements PES / level 2) Conservation easement
                                 
                %% Conservation: Baseline Neighbor-State Cooperation at landscape scale (PNSC): Probability of cooperation between Neighbours, including cooperation for sylvicultural activities (here for fast-growing plantations, but assumed the same for any type of forest)                   
         
                    % Country: USA, States: (Vokoun et al., 2010)
                        if Amenity < 3.7 % Amenity/2 
                            Nonconsumpt = 0;
                        else
                            Nonconsumpt = 1;
                        end
                        Pcoop1 = 1/(1 + exp(-(-2.962 + Nneighbours*8.65E-2 + IncomeHH*4.88E-6 + Nonconsumpt*0.632 + Pastparty*0.677 + AffectNeighbours*0.436)));
                        Enlargeforest = 0; % No intension to enlarge forest in the near future (fixed size)
                    
                    % Average probability
                        Pcoop = mean([Pcoop1]);  
            
                        % D.4.M - Efficiency in monitoring and management
                        Monitor = Pcoop;
                        Manage = 1;  
                        
                %% PES carbon sequestration       
                    % Country: USA, State aggregate: Lake States (Miller et al.,2012)
                        Pcarbon = 1/(1 + exp(-(AT*0.1244 + Credit*0.0484 - Contractlength*0.0388 + Gender*0.9879 + Amenity*0.1284 + CO2attitude*0.1418 + IncomeAdd*0.7431 - Reside*0.7795 - TenureY*0.025 - Barriers*0.0941)));
                
                %% PES Land-sparing [US$/ha/year] 
                       
                    % Country: Finland, Region: everywhere (Layton & Siikamaki, 2009)
                    % Country: USA, State: Massachusetts (Stevens et al., 2002)                                        
                            Psign1 = 1/(1 + exp(-(PES/tlimit*0.027 - Purchased*1.2314 - TimberRights*1.5455 - RecreationAccess*0.7776 - TreeCuttingObligation*0.9729)));
                                             
                    % Country: Finland (Horne, 2006)
                        % Payment: payment for biodiversity services and compensation for welfare from timber [US$/ha/y] with average 5 years annual
                            % exchange rate usd/euro = 1.31: average compensation claimed in
                            % Finland = 293.5 US$/ha/y InitNIPF: Initiator of the contract is the owner: 1 yes, 0 no 
                            % InitState: Initiator of the contract is the State via an environmental organistation, 1 yes, 0 no
                            % RestrictSmallpatches: Restriction on forest use by protecting small patches of forest: 1 yes, 0 no Restrictmanage: Restriction
                                % on forest use by implementing Nature management plan: 1 yes, 0 no
                            % RestrictSylvi: Restriction on forest use by prohibiting sylviculture practices: 1 yes, 0 no 
                            % Contract: Duration of the conservation contract (Years), Finland no more than 10 years and
                                % can be renewed 
                            % CancelContract: Forest owner can cancel: 1 yes, 0 no
                    if Contract < inf
                        if Contract >= 5;
                            if PESInitiator == 1
                                if ManageRestric == 1
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.4626 + RestrictSmallpatches*0.46 + Contract*0.4841 + CancelContract*0.172;
                                elseif ManageRestric == 2
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.4626 + Restrictmanage*0.237 + Contract*0.4841 + CancelContract*0.172;
                                elseif ManageRestric == 3
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.4626 - RestrictSylvi*0.138 + Contract*0.4841 + CancelContract*0.172;
                                end
                            elseif PESInitiator == 2
                                if ManageRestric == 1
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.4626 + RestrictSmallpatches*0.46 + Contract*0.4841 + CancelContract*0.172;
                                elseif ManageRestric == 2
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.2503 + Restrictmanage*0.237 + Contract*0.4841 + CancelContract*0.172;
                                elseif ManageRestric == 3
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.2503 - RestrictSylvi*0.138 + Contract*0.4841 + CancelContract*0.172;
                                end
                            end
                            
                        elseif Contract >= 10; % contract lasts 10 years and can be renewed
                            if PESInitiator == 1
                                if ManageRestric == 1
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.4626 + RestrictSmallpatches*0.46 + Contract*0.4841 + CancelContract*0.172;
                                elseif ManageRestric == 2
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.4626 + Restrictmanage*0.237 + Contract*0.4841 + CancelContract*0.172;
                                elseif ManageRestric == 3
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.4626 - RestrictSylvi*0.138 + Contract*0.4841 + CancelContract*0.172;
                                end
                            elseif PESInitiator == 2
                                if ManageRestric == 1
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.4626 + RestrictSmallpatches*0.46 + Contract*0.4841 + CancelContract*0.172;
                                elseif ManageRestric == 2
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.2503 + Restrictmanage*0.237 + Contract*0.4841 + CancelContract*0.172;
                                elseif ManageRestric == 3
                                    Z = 1.7385 + (PES*1.31/tlimit)*0.0033 + PESInitiator*0.2503 - RestrictSylvi*0.138 + Contract*0.4841 + CancelContract*0.172;
                                end
                            end
                        end 
                    
                            Z5nipf_smallpatch = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.4626 + 1*0.46 + 1*0.4841 + CancelContract*0.172;
                            Z5nipf_manage = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.4626 + 1*0.237 + 1*0.4841 + CancelContract*0.172;
                            Z5nipf_silvi = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.4626 - 1*0.138 + 1*0.4841 + CancelContract*0.172;
                            Z5state_smallpatch = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.4626 + 1*0.46 + 1*0.4841 + CancelContract*0.172;
                            Z5state_manage = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.2503 + 1*0.237 + 1*0.4841 + CancelContract*0.172;
                            Z5state_silvi = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.2503 - 1*0.138 + 1*0.4841 + CancelContract*0.172;
                    
                            Z10nipf_smallpatch = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.4626 + 1*0.46 + 1*0.286 + CancelContract*0.172;
                            Z10nipf_manage = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.4626 + 1*0.237 + 1*0.286 + CancelContract*0.172;
                            Z10nipf_silvi = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.4626 - 1*0.138 + 1*0.286 + CancelContract*0.172;
                            Z10state_smallpatch = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.4626 + 1*0.46 + 1*0.286 + CancelContract*0.172;
                            Z10state_manage = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.2503 + 1*0.237 + 1*0.286 + CancelContract*0.172;
                            Z10state_silvi = 1.7385 + (PES*1.31/tlimit)*0.0033 + 1*0.2503 - 1*0.138 + 1*0.286 + CancelContract*0.172;
                    
                            SumZ = Z5nipf_smallpatch + Z5nipf_manage + Z5nipf_silvi ... 
                                + Z5state_smallpatch + Z5state_manage + Z5state_silvi ...
                                + Z10nipf_smallpatch + Z10nipf_manage + Z10nipf_silvi ...
                                + Z10state_smallpatch + Z10state_manage + Z10state_silvi;
                            
                            Psign2 = exp(Z)/(1 + exp((SumZ)));
                            
                            Sparing = mean([Psign1 Psign2]);
                       
            % Expected proportion of the landowner forest land subject to conservation, for a given Payment for
                        % Ecosystem Services "PES" (Euro, lump-sum), and for a given Contract duration Contract" [Year]: 
                % Country: Finland, Region: everywhere (Layton & Siikamaki, 2009)
                            vit = exp(-6.346 + ln(PES)*0.43 - ln(Contract)*0.507);
                            wit = exp(-25.131 - 0.55*SetAside - Residence*0.576 + Farmer*1.753 + Gender*0.549 - IncomeHH_NF*0.737 - Age*2.584 * EducHH_F*1.533 + DegreeDays*3.063);
                            Acons = vit/(vit + wit);
                    
                    elseif Contract == inf
                        %% Intro: Perpetual Conservation easement (selling) = perpetual payment for ecosystem services
                                % The easement holder has a responsibility to monitor future uses of the land to ensure compliance with the terms of the easement and to enforce the terms if a violation occurs.
                                % We assume that the easement put economic constraints such
                                % that harvesting is rendered economically infeasable. However, in
                                % non-industrial "working forests" an easement frequently
                                % forbid only the 
                
                        % Country: USA, State: Massachusetts (Ma & Kittredge, 2011):               
                            % Assume CoopNeighbours as continuous, rather than dummy variable
                                CoopNeighbours = Pcoop;                     
                            % Trail: concidered putting a trail through the forest land in the past five years
                                Trail = 1;
                            % Green: Continuous- higher value indicates a stronger environmentally and socially responsible attitude toward forest land. % sum of Mean values of PCA components in Table 1
                                if EnvProtec == 1 && wildlife == 1 
                                    Green = 19.22;  
                                elseif (EnvProtec == 1 && wildlife == 0) || (wildlife == 1 && EnvProtec == 1)
                                    Green = 19.22/2; 
                                elseif EnvProtec == 0 && wildlife == 0
                                    Green = 0;
                                end
                                if AgeHH >= 30
                                    Age3050 = 1;
                                    Age5165 = 0;
                                    Age65plus = 0;
                                elseif AgeHH >= 50
                                    Age3050 = 0;
                                    Age5165 = 1;
                                    Age65plus = 0;
                                elseif AgeHH >= 65
                                    Age3050 = 0;
                                    Age5165 = 0;
                                    Age65plus = 1; 
                                end
                    
                                Psell_ns = 1/(1 + exp(-(- Age3050*0.999 - Age5165*0.998 - Age65plus*0.988 + AccessRoads*0.135 + CoopNeighbours*0.213 + Green*0.064))); % Unengaged in management programs: Probability that the objective is freezing land for conservation  = - 0.009 for Owners 
                                Psell_s1 = 1/(1 + exp(-(- Age3050*0.996 - Age5165*1 - Age65plus*0.982 + AfT*0.156 + CoopNeighbours*0.338))); % Engaged owners: Probability that the objective is freezing land for conservation = 0.156 
                            % Country: USA, State: Vermont (LeVert et al., 2009)
                                Coop = Pcoop; % assume linear rather than dummy variable
                                Psell_s2 = 1/(1 + exp(-(-3.4685 + log(PES*2.47105)*0.2608 + EducHH*0.2566 - Coop*0.2603 + Green*0.6143 + Recreation*0.2173 - MPW*0.2157 - Manage*0.1811 + Absentee*0.4145)));
                            % Country: USA, State: Massachusetts + Vermont (LeVert et al., 2009)    
                                Psell_s3 = 1/(1 + exp(-(-3.4685 + 0.7551 + log(PES*2.47105)*0.2608 + EducHH*0.2566 - Coop*0.2603 + EnvProtec*0.6143 + Recreation*0.2173 - MPW*0.2157 - Manage*0.1811 + Absentee*0.4145)));
                            % Average
                                Psell_s = mean([Psell_s1 Psell_s2 Psell_s3]);
                            % Global probability of selling and sparing the land
                                Sparing = Psign*Psell_s + (1 - Psell_s)*Psell_ns;
                    end
                    
                    %% PES coordinated neighboor management programs: NIPF landowner already enrolled with the state, probability to be engaged coordinated management programs, i.e. State provides incentives for cooperation with neighbours
                                
                        % Country: USA, State aggregate: New England (Klosowski et al., 2001)
                            if IncomeHH >= 50000
                                IncomeHH1 = 1;
                                IncomeHH2 = 0;
                            elseif IncomeHH < 50000
                                IncomeHH1 = 0;
                                IncomeHH2 = 1;
                            end 
                            if Contract >= 10
                                Contract = 10;
                            elseif Contract >= 20
                                Contract = 20;
                            end
                            
                            Pcoord = 1/(1 + exp(-(Taxgain/tlimit*0.00112 - Harvloss/tlimit*0.00101 - Contract*0.0621 - IncomeHH1*1.7 - IncomeHH2*1.175)));
                            Connect = Pcoop*(1 - Pcoord)*Psilvi + Pcoop*Pcoord*1;  
                   
                %% Probability selling timber for the next 5 years if owners engaged with State                
                    % Country: USA, State: Massachusetts (Ma & Kittredge, 2011)
                        if AgeHH >= 30
                            Age3050 = 1;
                            Age5165 = 0;
                            Age65plus = 0;
                        elseif AgeHH >= 50
                            Age3050 = 0;
                            Age5165 = 1;
                            Age65plus = 0;
                        elseif AgeHH >= 65
                            Age3050 = 0;
                            Age5165 = 0;
                            Age65plus = 1; 
                        end
                
                        if EducHH <= 15
                            Highschool = 1;
                            Graduatecollege = 0;
                        elseif EducHH >= 15
                            Highschool = 0;
                            Graduatecollege = 1; 
                        end
                        Ptimber = 1/(1 + exp(-(- Age3050*0.999 - Age5165*0.999 - Age65plus*0.998 + Highschool*0.17 + Graduatecollege*0.225 + Profres*0.082 - Amenity*0.083)));
                                                   
            
        
        
        elseif Tenure == 2 % Community ownership
                %% PES: Move to contract for payment for ecosystem services with caps defined by the State (CPES) 
                    % Introduction - 
                        % Protection and management practices include regulation of
                        % on grazing, fire, and extraction of forest products,
                        % selective retention of tree species and silvicultural
                        % operations, mixed species enrichment plantations,
                        % hardwood ...                    
                
                    %% PES carbon: Probability to joint Carbon-sequestration scheme CSC  
                        % Country Mozambique, Province: Sofala (Jindal et al., 2012): with
                            % $4.5/tCO2 paid to each farmer in the community (multiply 3.667 to convert C to CO2 tonnage/ha ~ $400-$800/ha/7years)
                            check paper whether the forest is managed by the community or whether it is on private lands
                            Pcarbon = 1/(1 + exp(-(PeopleHH*0.29 - IncomeHH*0.0008 + IncomeExt*0.0009 - Migration*1.32 - DistanceF*19.01)));
                
                    %% PES Conservation: Probability of signing Participatory forest management with the State (PFM) on the native community forest
                        % Country: India, State: Andhra Pradesh, CES Scheme: Joint forest Management (Behera, 2010)
                            % (Joint Forest Management communities JFM) of "Village forests" between local
                            % communities and the State to stimulate afforestation of degraded forests (i.e., <40% crown density).
                            % JFM involved the creation of village-based forest committees, known variously as forest
                            % protection committees (FPC) or Van Suraksha Samitis (VSS). 
                            % Payment rewards for Environmental Services (P/RES): not a CES
                            % programme per se, but has main elements of CES. 
                            % usufructuary right to items and fodder, fuelwood, loppings
                            % and minor forest products. A share in the proceeds from the
                            % sale of trees when they mature. Poor and landless given
                            % preference. Returns from the sale of surplus forest products,
                            % keeping 25% to Village Development Fund (VDF), shared equally
                            % between members. 75% of the VDF spent on those who last
                            % access to forest due to JMF implementation. Activities such
                            % as steps for inducement of natural regeneration, seeding,
                            % soil conservation methods, fire protection, maintenance of
                            % boundaries, weeding, tending, thinning, etc ... no rights over
                            % land. No grazing of agriculture is allowed on the site.
                    
                            % Parameters
                                %Forestvalue = 1;
                                %Access = 1;
                            % VARIABLES
                                %logscarcity = NumberHH*SizeHH/AfT; % log of population per hectar of JFM forest
                                %logpop = logscarcity*AfT;
                            % Equation
                                %Forestgrowth = 1/(1 + exp(-(-logpop*1.527 - logscarcity*94.941 + Forestvalue*2.566 + Access*2.209)));
                        % Country: Indonesia, Province: Jambi, Village forest: Rubber agrobiodiversity, CES Scheme: (Villamor et al., 2011): Villamor, G., Q.B. Le, P.L.G. Vlek and M. van Noordwijk, Payments for agro-biodiversity: An analysis of participation in Jambi's conservation agreements for rubber agroforests, (Sumatra) Indonesia, 13th Annual BIOECON Conference on Resource Economics, Biodiversity Conservation and Development, Geneva, 2011.
                            % ConsAct: 1 = yes, 0 = no, Participation in P/RES scheme: planting clonal rubber seedlings significantly influences the probability of adopting the  
                                % Parameters
                                                      
                                % VARIABLES
                                PercentRice = 1 - DependforestHH;
                                if Pconsact < 0.5  % refer to D.1.1
                                    ConsAct = 0;
                                else
                                    ConsAct = 1;
                                end
                            % Equation    
                                Ppes_cons1 = 1/(1 + exp(-(SizeHH*1.247 - AgeHH*0.192 - SizeRice*2.285 - AfT*0.392 - PercentRice*0.167 + ConsAct*0.847)));
                        % Country: Tanzania, 'Community Based forest management' (CBFM) on 'community/village land' (Lokina et al., 2008) - Lokina, Razack B., Robinson, Elizabeth J.Z., and Eggert, H., 2008. Determinant of the effectiveness of participatory forest management in Tanzania, presented at the European Association of Environmental and Resource Economists, Gothenburg, Sweden, June.
                            % CBFM takes place on village land  or private land, and the 
                            % trees are owned and managed by either a village 
                            % council (through a village natural resource committee), 
                            % a group, or an individual. Most of the costs and benefits 
                            % relating to management and utilization are carried by the owner. 
                            % The role of central government is minimal  and districts only
                            % have a role in monitoring.
                                %Ppfm2 = ;
                        % Average
                            Pcons = mean([Ppes_cons1]);                            
            
            
        elseif Tenure == 3 %% State-owned forests
            
            %% PES Carbon: (Probability to joint CSC)
                Pcarbon = 1; % Assume obligation of forest users to join the scheme on non-industrial forest plantations  
        
            %% PES Conservation    
                %% Decentralized Concession Forest (decentralized decision making)
            
                    % D.3.1 - Probability of signing a centralized contract for sustainable management of forests
                        % Country: Bangladesh, Provinces: Sal forests covering Dhaka, Tangail, and Mymensingh (Salam, Noguchi & Alim, 2006; Salam, Noguchi & Koike, 2005)
                            % in Centralized concession forests in Bengladesh, decisions regarding silvicultural activites, choice of species planted, curring regime ... are made by the forest department without any participation of local stakeholders.
                            % EducHH: [in schooling years: average = 5 years]        
                            % SUST: is dummy variable indicating whether or not the participating farmer agrees with the statement PFM is sustainable under the present state of management. If in agreement, SUST = 1 (60.4%) and 0 otherwise;
                            % KNOW: is dummy variable indicating whether or not the participating farmer had knowledge of the strategies of the PFM. If yes, KNOW = 1 (62.8%) and 0 otherwise;
                            % GOOD: is dummy variable indicating whether or not the participating farmer agrees with the statement PFM is a good step for conserving forests. If in agreement, GOOD = 1 (70.4%) and 0 otherwise.
                            % ABSS: a dummy variable indicating whether the farmer agrees with the benefit-sharing system or not; yes = 96%
                            SUST = 1;
                            KNOW = 1;
                            GOOD = 1;
                            ABSS = 1;                    
                            GTFF = 1/(1 + exp(-((IncomeHH/12)*10^-4 + EducHH*0.073 + TFAT*1.172  + SUST*1.379 - KNOW*1.887 + GOOD*1.584)));
                            Pcons_c = 1/(1 + exp(-(-4.512 + GTFF*2.046 + SSP*0.461 + Training*0.789 + FBRH*1.343 - ABSS*2.264 - APC*0.733 - RAFD*0.666)));
                          
                    % D.3.2 - Probability of moving from centralized to decentralized system
                        % Country: Nepal, Region: Mid-West (Sakurai et al., 2004) [Probit]                    
                            X = BrahminHH*0.05 + MaleHighschoolGrad*0.05 - FemaleHighschoolGrad*0.19 - DistanceMarket*0.01;
                            Xmax = 1*0.05 + 1*0.05 - 0*0.19 - 0*0.01;
                            Xmin = 0*0.05 + 0*0.05 - 1*0.19 - 1*0.01;
                            Xmean = (Xmax + Xmin)/2;
                            Xsd = (Xmax - Xmin)/6; % assume 100 rep
                            Pdecentralized = 1 - normcdf(X,Xmean,Xsd);  
                            Pcentralized = normcdf(X,Xmean,Xsd);
                    
                    % D.3.3 - Probability of signing a contract of sustainable management        
                        % Country: Indonesia, Province: Lampung (Arifin et al., 2009) 
                            % Assets2000: total assets owned [million Rp]
                            % Contract35: lenght of main contract is 35 years
                            % Variables
                            if minTreedensity >= 400
                                minTreedensity800 = 0 ; % 800 min tree density per ha
                                minTreedensity600 = 0 ; % 600 min tree density per ha
                                minTreedensity400 = 1 ; % 400 min tree density per ha (Baseline contract)
                            elseif minTreedensity >= 600
                                minTreedensity800 = 0 ; % 800 min tree density per ha
                                minTreedensity600 = 1 ; % 600 min tree density per ha
                                minTreedensity400 = 0 ; % 400 min tree density per ha (Baseline contract)
                            elseif minTreedensity >= 800
                                minTreedensity800 = 1 ; % 800 min tree density per ha
                                minTreedensity600 = 0 ; % 600 min tree density per ha
                                minTreedensity400 = 0 ; % 400 min tree density per ha (Baseline contract)
                            end
                            if AccessFees == 0
                                Fees36Kyr = 0;
                                Fees72Kyr = 0;
                            elseif AccessFees == 1
                                Fees36Kyr = 1;
                                Fees72Kyr = 0;
                            elseif AccessFees == 2
                                Fees36Kyr = 0;
                                Fees72Kyr = 1;
                            end 
                                Pcons_d = 1/(1 + exp(-(Contract35*1.454 + TreeCuttingRight*0.803 + minTreedensity400*0 - minTreedensity800*1.033 - minTreedensity600*0.637 - Fees36Kyr*0.933 - Fees72Kyr*1.164 + AccessServicesInputs*0.863 + AccessRoads*0.383 - AccessAssistance*0.496)));
                                Pcutting = 0.7; % 30% of timber trees (hard/heavy timber) replanted cannot be cut
                                
                                
                                
                                % Country: Tanzania, 'Joint forest Management' on 'reserved
                            % land' owned by national or local governments (Lokina et
                            % al., 2008) - Lokina, Razack B., Robinson, Elizabeth J.Z., and Eggert, H., 2008. Determinant of the effectiveness of participatory forest management in Tanzania, presented at the European Association of Environmental and Resource Economists, Gothenburg, Sweden, June.
                            Pcons = Pcentralized*Pcons_c + Pdecentralized*Pcons_d;                    
                 
                CuttingIntensity = *387/283; % Country:Nepal, Western Region (Sakurai et al., 2004) - Ratio of Gross profit Centralized/decentralized for timber harvesting
                Pcentralized*            
                TreeCuttingRight
                minTreedensity
                % DCF: Decentralized community forest = Decentralized Concession Forest: concession for the use of "National forests" and "Protected forest areas" are allocated to local community (e.g., Hutan Tanaman Rakyat HTR model in Indonesia, Joined Forest management JFM in India)
                    Harvesting = 1;
                % CCF: Centralized community forest
                    Harvesting = 2; % CCF, 0:no harvest, 1:medium intensity, 2:high intensity
            if SubTenure == 2
            %% Carbon sequestration (Probability to joint CSC)
                Pcss = 1; % Assume obligation of forest users to join the scheme on non-industrial forest plantations  
            %%  Setting aside conservation zone IUCN Criteria I-IV (land sparing)                
                Access = 0;         
            end        
                  
        elseif Tenure == 4 % no clear land-tenure
                    Pcarbon = 0;
                    Pcons = 0;
                    
        end % Tenure
    end % Axis 3
end  % Function
    
   
%% PROVISIONNING SERVICES

    
        
    
            
                
            % % D.1.1 - Forest level 
        % decision probability of harvesting the total forest stock 100%, or harvesting selectively/partially  (<100% of the area for different types of timber
            if HarvestIntens == 1 
                Intensity = 1;
                % Country: USA, States aggregate: South AL,FL,GA,NC,TN,VA (Polyakov et al., 2010, Table 1: median of all significant parameters between seven states)    
                %if governance == 1 % Community: asumption on the value
                    %Owner = 0.5;
                %elseif governance == 2 % state
                    %Owner = 1;
                %elseif governance == 3 % NIPF
                    %Owner = 0;
                %end                         
                %MPS = 1/(1 + exp(-(-3.5398 + Revenue*Afi*0.0013 - Owner*1.2595 - Diversity*0.4515 + Remeasure*1.0977)));
                %NS = 1/(1 + exp(-(-3.7623 + Revenue*Afi*0.0006 - Owner*1.2595 - Diversity*0.4515 + Remeasure*1.0977)));
                %FGM = 1/(1 + exp(-(-4.1080 + Revenue*Afi*0.0005 - Owner*1.2595 - Diversity*0.4515 + Remeasure*1.0977)));
                %UH  = 1/(1 + exp(-(-4.4656 + Revenue*Afi*0.00085 - Owner*1.2595 - Diversity*0.4515 + Remeasure*1.0977)));
                %LH  = 1/(1 + exp(-(-4.8019 + Revenue*Afi*0.0006 - Owner*1.2595 - Diversity*0.4515 + Remeasure*1.0977)));
                %Choice = [FGP FGN FGM UH LH]';              
               
            elseif HarvestIntens == 2 
            
            % Country: USA, States aggregate: South AL,FL,GA,NC,TN,VA (Polyakov et al., 2010, Table 1: median of all significant parameters between seven states)    
                %if governance == 1 % Community: asumption on the value
                    %Owner = 0.5;
                %elseif governance == 2 % state
                    %Owner = 1;
                %elseif governance == 3 % NIPF
                    %Owner = 0;
                %end           
                %FGP = 1/(1 + exp(-(-3.2691 + Revenue*0.0013 - Owner*1.4456 + Diversity*0.6802 + Remeasure*1.1022)));
                %FGN = 1/(1 + exp(-(-3.9683 + Revenue*0.0006 - Owner*1.4456 + Diversity*0.6802 + Remeasure*1.1022)));
                %FGM = 1/(1 + exp(-(-4.3372 + Revenue*0.0005 - Owner*1.4456 + Diversity*0.6802 + Remeasure*1.1022)));
                %UH  = 1/(1 + exp(-(-4.6569 + Revenue*0.00085 - Owner*1.4456 + Diversity*0.6802 + Remeasure*1.1022)));
                %LH  = 1/(1 + exp(-(-5.2927 + Revenue*0.0006 - Owner*1.4456 + Diversity*0.6802 + Remeasure*1.1022)));
                %Choice = [FGP FGN FGM UH LH]'; 
            end
            
            
            
            % Total probability of selling timber
                Psell = Pifp*Sell;
                
        
    
   
        
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% Other harvesting activities and revenues from forest lands

    % NTFP
    
        % Tapping trees for resin or latex
        % Harvesting seeds
        % Harvesting bark (Unbarking)
        % Harvesting leaves    
        % harvesting litter (fuel)  
    
    % LAND BANKING:
    % Decision 1: Probability of selling the land for development    
        %if Governance == 3
            % Country: USA, State: Massachusetts (Ma & Kittredge, 2011)
            %Psell = 1/(1 + exp(-(-0.028*AT + 0.131*Invest + 0.152*Landpay - 0.159*Amenity)));
        %elseif Governance == 4
            % Country: USA, State: Massachusetts (Ma & Kittredge, 2011)
            %Psell = 1/(1 + exp(-(Landpay*0.126 + Invest*0.135 - Tenure*3.44 - Amenity*0.074)));
        %end 
        % Category of investment: Continuous-higher value [1 - 5] indicates higher
        % importance of the land as an investment (land banking)
        %if Psell >= 0
            %Invest = 1;
        %elseif Psell >= 0.2
            %Invest = 2;
        %elseif Psell >= 0.4
            %Invest = 3;
        %elseif Psell >= 0.6
            %Invest = 4;
        %elseif Psell >= 0.8
            %Invest = 5;
        %end    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% REFERENCES
% Baker, J. M. (1998). The effect of community structure on social forestry outcomes: insights from Chota Nagpur, India. Mountain Research and Development, 51-62.
% Naidu, S. C. (2011). Access to benefits from forest commons in the Western Himalayas. Ecological Economics, 71, 202-210.