function [Dollar,Stimber,Ntimber,N,BNdebris,Pharvest,T] = Harvesting(Access,Pselltimber,Hselection,Farea,PFTs,s,height,nPFTS,TDmean,N,BNdebris,T, Random)
  
Parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Inputs 
% MPS: Monospecific plantation Softwood   (e.g., Pine plantation)
% NS: Natural forest Softwood
% UH: Upland hardwood
% LH: Lowland hardwood
% Diversity: Shannon tree diversity index
% Revenue: discounted revenue / Vol timber / ha
% Owner: dummy, 1 if public, or 0 if NIPF.
% Slope: proxi for harvesting costs (slope or hydricity of the soil).
% Assume Slope = 0
% Remeasure: log of the remeasurment period (average 5 years)
% Detectionlevel: [1-10[ Level of detection for saliance of LMA between species: Perfect detection == 1, 10 is no discrimination of LMA values between species
% Landscape: gives the ((Nstand x numberHH) x (Nstand x numberHH)) matrix with diagonal of 0/1 for defining the stands where timber can be harvested
TD = ones(size(height,1),1)*PFTs(:,1)';
SM = ones(size(height,1),1)*PFTs(:,3)';

%%   Outputs

%%   Asumptions
% We assume harvesting needs are the same between governance structures
% Timber extraction rules are based on USA timber market demand, as this is the most comprehensive world dataset freely available so far
% valuable tree stands are shown as valuable irrespective of extraction cost (distance to market, roads, etc ...)
% Only 35% of the raw timber extracted is effectively transformed into sawn
% wood (
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Initial conditions
% Populate inputs

[Bt,Bl,Bbr,Btr,~,~,~,Bfr,Bcr,~,~,~,~,~] = Allometry(PFTs,height,s,0);


% Build Adult Biomass matrix
Babove = N(2:size(N,1),:).*Bt.*1.06./2.06; %  based on the WBE model: Niklas,2005 (Annal of Botany); Cheng & Niklas,2007 (Annal of Botany) .

for i = 1:nPFTS
    Babove(Babove(:,i) < max(Babove(:,i))) = 0;
end

Badult = Babove./10^3.*10^4;   %[tonnes/ha]

%%  Timber extraction (the extraction rules are based on nipf owners from the USA: only comprehensive source of data available)
%   D.1 - Matrix of selection for harvest
HBadult = sum(sum(Badult)); %sum(sum(Badult).*Hselection);

%   D.2 - Fraction of stands harvested: Decision made after the decision  of partial/no/total harvest at a property level is made,
%       - Country: USA,State aggregate (12): Maine, New-York, New England, Michiga, Pennsylvania, Maryland, Wisconsin, Illinois, Indiana, Ohio, Kentucky, Virginia (Canham et al., 2013)
%           see timber density of species: http://www.wood-database.com/wood-identification/
%           Partial harvest (reduce basal area but dbh and age class do not change) or Selective harvest of PFT. We assume no distinction here.
%       - Assume: spruce fire forest ~ 450kg/m3, Oak forest ~ 750kg/m3,
%           Aspen/Birch forest ~ (450+670)/2kg/m3, Northern Hardwood ~
%           maple + yellow birch + American Beech dominated ~ (675+670+800)/3kg/m3
a1 = 1;
b1 = -0.0019.*TDmean + 1.846; % R2 = 0.575
m1 = 2E-5.*TDmean - 0.0071;   % R2 = 0.726


Pharvest = 1 - a1.*exp(-m1.*HBadult.^b1).^T;

display(Pharvest)

if Pharvest < 0.95 % Probability of harvesting is lower than 0.95 (could change setting 0.95 < Pharvest < 1)
    Ntimber = zeros(size(N,1)-1, size(N,2));
    Btimber = Ntimber.*Btr;
    Stimber = Access*Farea*Btimber; % Probability of harvesting equal 1    
elseif Pharvest >= 0.95    
    %   D.3 - Average percentage of basal area harvested per stand
    %           Once the harvesting probability of every stand is known, what is the intensity of harvesting the stand, given the above ground biomass of the stand (or stand basal area) for a given census interval T [year] :
    %       - Country: USA,State aggregate (12): Maine, New-York, New England, Michiga, Pennsylvania, Maryland, Wisconsin, Illinois, Indiana, Ohio, Kentucky, Virginia (Canham et al., 2013)
    %           see timber density of species: http://www.wood-database.com/wood-identification/
    
    b2 = -0.003.*TDmean + 2.44;   % R2 = 0.985
    m2 = 0.0007.*TDmean - 0.33;     % R2 = 0.559
    a2 = 114.48.*m2 + 40.897;    % R2 = 0.21
    b2(b2>1) = 1;
       
    BAR = a2.*exp(-m2.*Badult.^b2); % Percentage of Basal Area Removed from plot
    
    %   D.4 - Species-level preference: probability that a given species is selected, given the basal area removed.
    Hselmat = repmat(Hselection,size(N,1)-1,1); % vertical stack of copies of Hselection.
    
    if Random == 1
      alpha = (0.1161+0.08*(2*rand(1)-1)).*(log(SM)) + (2.9817+0.85*(2*rand(1)-1)); %R2 = 0.3496: based on data from (Canham et al., 2013) in combination with SM data from http://www.feis-crs.org/beta/ and other sources; other choice less good: 0.0015.*ones(size(height,1),1)*TD' + 0.8883;
      beta = (0.5012+0.45*(2*rand(1)-1)).*exp((-3.447+0.37*(2*rand(1)-1)).*alpha); %R2 = 0.8228, based on data from (Canham et al., 2013)
      gamma = (-0.0953+0.03*(2*rand(1)-1)).*alpha + (1.0985+0.05*(2*rand(1)-1)); %R2 = 0.7413, based on data from (Canham et al., 2013); other relation but less good: -0.0001.*ones(size(height,1),1)*TD' + 1.0107;    
    elseif Random == 0
      alpha = 0.1161.*(log(SM)) + 2.9817; %R2 = 0.3496: based on data from (Canham et al., 2013) in combination with SM data from http://www.feis-crs.org/beta/ and other sources; other choice less good: 0.0015.*ones(size(height,1),1)*TD' + 0.8883;
      beta = 0.5012.*exp(-3.447.*alpha); %R2 = 0.8228, based on data from (Canham et al., 2013)
      gamma = -0.0953.*alpha + 1.0985; %R2 = 0.7413, based on data from (Canham et al., 2013); other relation but less good: -0.0001.*ones(size(height,1),1)*TD' + 1.0107;    
    endif
    
    Plogg_s = 1 - gamma.*exp(-beta.*(BAR).^alpha); %./(Hselmat);
    Plogg_s(Plogg_s>1) = 1;
    Plogg_s(Plogg_s<0) = 0;
    
    %   D.5 - Tree-level preference: percentage of each size-class logged for every type of species (PFTS).
    %       - Country: USA,State aggregate (12): Maine, New-York, New England, Michiga, Pennsylvania, Maryland, Wisconsin, Illinois, Indiana, Ohio, Kentucky, Virginia (Canham et al., 2013)
    %           see timber density of species: http://www.wood-database.com/wood-identification/
    if Random == 1
      mu = (1.0581+0.77*(2*rand(1)-1)).*(log(SM)) + (54.78+3.68*(2*rand(1)-1));   % R2 = 0.3447: based on data from (Canham et al., 2013) in combination with SM data from http://www.feis-crs.org/beta/ and other sources
    elseif Random == 0
      mu = 1.0581.*(log(SM)) + 54.78;   % R2 = 0.3447: based on data from (Canham et al., 2013) in combination with SM data from http://www.feis-crs.org/beta/ and other sources
    endif
  
    dbh = height.^(1/alpha9)./beta9^(1/alpha9); 
    c = 1;
    Plogg_t = (exp(- 0.5.*((dbh - mu)./(a2 + b2.*BAR.^c)).^2));    
    Plogg_t(Plogg_s>1) = 1;
    Plogg_t(Plogg_s<0) = 0;
    
    %   D.6 - Global decision and supply: Aggregate Supply Model
    Plogg = Plogg_s.*Plogg_t.*Hselmat;
    Ntimber = Access*Pselltimber*(N(2:size(N,1),:).*Plogg);
    N(2:size(N,1),:) = N(2:size(N,1),:) - Ntimber;
    Btimber = Ntimber.*Btr; %multiply by ~ 2 to get total dry mass from dry mass of carbon
    BNdebris(:,:,1) = BNdebris(:,:,1) + Ntimber.*Bl;
    BNdebris(:,:,2) = BNdebris(:,:,2) + Ntimber.*Bbr;    
    BNdebris(:,:,5) = BNdebris(:,:,5) + Ntimber.*Bcr;
    BNdebris(:,:,6) = BNdebris(:,:,6) + Ntimber.*Bfr; 
    
    Stimber = Access*Farea*Btimber;    
    T = 0; % flush what has been harvested
end




%%  Fruit Collection

%%  Taping Latex

%%  Barking

%%  Economic Benefit from harvesting ($)
%       Cite 
if Random == 1
  Dollar = sum(sum(((0.65+0.1*(2*rand(1)-1)).*TD).*Stimber./TD));
elseif Random == 0
  Dollar = sum(sum((0.65.*TD).*Stimber./TD));  
end

end

% REFERENCES
% Canham, C. D., Rogers, N., & Buchholz, T. (2013). Regional variation in forest harvest regimes in the northeastern United States. Ecological Applications, 23(3), 515-522.