%============================================================================================%
% IVM: INDIVIDUAL VITAL MODEL
%      Estimate the vital rates from photosynthetic absorbtion of the trees
%==========================================================================


function [Ssg,Sk,Gxy,Fk,Tl,Tfr,Tb,Wup,Phi_net] =IVM(dEdz,Climate,Water,PFT,N,smax,n,Phi_net,hsg,hmat,hbymin,sg,s)

%   Populate necessary parameters and vectors of initial conditions
Parameters;
Ssg  = zeros(1,n);
Sk  = zeros(smax,n);
Gxy = zeros(smax,n);
Fk  = zeros(smax,n);
Tl  = zeros(smax,n);
Tfr  = zeros(smax,n);
Tb  = zeros(smax,n);
Wup  = zeros(smax,n);
P   = zeros(smax,n);
CO2 = Climate(:,1);
Qt  = Climate(:,2);
Qts = Climate(:,3);
Tc  = Climate(:,4);
VPa = Climate(:,6);
tmax=size(Qt,1);
STD = zeros(1,n);
LMA = zeros(1,n);
Ssize = zeros(1,n);
A = zeros(smax,n,tmax);

for i = 1:n
    STD(1,i) = PFT((i-1)*3+1,1);
    LMA(1,i) = PFT((i-1)*3+2,1);
    Ssize(1,i) = PFT((i-1)*3+3,1);
end  

%	
if sg ==0       %  Deal with trees: Size classes for all the PFTS present in the forest (mid-point rule)
	vec = ones(n,1)*(hbymin.*[1:smax-1]);
	hsgt = (hsg(:,1)+.5.*hbymin)*ones(1,smax);
	hsize = cat(2,zeros(n,1),vec);
	height  = (hsgt+hsize)';
elseif sg == 1   %  Deal with seedlings: Size classes for all the PFTS present in the forest (mid-point rule)
	height  = hsg';
end
%   	Populate biomass for all size classes
	[Bt,Bl,~,~,~,Bb,~,Bfr,~,LA,~,~,~,~] = Allometry(PFT,height,s);

%   Starting integration over 

for sh=1:smax
    if sg == 0
    if sum(sum(N(sh+1:smax+1,:),1)) == 0
        break
    end 
    end
    s = 10;  % for integration over 10 sub-size classes up to sh         
    Phinet(:,:) = Phi_net(sh,:);
    dPhi_O = zeros(1,n);
    dPhi_c = zeros(1,n);    
    q      = zeros(s,n);

    for t=1:tmax      
        
        %   Flux of photon within the canopy < sh [mol.m^-2[photon].s^-1] (assume same below sh to approx Falster et al., 2011)
            Qz  = Qt(t,1)*dEdz(sh,1);   % Total irradiance
            Qsz = Qts(t,1)*dEdz(sh,1);  % Short wave only (to estimate leaf temperature)

        %   Carbon concentration in atmosphere (Catm), intercell (Cint) and in the carboxilation chamber (Ccarb)
            Cint   = CO2(t,1)*0.8;      %  Poorter & Farquhar, 1994 (Austr. J Plant. Physiol) -
            Ccarb  = Cint*0.7;          %  Ccarb (carboxylation) is lower than Cint
   
        for z  = 1:s
            
            if sg == 0
                %  2nd integration mid-point rule: xzz = [hsg+.5*((height-hsg)/s),hsg+.5*((height-hsg)/s)+((height-hsg)/s)*[1:s-1]]';  
                dvec  = (((height(sh,:)'-hsg)./s)*[1:s-1]);            
                dhsgt = (hsg+.5*((height(sh,:)'-hsg)/s))*ones(1,s);            
                dhsize = cat(2,zeros(n,1),dvec);
                xzz  = (dhsgt+dhsize)'; 
            elseif sg == 1
                 %  2nd integration mid-point rule: xzz= [hsg+.5*((height-hsg)/s),hsg+.5*((height-hsg)/s)+((height-hsg)/s)*[1:s-1]]';  
                dvec  = (((height(sh,:)')./s)*[1:s-1]);            
                dhsgt = (.5*((height(sh,:)')/s))*ones(1,s);            
                dhsize = cat(2,zeros(n,1),dvec);
                xzz  = (dhsgt+dhsize)';
            end

            %   Leaf temperature Tlc [C]: simple leaf energy balance equation (Moorcroft et al., 2001) or 21.4 on average
                Phiconv = 38.4;                        %   Governs the rate of convective cooling [J/m2/s/K]
                lhv = (2.50084-0.00234*real(Tc(t,1)))*10^6;  %   Latent heat of water vaporization [J/Kg of water]
                PhiKg = Phinet.*10E-6*18.01528E-3;     %   Convert Phi_net [micromol H2O] into [Kg HeO]
                Tlc = (Qsz - lhv.*PhiKg)./Phiconv + real(Tc(t,1));
                Tlc = real(Tlc);
             
            %   Michaelis-Menten coefficient for C02 (K1) and 02 (K2)
                K1     = 1.5E-4.*exp(6000.*(1/288.2-1./(Tlc+273.2)));	   % Moorcroft et al., 2001
                K2     = 0.836.*exp(-1400.*(1/288.2-1./(Tlc+273.2)));     % Moorcroft et al., 2001
                %Ko    = 278.4*exp(36380*(Tl-298)/(298*Rgas*Tl));      % Meydlin et al., 2002
                %Kc    = 404.9*exp(79430*(Tl-298)/(298*Rgas*Tl));      % Meydlin et al., 2002

            %   Tau: Co2 compensation point
                Tau    = 2.12E-5.*exp(5000.*(1./288.2-1./(Tlc+273.2)));

            %	Optimal Temperature for Rubisco and RuBP
                %Toptv  = Hdv/(Sv-Rgas*log(Hav/(Hdv-Hav)));           % Meydlin et al.,2002
                %Toptj  = Hdj/(Sj-Rgas*log(Haj/(Hdj-Haj)));            % Meydlin et al., 2002

            %   Maximum capacity of Rubisco
                Vcmax   = 12.5.*exp(3000.*(1./288.2-1./(Tlc+273.2)))./((1+exp(0.4.*(5-Tlc))).*(1+exp(0.4.*(Tlc-45))));
                %Vcmax  = k25v*(Hdv*exp(Hav*(Tl-Toptv)/(Tl*Rgas*Toptv))/(Hdv-Hav*(1-exp(Hdv*(Tl-Toptv)/(Tl*Rgas*Toptv)))));   % Meydlin et al., 2002

            %   Maximum capacity of RuBP
                %Jmax   = k25j*(Hdj*exp(Haj*(Tl-Toptj)/(Tl*Rgas*Toptj))/(Hdj-Haj*(1-exp(Hdj*(Tl-Toptj)/(Tl*Rgas*Toptj)))));

            %   Photosynthesis demand when stomata are closed
                Ac = - 0.02.*Vcmax;

            %   Rubisco activity CO2 limited rate of photosynthesis
                Jc = Vcmax.*(Ccarb.*10^-6-Tau)./(Ccarb.*10^-6+K1.*(1+K2));        % Moorcroft et al., 2001
                %Ac = Vcmax*(Ccarb-Tau)/(Ccarb+K1*(1+Oi/Ko));     % Meydlin et al., 2002 

            %   Water demand & supply parameters
                Brc = Bfr.*RCr;

            %   Assume saturated vapour pressure (SVP) inside the leaf [hPa]
                SVPl   =  exp(1.8096 + (17.269425 .* Tlc)./(237.3 + Tlc));

            %   Water vapour deficit in the leaf - air: [mol.mol-1], which is just the vapour pressure kPA / 100kPa or hPA / 1000hPA
                Ds  = (SVPl-VPa(t,1)).*10^-3; % [mol.mol-1]          

            %   Light limited rate of photosynthesis when the RuBP activity is limited
                Je      = alphaC3.*Qz.*(Ccarb.*10^-6-Tau)./(Ccarb.*10^-6-2.*Tau);
                    %   Find J: f = @(x)Theta*x^2-(alpha*Q+Jmax)*x+alpha*Q*Jmax; J = fzero(f,0); % Meydlin et al., 2002
                    %   Aj     = J/4*(Ccarb-Tau)/(Ccarb+2*Tau);

            %   Photosynthetic assimilation when open stomata
                A0  = max(0,min(Jc,Je)+Ac);

            %   stomatal conductance:
                cso = 8*A0./((Ccarb.*10^-6-Tau).*(1+Ds./0.01))+0.01;  % open stomata   (8 for C3, 4 for C4)
                csc = 0.01;   % closed-stomata

            %   Evaporation rate at height z           
                dPhi_O  = dPhi_O+Ds.*cso;  % open stomata
                dPhi_c  = dPhi_c+Ds.*csc;  % closed-stomata
            
            %   Net assimilation at height z [micromol[C]/s]
                q(z,:)  = (2.*n0.*(1-(xzz(z,:).^n0).*height(sh,:).^(-n0))).*(xzz(z,:).^(n0-1)).*(height(sh,:).^-n0);            
                      
        end    %   Integration over height z
        
        
        %   Total Evapotranspiration integrated for the whole canopy for a second [micromol[C]/sc]
            Phi_O = dPhi_O.*(height(sh,:)./s); % *hbymin for integration
            Phi_c = dPhi_c.*(height(sh,:)./s); % *hbymin for integration
            Demand = Phi_O.*10E-6.*18.01528E-3.*(1./LMA).*Bl(sh,:);
            Supply = Kw.*Water.*Brc(sh,:);
            fow    = 1./(1+Demand./Supply);            
            Phinet= fow.*Phi_O+(1-fow).*Phi_c;   % Phi_net= fow*Phi_O+(1-fow)*Phi_c;   but Phi_c not defined yet
            Phinet = real(Phinet);
            Phinet(Phinet<0) = 0;
        
        %   Total assimilation integrated for the whole canopy for a second [micromol[C]/sc]
            dA =  max(0,((ones(s,1)*fow).*(ones(s,1)*(min(Jc,Je)))+(1-ones(s,1)*fow).*(ones(s,1)*Ac))).*q; %-Rroot;   % assuming 1/3 of assimilation is lost through growth respiration
            A(sh,:,t)=sum(dA,1).*(height(sh,:)./s);  % *hbymin for integration
            A(sh,:,t)=real(A(sh,:,t));
            A(A(sh,:,t)<0)=0;
        
        %   
        Wupnet = Phinet.*10E-6.*18.01528E-3.*Bt(sh,:).*(1./LMA).*1./(2+0.0012128.*(1./LMA).*height(sh,:));
        
        %   Respiration of roots       
        Root  = (exp(3000.*(1./288.2-1./(real(Tc(t,1))+273.2)))./((1+exp(0.4.*(5-real(Tc(t,1))))).*(1+exp(0.4.*(real(Tc(t,1))-45)))).*Bfr(sh,:)).*3600.*10^-6.*Cbio;    % Moorcroft et al., 2001
        
        if sg == 0   %   Calculate the turnover per month (T)   Moorcroft et al., 2001            
            sleaf = ((1./LMA)./16).^(-1./0.46);                  % leaf longevity
            Tleaf = Bl(sh,:).*1./sleaf;                          % leaf drop evergreen
            Troot = 1./sleaf.*Bfr(sh,:).*(1+exp(0.4.*(278.15-real(Tc(t,1))))).^-1; % fine root        
            Tbark = Bb(sh,:).*kb;                                % bark
            T = (Tleaf + Troot + Tbark)./(tmax.*12);            
            Tl(sh,:)  = Tl(sh,:) + Tleaf./(tmax.*12);            %   TURNOVER accumulated per month (leaf)
            Tfr(sh,:) = Tfr(sh,:) + Troot./(tmax.*12);           %   TURNOVER accumulated per month (fine roots)
            Tb(sh,:)  = Tb(sh,:) + Tbark./(tmax.*12);            %   TURNOVER accumulated per month (bark)
        elseif sg == 1
            T = zeros(1,n);    
        end

        %   Net assimilation [Kg[C]/h]
            Akgdt    = Y.*Cbio.*(LA(sh,:).*A(sh,:,t).*10.^-6.*3600);   % 10^-6 to transform from micromol to mol   , per hour (*3600)
        %   NET PRODUCTION per hour (P) [Kg[C]/h]
            P(sh,:) = P(sh,:) + Akgdt-Root-T;
            P=real(P);
            P(P<0)=0;
        %   Water Uptake per hour (Wup)   [kg H2O/h]
            Wup(sh,:)=Wup(sh,:)+Wupnet.*3600;     %  per hour(3600), mol (10E-6), kg/mol[h20](18.01528E-3)
        
    

    end    %   integration over time t
    
    Phi_net(sh,:) = Phinet;

    if sg == 0    %  Deal with trees, not seedlings    
    
        fr   = Cr1.*(1+exp(Cr2.*(1-height(sh,:)./hmat'))).^-1;  %   Fraction of production allocated to reproduction (hr)    
        FWPGL = 1./(1+(1+beta1).*(1+b).*STD.*nc.*theta.^(-1).*alpha1.*(LMA.^(-1-beta1)).*(Bl(sh,:).^beta1)+STD.*nc.*alpha2.*beta2.*(LMA.^(-beta2)).*(Bl(sh,:).^(beta2-1))+alpha3.*LMA.^(-1));   %   Fraction of whole plant that is leaf (FLAPL)  (see appendix S2 in Falster et al., 2011 (JoE) for details)
        
        Fm  = Cd0.*exp(-Cd1.*STD)+Cd2.*exp(-Cd3.*P(sh,:).*12./LA(sh,:)); %   Mortality force [year^-1]
        Fm = real(Fm);    
        Sk(sh,:)  = nthroot(exp(-Fm),12);         %   Monthly Survival rate        
        Bxy = Bl(sh,:)+((1-fr).*P(sh,:).*FWPGL);  %   Biomass after growing
        hy  = alpha1.*(Bxy.*LMA.^-1).^beta1;      %   Height after growing
        Gxy(sh,:) = (hy-height(sh,:))./hbymin;    %   Growth rate from one height class hx to another hy
        Gxy(Gxy<0)=0;
        Fk(sh,:)  = fr.*P(sh,:)./(Cacc.*Ssize);   %   Rate of seed production
    
    elseif sg == 1    % Deal with seedlings    		
       Ssg  = ((((P(sh,:)./LA(sh,:)).^-2).*(Cs0.^2)+1).^-1);    % Seedling mortality  
    
    end
end










