%============================================================================================%
% IVM: INDIVIDUAL VITAL MODEL
%      Estimate the vital rates from photosynthetic absorbtion of the trees
%==========================================================================


function [Sk,Gxy,Fk,Tl,Tfr,Tb,Wup,Phi_net] = IVMdiv(dEdz,Climate,Water,PFT,s,smin,height,sh,Phi_net,hsg,hmat,hby)

CO2 = Climate(:,1);
Qt  = Climate(:,2);
Qts = Climate(:,3);
Tc  = Climate(:,4);
VPa = Climate(:,6);
STD = PFT(1,1);
LMA = PFT(2,1);
Ssize = PFT(3,1);
%	CALL SCRIPTS AND FUNCTIONS
Parameters;
[Bt,Bl,~,~,~,Bb,~,Bfr,~,LA] = BiomassDiv(PFT,height);

%Br = Bfr + Bcr;
tmax=size(Qt,1);

Wup = 0;
P   = 0;
Tl  = 0;
Tfr = 0;
Tb  = 0;
for t=1:tmax
    A      = 0;    % initial conditions
    
if s > 10
    s = 10;
end

Phinet = ones(s,1).*Phi_net;
    for z  = 1:s
        xzz      = [hsg+.5*((height-hsg)/s),hsg+.5*((height-hsg)/s)+((height-hsg)/s)*[1:s-1]]';  %  integration using mid-point rule
        
        %   Flux of photon within the canopy (mol.m^-2[photon].s^-1	(Falster et al., 2011)
        Qz     = Qt(t,1)*dEdz(sh,1);    % Total irradiance
        Qsz    = Qts(t,1)*dEdz(sh,1);  % Short wave only (to estimate leaf temperature)
        %   Carbon concentration in atmosphere (Catm), intercell (Cint) and in the carboxilation chamber (Ccarb)
        Cint   = CO2(t,1)*0.8;       %  Poorter & Farquhar, 1994 (Austr. J Plant. Physiol) -
        Ccarb  = Cint*0.7;      %  Ccarb (carboxylation) is lower than Cint
        %   Leaf temperature Tlc [C]: simple leaf energy balance equation (Moorcroft et al., 2001) or 21.4 on average       
        Phiconv = 38.4;                        %   Governs the rate of convective cooling [J/m2/s/K]        
        lhv = (2.50084-0.00234*real(Tc(t,1)))*10^6;  %   Latent heat of water vaporization [J/Kg of water]        
        PhiKg = Phinet(z,1)*10E-6*18.01528E-3;     %   Convert Phi_net [micromol H2O] into [Kg HeO]        
        Tlc = (Qsz - lhv*PhiKg)/Phiconv + real(Tc(t,1));
        Tlc = real(Tlc);
        %   Michaelis-Menten coefficient for C02 (K1) and 02 (K2)
        K1     = 1.5E-4*exp(6000*(1/288.2-1/(Tlc+273.2)));	   % Moorcroft et al., 2001
        K2     = 0.836*exp(-1400*(1/288.2-1/(Tlc+273.2)));     % Moorcroft et al., 2001
        %Ko    = 278.4*exp(36380*(Tl-298)/(298*Rgas*Tl));      % Meydlin et al., 2002
        %Kc    = 404.9*exp(79430*(Tl-298)/(298*Rgas*Tl));      % Meydlin et al., 2002
        %   Tau: Co2 compensation point
        Tau    = 2.12E-5*exp(5000*(1/288.2-1/(Tlc+273.2)));
        %	Optimal Temperature for Rubisco and RuBP
        %Toptv  = Hdv/(Sv-Rgas*log(Hav/(Hdv-Hav)));           % Meydlin et al.,2002
        %Toptj  = Hdj/(Sj-Rgas*log(Haj/(Hdj-Haj)));            % Meydlin et al., 2002
        %   Maximum capacity of Rubisco
        Vcmax   = 12.5*exp(3000*(1/288.2-1/(Tlc+273.2)))/((1+exp(0.4*(5-Tlc)))*(1+exp(0.4*(Tlc-45))));
        %Vcmax  = k25v*(Hdv*exp(Hav*(Tl-Toptv)/(Tl*Rgas*Toptv))/(Hdv-Hav*(1-exp(Hdv*(Tl-Toptv)/(Tl*Rgas*Toptv)))));   % Meydlin et al., 2002
        %   Maximum capacity of RuBP
        %Jmax   = k25j*(Hdj*exp(Haj*(Tl-Toptj)/(Tl*Rgas*Toptj))/(Hdj-Haj*(1-exp(Hdj*(Tl-Toptj)/(Tl*Rgas*Toptj)))));
        %   Photosynthesis demand when stomata are closed
        Ac     = - 0.02*Vcmax;
        %   Rubisco activity CO2 limited rate of photosynthesis
        Jc     = Vcmax*(Ccarb-Tau)/(Ccarb+K1*(1+K2));        % Moorcroft et al., 2001
        %Ac    = Vcmax*(Ccarb-Tau)/(Ccarb+K1*(1+Oi/Ko));     % Meydlin et al., 2002
        
        
        %   Water demand & supply parameters
        Brc    = Bfr*RCr;
        %   Assume saturated vapour pressure (SVP) inside the leaf [hPa]
        SVPl   =  exp (1.8096 + (17.269425 * Tlc)/(237.3 + Tlc));
        %   Water vapour deficit in the leaf - air: , expressed in mole fraction [mol.mol-1], which is just the vapour pressure kPA / 100kPa or hPA / 1000hPA
        Ds     = (SVPl-VPa(t,1))*10^-3; % [mol.mol-1]
        
        %   Find J
        %f      = @(x)Theta*x^2-(alpha*Q+Jmax)*x+alpha*Q*Jmax; J = fzero(f,0); % Meydlin et al., 2002
        %   Light limited rate of photosynthesis when the RuBP activity is limited
        Je      = alphaC3*Qz*(Ccarb-Tau)/(Ccarb-2*Tau);
        %Aj     = J/4*(Ccarb-Tau)/(Ccarb+2*Tau);
        %   Photosynthetic assimilation when open stomata
        A0      = max(0,min(Jc,Je)+Ac);
        %   stomatal conductance:
        cso     = 8*A0/((Ccarb-Tau)*(1+Ds/0.01))+0.01;  % open stomata   (8 for C3, 4 for C4)
        csc     = 0.01;   % closed-stomata
        %   Evaporation rate
        Phi_O  = Ds*cso;  % open stomata
        Phi_c  = Ds*csc;  % closed-stomata
        %   Water demand & supply
        q      = (2*n0*(1-(xzz(z)^n0)*height^(-n0)))*(xzz(z)^(n0-1))*(height.^-n0);
        Demand = Phi_O*10E-6*18.01528E-3*(1/LMA)*Bl;
        Supply = Kw*Water*Brc;
        fow    = 1/(1+Demand/Supply);
        
        Phinet(z,1)= fow*Phi_O+(1-fow)*Phi_c;   % Phi_net= fow*Phi_O+(1-fow)*Phi_c;   but Phi_c not defined yet
        
        %   Maintenance respiration: (Kg[C]/h)
        %Rroot  = exp(3000*(1/288.2-1/(Tc+273.2)))/((1+exp(0.4*(5-Tc)))*(1+exp(0.4*(Tc-45))))*Br;
        
        %   Net assimilation at height z [micromol[C]/s]
        Anet   =  max(0,(fow*(min(Jc,Je))+(1-fow)*Ac))*q; %-Rroot;   % assuming 1/3 of assimilation is lost through growth respiration
        %Rstem = ((Bs+2*Bb)/STD)*(Crs/((sum(dmax))*24));
        %	Total assimilation integrated for the whole canopy for an hour [micromol[C]/h]
        
        A  = A+Anet;
    end
    A=real(A);
    A(A<0)=0;
    Phi_net = mean(Phinet);
    
    Phi_net = real(Phi_net);   
    Phi_net(Phi_net<0) = 0;
    Wupnet = Phi_net*10E-6*18.01528E-3*Bt*(1/LMA)*1/(2+0.0012128*(1/LMA)*height);
    %   Respiration roots
    %R  = ((Bs+2*Bb)/STD+Br*Crr)/tmax;
    %R  = (LAold*Nu*Crl+(Bsold+2*Bbold)/STDold+Brold*Crr)/tmax;
    Root  = (exp(3000*(1/288.2-1/(real(Tc(t,1))+273.2)))/((1+exp(0.4*(5-real(Tc(t,1)))))*(1+exp(0.4*(real(Tc(t,1))-45))))*Bfr)/tmax;    % Moorcroft et al., 2001
    
    %   TURNOVER per year (T)   Moorcroft et al., 2001 + Falster et al., 2011
    %   TURNOVER per year (T)   Moorcroft et al., 2001 + Falster et al., 2011
    sleaf = ((1/LMA)/16)^(-1/0.46);                      % leaf longevity
    Tleaf = Bl*1/sleaf;                                  % leaf drop evergreen
    Troot = 1/sleaf*Bfr*(1+exp(0.4*(278.15-real(Tc(t,1)))))^-1; % fine root
    %Tdrop =                                             % add Tdrop if decidious
    Tbark = Bb*kb;                                       % bark
    T = (Tleaf + Troot + Tbark)/(tmax*12);
    %   TURNOVER accumulated per month
    Tl  = Tl + Tleaf/(tmax*12);
    Tfr = Tfr + Troot/(tmax*12);
    Tb  = Tb + Tbark/(tmax*12);
    %   Net assimilation [Kg[C]/h]
    Akgdt    = Y*Cbio*(LA*A*(height/s)*10^-6*3600);   % 10^-6 to transform from micromol to mol   , per hour (*3600)
    %   NET PRODUCTION per hour (P) [Kg[C]/h]
    P = P + Akgdt-Root-T;
    P=real(P);
    P(P<0)=0;
    %   Water Uptake per hour (Wup)   [kg H2O/h]
    Wup=Wup+Wupnet*3600;     %  per hour(3600), mol (10E-6), kg/mol[h20](18.01528E-3)
end
      
%   Fraction of production allocated to reproduction (hr)
fr   = Cr1*(1+exp(Cr2*(1-height/hmat)))^-1;
%   Fraction of whole plant that is leaf (FLAPL)  (see appendix S2 in Falster et al., 2011 (JoE) for details)
FWPGL = 1/(1+(1+beta1)*(1+b)*STD*nc*theta^(-1)*alpha1*(LMA^(-1-beta1))*(Bl^beta1)+STD*nc*alpha2*beta2*(LMA^(-beta2))*(Bl^(beta2-1))+alpha3*LMA^(-1));
%   VITAL RATES
%   Instantaneous mortality rate (mortality force [year^-1])
Fm  = Cd0*exp(-Cd1*STD)+Cd2*exp(-Cd3*P*12/LA);
Fm = real(Fm);

%Cd0inv = 1/Cd0;
%Cd0h   = 1/(Cd0inv*(sum(dmax))*24);
%Cd2inv = 1/Cd2;
%Cd2h   = 1/(Cd2inv*(sum(dmax))*24);
%	Fm  = (1-(Cd0h*exp(-Cd1*STD)+Cd2h*(exp(-Cd3*((P)*(sum(dmax))*24)/(LA)))))^(1/(sum(dmax))*24);   %   Probability of survival: 1 - mortality rate
%   Survival rate
Sk  = nthroot(exp(-Fm),12);
%   Growth rate
Bxy = Bl+((1-fr)*P*FWPGL);
hy  = alpha1*(Bxy*LMA^-1)^beta1;
Gxy = (hy-height)/hby; %   Growth rate in height combining Eqn 2,3,19 in Falster et al. modified using
Gxy(Gxy<0)=0;
Fk  = fr*P/(Cacc*Ssize); % 	Rate of seed production
end










