function [Timber, LMA, Seed, Dplanting] = Planting(PlantType, Clim,Nplant)

if PlantType == 1
    %	Number of PFTS that need to be planted
    Timber = 0;
    LMA = 0;
    Seed = 0;
    Dplanting = 0;
elseif PlantType == 2
    if Clim == 1
        %	Gives the trait values of each PFTS to plant (group per vector)
        Timber       = 300;
        LMA          = 0.05;
        Seed         = 10^-7;
    elseif Clim == 2;
        Timber       = 1000;
        LMA          = 0.05;
        Seed         = 10^-7;
    end
    %	Initial Dplanting of plantation for each PFTs planted [m2] (must be a vector in agreement with Timber, LMA, Seed)
    Dplanting      = Nplant;
elseif PlantType == 3
    if Clim == 1
        %	Gives the trait values of each PFTS to plant (group per vector)
        Timber       = 300;
        LMA          = 0.05;
        Seed         = 10^-3;
    elseif Clim == 2;
        Timber       = 1000;
        LMA          = 0.05;
        Seed         = 10^-3;
    end
    Dplanting      = Nplant;
elseif PlantType == 4
    Timber       = [300,300,300,300,533.33,533.33,533.33,533.33,766.66,766.66,766.66,766.66,1000,1000,1000,1000];
    LMA          = [0.35,0.35,0.35,0.35,0.35,0.35,0.35,0.35,0.35,0.35,0.35,0.35,0.35,0.35,0.35,0.35];
    Seed         = [10^-7,10^-7,10^-7,10^-7,10^-6,10^-6,10^-6,10^-6,10^-5,10^-5,10^-5,10^-5,10^-5,10^-4,10^-4,10^-4,10^-4];
    Dplanting      = [1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16]*Nplant;
elseif PlantType == 5
    Timber       = [300,533.33,766.66,1000,300,533.33,766.66,1000,300,533.33,766.66,1000,300,533.33,766.66,1000];
    LMA          = [0.05,0.15,0.25,0.35,0.05,0.15,0.25,0.35,0.05,0.15,0.25,0.35,0.05,0.15,0.25,0.35];
    Seed         = [10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4,10^-4];
    Dplanting      = [1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16]*Nplant;
    
elseif PlantType == 6
    Timber       = [1000,1000,1000,1000,1000,1000,1000,1000,1000,1000,1000,1000,1000,1000,1000,1000];
    LMA          = [0.05,0.05,0.05,0.05,0.15,0.15,0.15,0.15,0.25,0.25,0.25,0.25,0.35,0.35,0.35,0.35];
    Seed         = [10^-7,10^-6,10^-5,10^-4,10^-7,10^-6,10^-5,10^-4,10^-7,10^-6,10^-5,10^-4,10^-7,10^-6,10^-5,10^-4];
    Dplanting    = [1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16,1/16]*Nplant;
    
elseif PlantType == replant
    
    %%  Replanting after harvesting
    %   Walking time
    WalkingNeighboors = Nforestpatches*DistanceForests*1000/80; % walking time to go to neighbour's forest patch.
    Walktime = Walktime + WalkingNeighboors; % According to Wikipedia's page on walking, the average adult walking speed is 80 m/min, therefore it would take 1500/80 = 18.5 minutes to walk 1.5 kilometre.
    
    %   Proportion and Dplanting of the forest that will be replanted by the nipf owner after harvesting per household (OLS model)
    %   Country: Nepal, Region: Mid-West (Sakurai et al., 2004)
    % Planting Dplanting [*1000 seedlings/ha]:
    if harvesting == 1
        Dplanting_e = 10.2 - 1*2.51 - log(Walktime) - GravelSoil*1.85 - SandySoil*2.03;
        Dplanting_ne = 10.2 - 0*2.51 - log(Walktime) - GravelSoil*1.85 - SandySoil*2.03;
        Dplanting = Efficient_manager*Dplanting_e + (1 - Efficient_manager)*Dplanting_ne;
    else
        Dplanting = 0;
    end
    
    % D.3.7 - Diversity and density of plantation
    % Country: India, States: 27 (Murali, 2002) -Murali KS, Murthy IK, Ravindranath NH (2002a) Joint forest management in India and its ecological impacts. Environ Manag Health 13(5):512528
    nPlanting = ; % number of PFT planted
    lightwood  = 1/3; (% 60% firewood species (e.g., 40% acacia auriculiformis [550-600 kg/m3], LMA = 0.06 kg/m2, SM = 2.5E-05), 25% timber species (teak [650kg/m3]), 15% NTFP species (mango: Mangifera indica [Timber = 670kg/m3, seed mass ~ 0.25kg, LMA = 0.143], soapnuts: Sapindus emarginatus [kg/m3], Jamun plum: Syzygium cuminii [kg/m3]).
    midwood = 1/3;
    densewood  = 1/3;
    
end

