function Plot_Analysis_2(OUTPUT, Clim, Land)

%% Dimensions of OUTPUT = [years, variables, forestry practices, number of species, replicates]

%% Estimation of statistics
        
OUTPUT_mean_y_temp =  mean(OUTPUT, [1 4 5]);
splitmean = num2cell(OUTPUT_mean_y_temp, [1 2]);
OUTPUT_mean_y = vertcat(splitmean{:});
OUTPUT_se_y_temp =  std(OUTPUT, [1 4 5]) ./ sqrt(size(OUTPUT, 1) * size(OUTPUT, 4) * size(OUTPUT, 5));  %  Unlike Matlab, Octave does not have the option to do size(OUTPUT, [1 4 5]), as of 2021/09
splitmean = num2cell(OUTPUT_se_y_temp, [1 2]);
OUTPUT_se_y = vertcat(splitmean{:});

%% Save outputs 

title_mean = strcat('Mean', 'Analysis', int2str(Forestry_Analysis), 'Sp', int2str(nPFTS), 'C', int2str(Clim), 'L', int2str(Land));
title_se = strcat('S.E.', 'Analysis', int2str(Forestry_Analysis), 'Sp', int2str(nPFTS), 'C',int2str(Clim), 'L', int2str(Land));
csvwrite(title_mean, OUTPUT_mean_y);  
csvwrite(title_se, OUTPUT_se_y);

%% Plot results

subplot(3, 2, 1) % Fig 3A| Effect of ???? on biodiversity    
  set(gca, 'fontsize', 8)    
  errorbar(OUTPUT_mean_y(:, 3), OUTPUT_mean_y(:, 4), OUTPUT_se_y(:, 3), OUTPUT_se_y(:, 4), 'o')
  hold all    
  xlabel('Number of species in the forest')
  ylabel('level biological diversity in life-history traits (Shannon index)')
      
subplot(3, 2, 2) % Fig 3B| Effect on  forest above ground carbon biomass
  set(gca, 'fontsize', 8)
  errorbar(OUTPUT_mean_y(:, 3), OUTPUT_mean_y(:, 5), OUTPUT_se_y(:, 3), OUTPUT_se_y(:, 5), 'o')
  hold all
  xlabel('Number of species in the forest')
  ylabel('Average annual forest above-ground carbon content [kg.m^-^2]')
  
subplot(3, 2, 3) % Fig 3B| Timber harvesting
  set(gca, 'fontsize', 8)
  errorbar(OUTPUT_mean_y(:, 3), OUTPUT_mean_y(:, 18), OUTPUT_se_y(:, 3), OUTPUT_se_y(:, 18), 'o')
  hold all
  xlabel('Number of species in the forest')
  ylabel('Average annual economic benefit from harvesting [$.year^-^1]')
   
subplot(3,2,4) % Fig 3C| Average basic timber density in the forest
  set(gca,'fontsize',8)            
  errorbar(OUTPUT_mean_y(:, 3), OUTPUT_mean_y(:, 10), OUTPUT_se_y(:, 3), OUTPUT_se_y(:, 10), 'o')
  hold all
  xlabel('Number of species in the forest')
  ylabel('Average timber trait (basic timber density [kg.m^-^3])')
  
subplot(3,2,5) % Fig 3D| Average Seed size of trees in the forest
  set(gca,'fontsize',8)
  errorbar(OUTPUT_mean_y(:,3), OUTPUT_mean_y(:,11), OUTPUT_se_y(:,3), OUTPUT_se_y(:,11),'o')
  hold all
  xlabel('Number of species in the forest')
  ylabel('Average seed trait (see size [kg.m^-^3])')
  
subplot(3,2,6) % Fig 3D| Average specific leaf area SLA of trees in the forest
  set(gca,'fontsize',8)
  errorbar(OUTPUT_mean_y(:,3), OUTPUT_mean_y(:,12), OUTPUT_se_y(:,3), OUTPUT_se_y(:,12),'o')
  hold all
  xlabel('Number of species in the forest')
  ylabel('Average leaf trait (Species Leaf Area SLA [kg.m^-^2] ')    