function [Germ,Ssb] = SeedBank(E,Ssize,Scale)

%   E: canopy openess [0-1]
%   Ssize: seed mass [kg]
%   Scale: is the time scale in month at which the germ and Ssb must be
    %   estimated. If 1 month then Scale = 12; if 1 season the Scale = 3; if 1 year the Scale = 1

%   Type of dormancy
    %   Exogeneous dormancy
        %   Physical dormancy (PY)
        %   Mechanical dormancy (
        %   Chemical dormancy 
    %   Endogeneous dormancy
        %   Physiological dormancy (PD / ND)
        %   Morphological dormancy (MD)
        %   Morphophysiological dormancy (MPD)
    %   Combinational dormancy (PY + PD)

%   Seed mass reserve [g] is approximatly equal to the protective mass (Moles et al., 2003 (Ecology) - DO SMALL-SEEDED SPECIES HAVE HIGHER SURVIVAL THROUGH SEED PREDATION THAN LARGE-SEEDED SPECIES?
Res_mass = ((Ssize).*10^3)./2;
%   Germination model developped byvan Ulft L.H., 2004 (Plant Biology) -
%   Effect of seed size and gap size on seed fate of tropical rainforest
%   tree species in Guyana. Mostly PD dormancy species.
a = 0.901;
b = 0.314;
c = -0.049;
d = 8.77E-4;
e = -0.024;
f = 4.84E-4;

asin_sqrt_Germ = a + b.*log10(Res_mass) + c.*E + d.*E.^2 + e.*log10(Res_mass).*E + f.*log10(Res_mass).*E.^2;
Germ = nthroot((sin(asin_sqrt_Germ)).^2,Scale);

%   Seed bank survival
odd  = 1.64.*log10(Ssize.*10^6)-3;        %  Moles et al., 2003
Ssb  = nthroot(exp(odd)./(exp(odd)+1),Scale);

%   "The maximum seed burial depth from which seedlings could emerge
%   succesfully [is] strongly positively associated with seed mass (n=8
%   species neotropical pioneers". (Pearson et al., 2002 (Ecology) -
%   Germination ecology of neotropical pioneers: ....")
end
