function [Cost,N,BNdebris] = Silviculture(Farea,Nforestpatches,SoilElements,dEdN,Efficient_manager,Efficient_monitor,Hselection,Eplanting,Pharvest,PFTs,s,height,N,BNdebris,Random)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Inputs

% Efficient_manager: 1 = private or state, 0 = community
% Efficient_monitor: 1 = community, 0 = state or private
% Ndominant
Pfws = Eplanting(1,1);  % Proportion firewood species planted
Ptfs = Eplanting(2,1);  % Proportion timber forest species planted
Pntfs = Eplanting(2,1); % Proportion non-timber forest species planted
Mfws = Hselection(:,1); % Vector preferences
Mtfs = Hselection(:,2);
Mntfs = Hselection(:,3);
TD = PFTs(:,1);
%% Outputs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Parameters
[~,Bl,Bbr,Btr,~,Bb,~,Bfr,Bcr,~,~,~,~,~] = Allometry(PFTs,height,s,0);

%%  Define Whether the soil is sandy
[~,~,~,~,~,~,STypeUSDA] = Soil(SoilElements);
comp1 = strcmp(STypeUSDA,'sand');
comp2 = strcmp(STypeUSDA,'loamy sand');
comp3 = strcmp(STypeUSDA,'sandy loam');
comp4 = strcmp(STypeUSDA,'sandy clay loam');
comp5 = strcmp(STypeUSDA,'loam');
comp6 = strcmp(STypeUSDA,'silt loam');
comp7 = strcmp(STypeUSDA,'clay loam');
comp8 = strcmp(STypeUSDA,'silty clay loam');

if comp1 == 1 || comp2 == 1
    SandySoil = 1;
    LoamySoil = 0;
elseif comp3 == 1 || comp4 == 1 || comp5 == 1 || comp6 == 1 || comp7 == 1 || comp8 == 1
    SandySoil = 0;
    LoamySoil = 1;
end
GravelSoil = 0;

%%  Walking time
WalkingNeighboors = Nforestpatches*DistanceNeighboorForests*1000/80; % walking time to go to neighbour's forest patch.
Walktime = DistanceMainForest*1000/80;
Twalktime = Walktime + WalkingNeighboors; % According to Wikipedia's page on walking, the average adult walking speed is 80 m/min, therefore it would take 1500/80 = 18.5 minutes to walk 1.5 kilometre.

%%  Replanting
%   60% firewood species (e.g., 40% acacia auriculiformis [550-600 kg/m3], LMA = 0.06 kg/m2, SM = 2.5E-05),
%   25% timber species (teak [650kg/m3]),
%   15% NTFP species (mango: Mangifera indica [Timber = 670kg/m3, seed mass ~ 0.25kg, LMA = 0.143], soapnuts: Sapindus emarginatus [kg/m3], Jamun plum: Syzygium cuminii [kg/m3]).
%   (Murali, 2002 - Country: India, States: 27)

%   D.1 - Proportion and density of the forest that will be replanted by the nipf owner after harvesting per household (OLS model)
%       Country: Nepal, Region: Mid-West (Sakurai et al., 2004)
%       Planting density [*1000 seedlings/ha]:



if Pharvest >= 0.95
    Dplanting_e = (10.2+3.32*(2*rand(1)-1)) - 1*(2.51) - log(Twalktime) - GravelSoil*(1.85+0.93*(2*rand(1)-1)) - SandySoil*(2.03+1.31*(2*rand(1)-1));
    Dplanting_ne = (10.2+3.32*(2*rand(1)-1)) - 0*2.51 - log(Twalktime) - GravelSoil*(1.85+0.93*(2*rand(1)-1)) - SandySoil*(2.03+1.31*(2*rand(1)-1));
    Dplanting = Efficient_manager*Dplanting_e + (1 - Efficient_manager)*Dplanting_ne;
else
    Dplanting = 0;
end



%   D.3 - Preference in species collection given the TD of the species of interest
%               The Fuel Value Index (FVI)is a simple and practical instrument for
%               predicting the local preference for fuelwood species in a community (Ramos et al., 2008).
%               (with FVI = CaloricValue*WetDensity/MoistureContentent ~ preference)
%           Country: Brazil, State:Pernambuco (Ramos et al., 2008)

if Random == 1
  FVI = (0.0475+0.008*(2*rand(1)-1)).*TD - (11.424+4.8*(2*rand(1)-1));
elseif Random == 0
  FVI = 0.0475.*TD - 11.424;
endif

FVIindex = sum(sum(unique(FVI','rows')))/size(sum(unique(FVI','rows')),2);
FW_pref_TD = FVI/FVIindex;


%   D.2 - Planting species that have been harvested
N(2,:) = N(2,:) + Dplanting.*(Pfws.*FW_pref_TD' + Ptfs.*repmat(Mtfs,size(N,2),1)' + repmat(Pntfs.*Mntfs,size(N,2),1)');

%   D.4 - Final planting choice

%%  Pre-commercial Thinning/Weeding/prunning
%       Reasons see here: https://cfs.nrcan.gc.ca/pages/134. Thinning allows forest managers to control the mix of tree species in a stand, which means they can maintain types of trees that are important food sources and habitat for wildlife.

%   D.1 - Weeding labor [man-day/ha/year]
%       Country: Nepal, Region: Mid-West (Sakurai et al., 2004)
if Random == 1
  Weeding = (30.9+12.2*(2*rand(1)-1)) - log(Twalktime)*(2.79+1.35*(2*rand(1)-1)); % private/state plantation 11 man-day/ha/yr, community 6 man-day/ha/yr
elseif Random == 0
  Weeding = 30.9 - log(Twalktime)*2.79; % private/state plantation 11 man-day/ha/yr, community 6 man-day/ha/yr
endif

%   D.2 - Pre-commercial thinning/weeding
if Random == 1
  Thinning_e = 1*(6.09+2.23*(2*rand(1)-1)) - Farea/10000*(2.34+1.2*(2*rand(1)-1)) - GravelSoil*(4.37+1.79*(2*rand(1)-1)) - LoamySoil*(3.33+1.71*(2*rand(1)-1));
  Thinning_ne = 0*(6.09+2.23*(2*rand(1)-1)) - Farea/10000*2.34 - GravelSoil*(4.37+1.79*(2*rand(1)-1)) - LoamySoil*(3.33+1.71*(2*rand(1)-1));
elseif Random == 0
  Thinning_e = 1*6.09 - Farea/10000*2.34 - GravelSoil*4.37 - LoamySoil*3.33;
  Thinning_ne = 0*6.09 - Farea/10000*2.34 - GravelSoil*4.37 - LoamySoil*3.33;
endif

Thinning = Efficient_manager*Thinning_e + (1 - Efficient_manager)*Thinning_ne;


%   D.3 - Restriction on precommercial thinning (in multispecies stand,
%   assume thinning only species with no livelihood interest.
Hthinning = Hselection - 1;
Hthinning(Hthinning == -1) = 1;

%   D.4 - Detection of trees for thinning, given thinning effort
%       Trait based Multispecies detectability model (Garrard et al., 2013)
%       Defining dominance
dEdNthinning = dEdN.*Hthinning(1,:);
[~,position] = min(dEdNthinning);
%       Mean time to detection of 1 individual of the species with dominant
%       PFT syndrome (Garrard et al., 2013)
expert = 1; % experienced observer
Nsurvey = N(3:size(N,1),position);
Nsurvey(Nsurvey > 1) = 1;
% assumes that density per squarre/m = frequency of occurance at one hectar
% scale.
if Random == 1
  tmean = exp((4.27+0.58*(2*rand(1)-1)) - (0.17+0.39*(2*rand(1)-1)).*expert - (0.28+0.12*(2*rand(1)-1)).*log(-log(1 - Nsurvey) + (0.34+0.17*(2*rand(1)-1)) + (0.27+0.2*(2*rand(1)-1)) + (0.89+0.2*(2*rand(1)-1))));
elseif Random == 0
  tmean = exp(4.27 - 0.17.*expert - 0.28.*log(-log(1 - Nsurvey) + 0.34 + 0.27 + 0.89));
endif

tmean(tmean <= 0) = 0.0001;

%       Number of individuals detected and weeded.
%           Asumtions: % spatial random distribution, 8 hours per man-day (and 60 mn/hour)
%           Only rules on grasses are known, so assume the same detection apply between grass and trees and does not change with surrounding vegetation structure, shade level and color
Nweeding = ((Weeding + Thinning).*8.*60./tmean)/10000;


Nweeding(isnan(Nweeding)) = 0;
Nweeding(isnan(Nweeding)) = 0;

%   D.5 - Applying pre-commercial weeding/thinning on the community vector
%       Assume thinning effort on dominant species evenly spread between size-classes (same percentage thinned, not same number).
if sum(N(:,position)) < Nweeding
    N(:,position) = 0;
else
    alpha = Nweeding/sum(N(3:size(N,1),position));
    Rthin = ones(size(N,1) - 2,1).*alpha;
    Rthin(1,1) = 0;
    N(3:size(N,1),position) = N(3:size(N,1),position) - Nweeding.*Rthin;
    N(N<0) = 0;
    N(isnan(N)) = 0;
end

%%  Attribute dead biomass
BNdebris(2:size(N,1)-1,position,1) = BNdebris(2:size(N,1)-1,position,1) + Nweeding.*Bl(2:size(N,1)-1,position,1);   % Leaves
BNdebris(2:size(N,1)-1,position,2) = BNdebris(2:size(N,1)-1,position,2) + Nweeding.*Bbr(2:size(N,1)-1,position,1);   % branches
BNdebris(2:size(N,1)-1,position,3) = BNdebris(2:size(N,1)-1,position,3) + Nweeding.*Btr(2:size(N,1)-1,position,1);   % Trunk
BNdebris(2:size(N,1)-1,position,4) = BNdebris(2:size(N,1)-1,position,4) + Nweeding.*Bb(2:size(N,1)-1,position,1);   % Bark
BNdebris(2:size(N,1)-1,position,5) = BNdebris(2:size(N,1)-1,position,5) + Nweeding.*Bcr(2:size(N,1)-1,position,1);   % Coars roots
BNdebris(2:size(N,1)-1,position,6) = BNdebris(2:size(N,1)-1,position,6) + Nweeding.*Bfr(2:size(N,1)-1,position,1);   % Fine Roots
BNdebris(isnan(BNdebris)) = 0;
BNdebris(~isfinite(BNdebris)) = 0;
%%  Monitoring


%%  Costs
% D.3.9 Costs of protecting and maintaining the land
% Country: Nepal, Region: Mid-West (Sakurai et al., 2004)
% Cost of protection Rupee/ha/year:
PPPrate = 36.41; % 2013 PPPrate for Nepal
Cprotection_e = (0*8.08 - 8.33*GravelSoil)*1000/PPPrate;
Cprotection_ne = (1*8.08 - 8.33*GravelSoil)*1000/PPPrate;
Cprotection = Efficient_monitor*Cprotection_e + (1 - Efficient_monitor)*Cprotection_ne;

 
% Cost of managing:  Silvicultural expenses per hectare of land owned [$/ha/yr] (NB: should be per hectare land treated and not owned)
% Country: USA, State: Mississippi (Arano & Munn, 2006)
%Cmanaging = (-11.97 + 2.23*Pfastree + 1.5*log(Farea))/; % include cooperation with state/community/neighbors
Cweeding = 0;
%       Thinning
%if  j >= 1 && ThinV(y,1)>= 1
%[Thin,Nthin,N] = Thinning(dEdN,dEdz,N,S(:,n),Seedmean,LMAmean,Timbermean,PFT(:,n),j);
%else
%Thin = 0;
%Nthin = 0;
%end

Cost = Cprotection + Cweeding;

%%  REFERENCES

%   - Murali KS, Murthy IK, Ravindranath NH (2002a) Joint forest management in India and its ecological impacts. Environ Manag Health 13(5):512�528
%   - Sakurai, T., Rayamajhi, S., Pokharel, R. K., & Otsuka, K. (2004). Efficiency of timber production in community and private forestry in Nepal. Environment and Development Economics, 9(4), 539-561.
%   - Arano, K. G., & Munn, I. A. (2006). Evaluating forest management intensity: a comparison among major forest landowner types. Forest Policy and Economics, 9(3), 237-248.
%   - Garrard, G. E., McCarthy, M. A., Williams, N. S. G., Bekessy, S. A., Wintle, B. A. (2013), A general model of detectability using species traits. Methods in Ecology and Evolution, 4: 45�52. doi: 10.1111/j.2041-210x.2012.00257.x
%   - Ramos, M. A., Medeiros, P. M. D., Almeida, A. L. S. D., Feliciano, A. L. P., & Albuquerque, U. P. D. (2008). Can wood quality justify local preferences for firewood in an area of caatinga (dryland) vegetation?. Biomass and Bioenergy, 32(6), 503-509.


