function output = SoilTexture(A)
%% Function description
% Soil Texture Triangle Function
% InputA ===========================================================================
% A : ?? ?? (%)
%    col     1     2    3
% soil P   Sand  Clay  Silt

% OutputA ===========================================================================
% output.soil_texture: Soil texture
% output.soil_index : Soil texture index number
% Soil Texture Index Number
    % 0) ERROR
    % 1) Sand
    % 2) Loamy sand
    % 3) sandy loam
    % 4)sandy clay loam
    % 5) loam
    % 6) silt loam
    % 7) silt
    % 8) sandy clay
    % 9) clay loam
    % 10) silty clay loam
    % 11) clay
    % 12) silty clay
% output.soil_A : Silt ??? ??? SIlt ? ???, SIlt? ???, Sand? Clay? ???
%                    SIlt?? ?? ??? ??, ? ??? A(:,4)? ????, A(:,5)?
%                    ??? Silt? ????.
% ==================================================================================================
% Copyright: wh1988ha@gmail.com, 2013
% author: http://blog.daum.net/wh1988ha
% version : v1.01
% ==================================================================================================
%
%                                       100/\
%                                         /  \
%                                      90/    \10
%                                       /      \
%                                    80/        \20
%                                     /          \
%                     / \          70/            \30
%                      |            /              \
%                      |         60/       C        \40
%                      |          /                 /\
%                Percent clay  50/\                /  \50  Percent silt
%                               /  \              / SiC\         |
%                            40/ SC \____________/______\60      |
%                             /______\     CL    \ SiCL  \       |
%                          30/ SCL    \___________\_______\70   \ /
%                           /_________/          /         \
%                        20/_         \    L    /   SiL     \80
%                         /  \_   SL   \       /             \
%                      10/\_   \_       \_____/         ______\90
%                       / S \ LS \_          /         /  Si   \
%                      /_____\_____\________/_________/_________\
%                     100  90  80  70  60  50  40  30  20  10   
%                                   <--------------
%                                     Percent sand
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Classification of Soil Texture
tic
 
x = (100-A(:,1)-A(:,2)/2) ;
y = A(:,2)*sqrt(3)/2 ;
 
soil{size(A,1),1} = 0;
soil_n(size(A,1),1) = 0;
for i = 1: size(A,1)
% --------------------------------------------------
    % 1) sand
    if (0<=x(i,1) && x(i,1)<5 && y(i,1)>=0 && y(i,1)<= sqrt(3)*x(i,1)) ||...
            (5<=x(i,1) && x(i,1)<15 && y(i,1)>=0 && y(i,1)< -1*sqrt(3)/2*x(i,1)+15*sqrt(3)/2)
        soil{i,1} = 'sand' ;
        soil_n(i,1) = 1 ;
       
% 2) loamy sand
    elseif (5<=x(i,1) && x(i,1)<7.5 && y(i,1)>=-1*sqrt(3)/2*x(i,1)+15*sqrt(3)/2 && y(i,1)<= sqrt(3)*x(i,1)) ||...
            (7.5<=x(i,1) && x(i,1)<15 && y(i,1)>=-1*sqrt(3)/2*x(i,1)+15*sqrt(3)/2 && y(i,1)<-7.5*sqrt(3)/22.5*(x(i,1)-30) ) ||...
            (15<=x(i,1) && x(i,1)<30 && y(i,1)>=0 && y(i,1)<-7.5*sqrt(3)/22.5*(x(i,1)-30) )
        soil{i,1} = 'loamy sand' ;
        soil_n(i,1) = 2 ;
% 3) sandy loam
    elseif ( 7.5 <=x(i,1)  &&  x(i,1)< 10  && y(i,1)>= -1/sqrt(3)*(x(i,1)-30)  && y(i,1)<= sqrt(3)*x(i,1) ) ||...
            (10 <=x(i,1)  &&  x(i,1)< 30  && y(i,1)>= -1/sqrt(3)*(x(i,1)-30)  && y(i,1)< 10*sqrt(3) )||...
            (30 <=x(i,1)  &&  x(i,1)< 37.5  && y(i,1)>= 0  && y(i,1)< 10*sqrt(3) )||...
            (37.5 <=x(i,1)  &&  x(i,1)< 43.75  && y(i,1)>= 0  && y(i,1)< -1*sqrt(3)*(x(i,1)-47.5) )||...
            (43.75 <=x(i,1)  &&  x(i,1)< 50  && y(i,1)>= 0  && y(i,1)< 3.75*sqrt(3) )||...
            (50 <=x(i,1)  &&  x(i,1)< 53.75  && y(i,1)>= sqrt(3)*(x(i,1)-50) && y(i,1)< 3.75*sqrt(3))
        soil{i,1} = 'sandy loam' ;
        soil_n(i,1) = 3 ;
% 4)sandy clay loam
    elseif (10 <=x(i,1)  &&  x(i,1)< 17.5  && y(i,1)>= 10*sqrt(3)  && y(i,1)<= sqrt(3)*x(i,1) ) ||...
            (17.5<=x(i,1)  &&  x(i,1)< 37.5  && y(i,1)>= 10*sqrt(3)  && y(i,1)< 17.5*sqrt(3) ) ||...
            (37.5 <=x(i,1)  &&  x(i,1)< 41.25  && y(i,1)>= sqrt(3)*(x(i,1)-27.5)  && y(i,1)< -1*sqrt(3)*(x(i,1)-55))
        soil{i,1} = 'sandy clay loam' ;
        soil_n(i,1) = 4 ;
% 5) loam
    elseif (37.5 <=x(i,1)  &&  x(i,1)< 41.25 && y(i,1)>= -1*sqrt(3)*(x(i,1)-47.5) && y(i,1)< sqrt(3)*(x(i,1)-27.5) ) ||...
            (41.25 <=x(i,1)  &&  x(i,1)< 43.75 && y(i,1)>= -1*sqrt(3)*(x(i,1)-47.5)  && y(i,1)< 13.75*sqrt(3) ) ||...
            (43.75 <=x(i,1)  &&  x(i,1)< 53.75 && y(i,1)>= 3.75*sqrt(3)  && y(i,1)< 13.75*sqrt(3) ) ||...
            (53.75 <=x(i,1)  &&  x(i,1)< 63.75  && y(i,1)>= sqrt(3)*(x(i,1)-50)  && y(i,1)< 13.75*sqrt(3))
        soil{i,1} = 'loam' ;
        soil_n(i,1) = 5 ;
% 6) silt loam
    elseif (50 <=x(i,1)  &&  x(i,1)< 63.75 && y(i,1)>= 0  && y(i,1)< sqrt(3)*(x(i,1)-50) ) ||...
            (63.75 <=x(i,1)  &&  x(i,1)< 80 && y(i,1)>= 0  && y(i,1)< 13.75*sqrt(3) ) ||...
            (80 <=x(i,1)  &&  x(i,1)< 86.25 && y(i,1)>= sqrt(3)*(x(i,1)-80)  && y(i,1)< 13.75*sqrt(3) ) ||...
            (86.25 <=x(i,1)  &&  x(i,1)<=93.75  && y(i,1)>= 6.25*sqrt(3)  && y(i,1)<= -1*sqrt(3)*(x(i,1)-100))
        soil{i,1} = 'silt loam' ;
        soil_n(i,1) = 6 ;
% 7) silt
    elseif (80 <=x(i,1)  &&  x(i,1)< 86.25 && y(i,1)>= 0 && y(i,1)< sqrt(3)*(x(i,1)-80) ) ||...
            (86.25 <=x(i,1)  &&  x(i,1)<= 93.75 && y(i,1)>= 0 && y(i,1)< 6.25*sqrt(3) ) ||...
            (93.75 <=x(i,1)  &&  x(i,1)<= 100  && y(i,1)>= 0 && y(i,1)<= -1*sqrt(3)*(x(i,1)-100) )
        soil{i,1} = 'silt' ;
        soil_n(i,1) = 7 ;
% 8) sandy clay
    elseif (17.5 <=x(i,1)  &&  x(i,1)< 27.5  && y(i,1)>= 17.5*sqrt(3)  && y(i,1)<= sqrt(3)*x(i,1) ) ||...
            (27.5<=x(i,1)  &&  x(i,1)< 37.5  && y(i,1)>= 17.5*sqrt(3)  && y(i,1)< -1*sqrt(3)*(x(i,1)-55))
        soil{i,1} = 'sandy clay' ;
        soil_n(i,1) = 8 ;
% 9) clay loam
    elseif (35 <=x(i,1)  &&  x(i,1)< 41.25 && y(i,1)>= -1*sqrt(3)*(x(i,1)-55)  && y(i,1)< 20*sqrt(3) ) ||...
            (41.25 <=x(i,1)  &&  x(i,1)< 60 && y(i,1)>= 13.75*sqrt(3)  && y(i,1)< 20*sqrt(3) ) ||...
            (60 <=x(i,1)  &&  x(i,1)< 66.25  && y(i,1)>= 13.75*sqrt(3)  && y(i,1)< -1*sqrt(3)*(x(i,1)-80))
        soil{i,1} = 'clay loam' ;
        soil_n(i,1) = 9 ;
% 10) silty clay loam
    elseif (60 <=x(i,1)  &&  x(i,1)< 66.25  && y(i,1)>= -1*sqrt(3)*(x(i,1)-80)  && y(i,1)< 20*sqrt(3) ) ||...
            (66.25 <=x(i,1)  &&  x(i,1)< 80 && y(i,1)>= 13.75*sqrt(3)  && y(i,1)< 20*sqrt(3) ) ||...
            (80 <=x(i,1)  &&  x(i,1)< 86.25  && y(i,1)>= 13.75*sqrt(3)  && y(i,1)<= -1*sqrt(3)*(x(i,1)-100))
        soil{i,1} = 'silty clay loam' ;
        soil_n(i,1) = 10 ;
% 11) clay(i,1)
    elseif (27.5 <=x(i,1)  &&  x(i,1)< 35  && y(i,1)>= -1*sqrt(3)*(x(i,1)-55) && y(i,1)<= sqrt(3)*x(i,1) ) ||...
            (35 <=x(i,1)  &&  x(i,1)< 50  && y(i,1)>= 20*sqrt(3)  && y(i,1)<= sqrt(3)*x(i,1) ) ||...
            (50 <=x(i,1)  &&  x(i,1)< 60 && y(i,1)>= 20*sqrt(3)  && y(i,1)<= -1*sqrt(3)*(x(i,1)-100) ) ||...
            (60 <=x(i,1)  &&  x(i,1)< 70  && y(i,1)>= sqrt(3)*(x(i,1)-40)  && y(i,1)<= -1*sqrt(3)*(x(i,1)-100))
        soil{i,1} = 'clay' ;
        soil_n(i,1) = 11 ;
% 12) silty clay
    elseif (60 <=x(i,1)  &&  x(i,1)< 70  && y(i,1)>= 20*sqrt(3)  && y(i,1)< sqrt(3)*(x(i,1)-40) ) ||...
            (70 <=x(i,1)  &&  x(i,1)< 80  && y(i,1)>= 20*sqrt(3)  && y(i,1)<= -1*sqrt(3)*(x(i,1)-100))
        soil{i,1} = 'silty clay' ;
        soil_n(i,1) = 12 ;
    else
        soil{i,1} = 'error' ;
        soil_n(i,1) = 0 ;
    end
% --------------------------------------------------   
   
end
 
%% Test
 
if size(A,2) == 3
    test = 100-(A(:,1)+A(:,2)+A(:,3));
    A(:,4) = test ;
    A(:,5) = 100 - A(:,1) - A(:,2) ;
else
    A(:,3) = (-1)*(A(:,1)+A(:,2))+100 ;
end
 
%% Platform Ploting
set(figure(1),'Color', [1 1 1], 'pos',[50 50 650 500])
% Triangle
plot([0 100],[0 0],'k',0:50,sqrt(3).*(0:50),'k',50:100,sqrt(3).*(50:-1:0),'k'); hold on ;
fontsize_a = 7 ;
for i = 0:0.5:10
    if rem(i,1) == 0
        fontsize_a = 8 ;
        color_grid = [0.4 0.4 0.5] ;
    else
        fontsize_a = 6 ;
        color_grid = [0.8 0.8 0.8] ;
    end
   
    plot([i*10 5*i], [0 (5*i)*sqrt(3)],'color', color_grid ) % Sand grid
    plot([i*10 50+5*i], [0 (50-5*i)*sqrt(3)],'color', color_grid ); % Silt grid
    plot([5*i 100-5*i],[(5*i)*sqrt(3) (5*i)*sqrt(3)],'color', color_grid ) % Clay grid
    % axis ----
    plot([i*10 i*10+2],[0 -2*sqrt(3)],'color',[0 0 0]) ; % Sand axis
        text(i*10+2,-2*sqrt(3),num2str(100-10*i),'Rotation',-60,'HorizontalAlignment','left',...
            'FontSize',fontsize_a,'VerticalAlignment','bottom');
    plot([50+5*i 50+5*i+2],[(50-5*i)*sqrt(3) (50-5*i)*sqrt(3)+2*sqrt(3)],'color',[0 0 0]) ; % Silt axis
        text(50+5*i+2,(50-5*i)*sqrt(3)+2*sqrt(3),num2str(10*i),'Rotation',60,'HorizontalAlignment','left',...
            'FontSize',fontsize_a,'VerticalAlignment','bottom')
    plot([5*i 5*i-2*sqrt(3)],[(5*i)*sqrt(3) (5*i)*sqrt(3)],'color',[0 0 0]) ; % Clay axis
        text(5*i-2*sqrt(3),(5*i)*sqrt(3),num2str(10*i),'Rotation',0,'HorizontalAlignment','right',...
            'FontSize',fontsize_a,'VerticalAlignment','bottom');
end
plot([0 100],[0 0],'k',0:50,sqrt(3).*(0:50),'k',50:100,sqrt(3).*(50:-1:0),'k'); % one more
% Soil Classification plot
linewidth_c = 2 ;
linecolor = [1 0 0 ] ;
plot([5 15],[5*sqrt(3) 0],'color',linecolor,'linewidth',linewidth_c) ; % 01
plot([7.5 30],[7.5*sqrt(3) 0],'color',linecolor,'linewidth',linewidth_c) ; % 02
plot([10 37.5],[10*sqrt(3) 10*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 03
plot([37.5 43.75],[10*sqrt(3) 3.75*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 04
plot([43.75 53.75 ],[3.75*sqrt(3) 3.75*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 05
plot([50 63.75],[0 13.75*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 06
plot([37.5 41.25],[10*sqrt(3) 13.75*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 07
plot([41.25 27.5 ],[13.75*sqrt(3) 27.5*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 08
plot([41.25 86.25],[13.75*sqrt(3) 13.75*sqrt(3) ],'color',linecolor,'linewidth',linewidth_c) ; % 09
plot([17.5 37.5],[17.5*sqrt(3) 17.5*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 10
plot([35 80],[20*sqrt(3) 20*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 11
plot([60 70],[20*sqrt(3) 30*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 12
plot([60 66.25],[20*sqrt(3) 13.75*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 13
plot([80 86.25],[0 6.25*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 14
plot([86.25 93.75],[6.25*sqrt(3) 6.25*sqrt(3)],'color',linecolor,'linewidth',linewidth_c) ; % 15
 
dis = 15 ; % distance between label and chart
axis off
%% Legend, Label
title('Soil Texture Triangle','FontSize',15)
 
%% Text
% Sand
text('String','Sand (%)','Rotation',0,'Position',[50 -1*dis],...
    'HorizontalAlignment','center',...
    'FontSize',10,...
    'FontName','HY??B',...
    'EdgeColor',[0 0 0],...
    'Color',[1 1 0],...
    'BackgroundColor',[0 0 0]);
% Clay   
text('String','Clay (%)','Rotation',60,'Position',[25-dis/1.5 25*sqrt(3)+dis/1.5],...
    'HorizontalAlignment','center',...
    'VerticalAlignment','bottom',...
    'FontSize',10,...
    'FontName','HY??B',...
    'EdgeColor',[0 0 0],...
    'Color',[0.4 0.8 1],...
    'BackgroundColor',[0 0 0]);
% Silt
text('String','Silt (%)','Rotation',-60,'Position',[75+dis/1.5 25*sqrt(3)+dis/1.5],...
    'HorizontalAlignment','center',...
    'VerticalAlignment','bottom',...
    'FontSize',10,...
    'FontName','HY??B',...
    'EdgeColor',[0 0 0],...
    'Color',[1 0 0],...
    'BackgroundColor',[0 0 0]);
Fontsize_soil = 7 ;   
color_soil = [0.2 0.2 0.2] ;
% text : 01. sand
text('String','sand','Position',[6 3],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 02. loamy sand
text('String','loamy','Position',[15 5],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
text('String','sand','Position',[17 2],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 03. sandy loam
text('String','sandy loam','Position',[30 10],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 04. sandy clay loam
text('String','sandy clay loam','Position',[26 22],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 05. loam
text('String','loam','Position',[49 15],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 06. silt loam
text('String','silt loam','Position',[72 12],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 07. silt
text('String','silt','Position',[90 5],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 08. sandy clay
text('String','sandy','Position',[28 38 ],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
text('String','clay','Position',[28 35 ],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 09. clay loam
text('String','clay loam','Position',[52 29 ],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 10. silty clay loam
text('String','silty','Position',[72 31 ],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
text('String','clay loam','Position',[74 28 ],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 11. clay
text('String','clay','Position',[50 55],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
% text : 12. silty clay
text('String','silty','Position',[70 42],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
text('String','clay','Position',[70 39],'HorizontalAlignment','center','VerticalAlignment','Middle',...
    'FontSize',Fontsize_soil,'Color',color_soil);
 
%% Arrow
 
% Create arrow
annotation(figure(1),'arrow',[0.626 0.419],[0.092 0.092]);
annotation(figure(1),'arrow',[0.234 0.337],[0.517 0.750]);
annotation(figure(1),'arrow',[0.688 0.798],[0.758 0.510]);
 
%% Soil Point
 
plot(x ,y ,'.','MarkerSize',15,'Color',[0.5 0.6 1] )
time = toc;
fprintf('Time consumed %4.3f second\n',time)
 
%% OUTPUT
 
output.soil_texture = soil;
output.soil_index = soil_n ;
output.soil_A = A ;
 