%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   ISLSCP Soil hydrology parameters  (Sellers et al., 1995, Moorcroft et al., 2001)
%   
%   Type of soil: Stype == 1 (coarse), 
%                       == 2 (medium/coarse)
%			== 3 (medium)
%			== 4 (fine/medium)
%			== 5 (fine) 
%			== 6 (organic) 
%		
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [hb,thetamax,thetamin,Ksat,tauS,Water] = SoilWater(Stype)

if Stype == 1        % Coarse soil
	dg       = 20;          %  Bulk diameter (geometric mean particul size [cm]
	hb       = 5*dg^-0.5;   %  Bubling pressure [cm]
    	thetamin = 0.025;       %  resudual soil moisture [cm3/cm3]
    	thetamax = 0.0363;      %  Maximum soil moisture [cm3/cm3]
	Ksat     = 14.1E-6;     %  Saturated hydraulic conductivity [m/s]
	tauS     = 4.26;        %  Empirical parameter governing the rate at which conductivty devreases as saturation level decreases[cm3/cm3]

elseif Stype == 2    % medium/coarse soil
	dg       = 5;           
    	hb       = 5*dg^-0.5; 
    	thetamin = 0.01;        
    	thetamax = 0.1413;
	Ksat     = 5.23E-6;
	tauS     = 4.74; 
	
elseif Stype == 3   % medium soil
	dg       = 0.6;           
    	hb       = 5*dg^-0.5; 
    	thetamin = 0.01;        
    	thetamax = 0.3548;
	Ksat     = 3.38E-6;
	tauS     = 5.25;
	
elseif Stype == 4   %  fine/medium soil
	dg       = 0.1;           
    	hb       = 5*dg^-0.5; 
    	thetamin = 0.025;        
    	thetamax = 0.1349;
	Ksat     = 4.45E-6;
	tauS     = 6.67;
	
elseif Stype == 5   %  fine soil
	dg       = 2*10^-2;           
    	hb       = 5*dg^-0.5; 
    	thetamin = 0.01;        
    	thetamax = 0.263;
	Ksat     = 2.45E-6;
	tauS     = 8.17;
	
elseif Stype == 6   %  organic soil
	dg       = 10^-3;           
    	hb       = 5*dg^-0.5;     
    	thetamin = 0.01;        
    	thetamax = 0.354;
	Ksat     = 3.38E-6;
	tauS     = 5.25;
end

%   Initial water availability in the soil [mm] = [kg/m2]
    Water = 100;

			
    
