function [Thin,Nthin,N] = Thinning(dEdN,dEdz,N,S,Ssize,LMA,TD,PFTs,strategy)

CO = 0.99;
%   Thin dominant if canopy cover <= 0.01%
if strategy == 1
    Thin = 0;    
    Nthin = 0;

%   Do not thin if the canopy openness is higher than 5%
elseif strategy > 1 && dEdz(2,1)> CO
    Thin = 0;    
    Nthin = 0;

%   Thin all trees belonging to the dominant plant functional trait 
%   syndrome PFT

elseif strategy == 2 && dEdz(2,1)<= CO
    [~,position] = min(dEdN);
    Nthin = sum(N(3:1+S(position,1),position));
    for i = 2:1+S(position,1)
        N(i,position) = 0;
    end
    Thin = position;
    
%   If canopy cover <= 5%, thin all trees belonging to the dominant plant 
%   functional trait syndrome selectively increase the average density of
%   timber produced by the forest.

elseif strategy == 3 && dEdz(2,1)<= CO
    [~,position]=sort(dEdN,'ascend');
    for i = 1:size(N,2)
        if PFTs((position(1,i)-1),1) >= TD
            continue
        elseif PFTs((position(1,i)-1),1) < TD
            value = position(1,i);
            break
        end
    end
    Nthin = sum(N(3:1+S(value,1),value));
    for i = 2:1+S(value,1)
        N(i,value) = 0;
    end
    Thin = value;    
    
%   If canopy cover <= 5%, thin all trees belonging to the dominant plant 
%   functional trait syndrome selectively increase the average mass of 
%   seeds produced by the forest.

elseif strategy == 4 && dEdz(2,1)<= CO
    [~,position]=sort(dEdN,'ascend');
    for i = 1:size(N,2)
        if PFTs((position(1,i)-1),3) >= Ssize
            continue
        elseif PFTs((position(1,i)-1),3) < Ssize
            value = position(1,i);
            break
        end
    end
    Nthin = sum(N(3:1+S(value,1),value));
    for i = 2:1+S(value,1)
        N(i,value) = 0;
    end
    Thin = value;
    
%   If canopy cover <= 5%, thin all trees belonging to the dominant plant 
%   functional trait syndrome selectively increase the average mass area of 
%   leaves produced by the forest.

elseif strategy == 5 && dEdz(2,1) <= CO
    [~,position]=sort(dEdN,'ascend');
    for i = 1:size(N,2)
        if PFTs((position(1,i)-1),2) >= LMA
            continue
        elseif PFTs((position(1,i)-1),2) < LMA
            value = position(1,i);
            break
        end
    end
    Nthin = sum(N(3:1+S(value,1),value));
    for i = 2:1+S(value,1)
        N(i,value) = 0;
    end
    Thin = value;

%% Diversity thinning 1    
elseif strategy == 6 && dEdz(2,1) <= CO   
   
    
    
    
%%%%%%%%%%%%%%%%%%%%%%   Other possible thinning strategies %%%%%%%%%%%%    
    
%   If canopy cover <= 0.5, Thin until reaching certain tree height 
%   (e.g., hmax = 20m), Then back to strategy 2: 

end




