function [Sfuel,Nfuelalive,BNdebris,N] = ThinningFirewood(NumberHH,SizeHH,Access,Farea,Nforestpatches,PFTs,N,height,s,nLMA,rLMA,LMAmin,LMAmax,Language,BNdebris,Hrestrictionfire)
                                                         
% rLMA = resolution of saliance for colour rLMA = nLMA + 1
Parameters
[~,~,Bbr,Btr,~,~,~,~,~,~,~,~,~,~] = Allometry(PFTs,height,s,0);

% AfT: area of forest [m2]
%NumberHH = Social(1,1);    % Number of household that have access to this patch of forest
%SizeHH = Social(2,1); % Average Size of household
%Access = Social(3,1); % Average access rate per household
Bbrdebris = BNdebris(:,:,2); 
Btrdebris = BNdebris(:,:,3); 
TD = ones(size(height,1),1)*PFTs(:,1)';
LMA = ones(size(height,1),1)*PFTs(:,2)';

%%  Fuelwood collection

%       D.1 - Annual Household fuelwood collection [kg]
%           Country: Nepal, District: Dhading (Webb & Dhakal, 2011). - Patterns and drivers of fuelwood collection and tree planting in a Middle Hill watershed of Nepal
%           Average SizeHH = 6.5 +- 2.8  % demand in fuelwood / individual = average 500: 200 - 1000 [kg/capita/yr]
Bfuelwood = SizeHH.*(899.24 - SizeHH.*34.68).*NumberHH./Nforestpatches;  % negative component means that household needs less energy per capita when the household size is bigger.

%       D.2 - Preference in species collection given the TD of the species of interest
%               The Fuel Value Index (FVI)is a simple and practical instrument for
%               predicting the local preference for fuelwood species in a community (Ramos et al., 2008).
%               (with FVI = CaloricValue*WetDensity/MoistureContentent ~ preference)
%           Country: Brazil, State:Pernambuco (Ramos et al., 2008) - 
FVI = 0.0475.*TD - 11.424;
FVIindex = sum(sum(unique(FVI','rows')))/size(sum(unique(FVI','rows')),2);
FW_pref_TD = FVI/FVIindex;
%   or based on rank
%FVIrank = -0.0711.*TD + 62.454;
%FW_pref_sp = (0.2564.*FVI(1,:) + 3.2438)./sum(0.2564.*FVI(1,:) + 3.2438);
%FW_pref_TD = repmat(FW_pref_sp,);
% D.3 - Preference in size classes collection (x-axis: dbh classes [cm], y-axis: percentage trees lopped)
% Country: Nepal, District: Bardia & Banke (Thapa & Chapman, 2010)
% stemsize = beta9*dbh.^alpha9: transform dbh into stem size using alpha9 and beta9 scaling parameters
% Gamma distribution (x-axis = diameter classes, y-axis = probability cutting): y0*(1/(sigma*sqrt(2*3.14)*(x-xc)))*exp(-((ln(x-xc)-lambda)^2)/(2*sigma^2))
% GoF using SCiDavis: Unscaled Levenberg-Marquardt algorithm with tolerance = 0.0001
% From x = 5 to x = 105
% sigma  = 1.23031878030423 +/- 0.00800947337010023
% xc  = 4.10554809840698 +/- 0.0299885199532434
% lambda  = 3.38095546181322 +/- 0.00473001543985604
% y0  = 12.4304951395289 +/- 0.0557722103065449
% Chi^2/doF = 0.00052336648184774
% R^2 = 0.942748658755113
dbh = (height.^(1./alpha9))./(beta9.^(1./alpha9));
dbh(dbh < 4.106/100) = 4.2/100;
FW_pref_size = real(12.43.*(1./(1.23*sqrt(2*3.14).*(dbh*100 - 4.106))).*exp(-((log(dbh*100 - 4.106) - 3.381).^2)./(2.*1.23^2)));
FW_pref_size(1:2,:) = 0; % set 0 diameter for seeds and seedlings
FW_pref_size(FW_pref_size < 0 | FW_pref_size > 1) = 0;

%   D.4 - Restriction on slow-growing species
X = LMAmin:(LMAmax - LMAmin)/(nLMA - 1):LMAmax;
Y = 0:1/(size(X,2)-1):1;
Y = fliplr(Y);
%   Estimate slope and intercept
p=polyfit(X,Y,1);

%   Change resolution of perception
if Language == 1
    pLMA = (p(1,1).*LMA + p(1,2)); %./sum(sum(p(1,1).*LMA + p(1,2)));
elseif Language > 1
    LMAstock = (p(1,1).*LMA + p(1,2));
    for i = LMAmin:(LMAmax - LMAmin)/(rLMA - 1):LMAmax
        LMAstock(LMAstock > i-0.1 & LMAstock <= i) = i;
    end
    pLMA = LMAstock; %./sum(sum(LMAstock));
end

%   Sum
FWrestrict = 1; %pLMA;
FWpref1 = FW_pref_TD.*FW_pref_size.*FWrestrict;
FWpref = FWpref1./sum(sum(FWpref1));

%   Populate a matrix of individual trees that are thinned for fuelwood
% rural demand for fuelwood do not induce deforestation, as when
% there is not enough wood, people move outside the forest to get
% trees or use alternative sources of fuel (deadwood, pruning, coppicing, dung). So model here
% consider that people take the maximum they can under the required wood characteristics.
% Estimate the Biofuel Supply harvested
FWneeds = Access*(Bfuelwood/Nforestpatches);

%   Harvesting of deadwood first
FWmaxstockdead = sum(sum((Farea./Nforestpatches).*(Bbrdebris + Btrdebris))); %[kg]
FWneedsdead = sum(sum(FWpref.*FWneeds)); %[kg]
if  FWneedsdead >= FWmaxstockdead
    %display('FWneedsdead >= FWmaxstockdead')
    %   Supplement by thinning on alive trees
    FWneeds_N = FWpref.*FWneeds - (Farea./Nforestpatches).*(Bbrdebris + Btrdebris); %[kg]    
    FWneeds_N(FWneeds_N<0) = 0;
    FWmaxstock_N = N(2:size(N,1),:).*(ones(size(height,1),1)*Hrestrictionfire).*(Farea./Nforestpatches).*(Bbr + Btr); %[kg]  % multiply by 2 to get total dry mass from dry carbon mass
    FWratio = FWneeds_N./FWmaxstock_N;
    FWratio(FWratio > 1) = 1;
    FWratio(isnan(FWratio)) = 0;
    FWratio(~isfinite(FWratio)) = 0;
    %   Update size class community vector after harvesting
    Nfuelalive = N(2:size(N,1),:).*FWratio;
    N(2:size(N,1),:) = N(2:size(N,1),:) - Nfuelalive;  %Dimensionless [0 - inf[    
    FWharvested = FWmaxstock_N.*FWratio; % max stock
    %   Estimate 
    FWsupply = (FWharvested + (Btrdebris + Bbrdebris)).*Farea;
    %   Update dead biomass stock
    Bbrdebris(Bbrdebris >= 0) = 0; 
    Btrdebris(Btrdebris >= 0) = 0;   
elseif FWneedsdead < FWmaxstockdead
    %display('FWneedsdead < FWmaxstockdead')
    Nfuelalive = zeros(size(N,1)-1,size(N,2));
    FWsupply = FWpref.*FWneeds;
    %   Update dead biomass stock
    Rdead = FWneedsdead./(sum(sum(((Farea./Nforestpatches).*Bbrdebris + Btrdebris))));    
    Bbrdebris = (1 - Rdead).*Bbrdebris;
    Btrdebris = (1 - Rdead).*Btrdebris;    
end

%%  Outputs
%   Total firewood supply
Sfuel = FWsupply;
%   Deadwood stock after harvesting
BNdebris(:,:,2) = Bbrdebris;
BNdebris(:,:,3) = Btrdebris;

%% REFERENCES

%   Ramos, M. A., Medeiros, P. M. D., Almeida, A. L. S. D., Feliciano, A. L. P., & Albuquerque, U. P. D. (2008). Can wood quality justify local preferences for firewood in an area of caatinga (dryland) vegetation?. Biomass and Bioenergy, 32(6), 503-509.
%   Thapa, S., & Chapman, D. S. (2010). Impacts of resource extraction on forest structure and diversity in Bardia National Park, Nepal. Forest Ecology and Management, 259(3), 641-649.