% Vf: Volume of timber in the forest at time t
% Vt: Volume of timber harvested at the time of the harvest
% r1: discount rate for timber price
% g1: historical annual growth rate of real timber price
% Pt: Price of timber at the time of the harvest

% Vf: Volume of food (fruits) harvested at the time of the harvest
% Vd: Volume of plant for drug compounds extracted at the time of the
% harvest

% Pc: Price of the tonne of carbon (fixed at $23 AUD/tonne until 2015) then
% flexible
% Pf: Price of food sold outside at the time of the harvest (assume no
% storage possibilities and sold directly as harvested)
% Pd: price of drug, assuming constant price.

% g2: historical annual growth rate of real carbon price
% h: rotation length of the stand
% Cl: Cost of owning an hectar of land at time t
% Cr: Index of reforestation costs, initially set equal to 1
% R: Cost of restoration 
% L: hectares of land in ownership
% w: weighting factor 1, 2 and 3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function U = Utility(L,Cr,Cl)
% Costs of owning and managing the forest stand
C  = R*Cr*L + (Cl*L/r1)*(1 - exp(-rl*h));
Yt = sum(Vt*Pt*exp((gt-rt)*h),1); % Timber (hard&softwood for pulp, saw)
Yb = Vt*Pt*exp((ge-re)*h); % biofuel
Yc = TOC*Pc*exp((gc-rc)*h); % Carbon sequestration
Yf = sum(Vh*Pf*exp((gf-rf)),1); % 
Yd = sum(Vd*Pd*exp((gd-rd)),1); 
% Incomes generated from provisioning services
Yprovisioning = Yt + Yf + Yd + Yb;
Yregulating = Yc;
Ycultural = 0;
Y = Yprovisioning + Yregulating + Ycultural - C;
U = w1*H + w2*Y;

