clear
format short G
tic

%% INPUTS

%%  PHYSICAL CONDITIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Give the time horizon [years] for which you want to maximize carbon sequestration
Tmax  = 100;
% 	Location (lattitude / longitude)
Lat    = -27.467778;
Long   = 153.027778;
%   IPCC Climate change severity: low severity (wet-hot) == 1 , high severity (arid-hot) == 2
Climmax = 1;
%   Upland == 1 , Upland then Lowland == 2
Landmax  = 1;
%	Unit of area at which the cobenefits are estimated [m2]
Farea = 10000;
%   Baseline Number of forest patches for Farea (~ level of fragmentation)
Nforestpatches = 1;
%	Initial state of the forest to restore: SF == n: n PFTs already present in the forest (n == 0: no forest)
Fregrowth = 0;
%	Surrounding forests (important for seed colonization): SC == 0: no, SC == 1: yes.
Fsurroundings = 1;
%   Soil elements for the 1st 30cm of soil (sand, clay, silt, with sand + clay + silt = 1)
Sand = 0.5;
Clay = 0.3;
Silt = 1 - (Sand + Clay);
% do you consider the soil as organic (e.g., Peat)? Yes: 1, No:0
Organic = 0;
SoilElements = [Sand Clay Silt Organic];
%   Soil depth [m]
SoilDepth = 3;      % usually soils are 1-10m thick

%%  1. BIOLOGICAL SYSTEM
%   1.1 - UNIVERSE OF PLANT FUNCTIONAL TRAITS (PFTs), including the Range [min-max] & resolution [n] for every PFT: Stem density [kg/m3] (Maximum average stem density for a species)
Timbermin = 400;   %300
Timbermax = 1000;  %1000
nTimber   = 2;     %number of density classes
% 	Leaf economy [kg/m2] (Maximum average LMA for a species)
LMAmin    = 0.05;  %0.05
LMAmax    = 0.35;  %0.35
nLMA      = 2;     % number of density classes
% 	Seed size [kg] (average seed mass at maturity for a species)
Seedmin   = 10^-7; %10^-7
Seedmax   = 10^-4; %10^-3
nSeed     = 2;    % number of mass classes from Ssizemin to Ssizemax

%%  PRACTICE
%   Do you want to optimize planting (Optimalplanting = 1) or predict consequences of existing behaviours (Optimalplanting = 0)
Optimalrestoration = 0;

%   Answer these questions below if and only if you chose Optimalplanting = 1:

%   Number of planting strategy you want to test: doing nothing 1, Framework Functional Trait (FFT), Maximum Functional Diversity (MFD
Plantmax = 2; %6
%   Density of planting per ha
Nplant = 1/2;
%   Thinning of dominant PFTS if canopy openness < 1%; 3 = Yes all individuals of dominant PFTS
ThinDivmax = 2; %4
%   Thinning frequency (1: every years, 2: every two years ...)
ThinFreqmax = 2; %50
%   Baseline Management efficiency: planting, weeding, pruning, etc ... (best = families; communities and state less good)
Efficient_manager = 1;
%   Baseline Monitoring efficiency: poaching ... (best = communities, less good = individual families and state less good)
Efficient_monitor = 1;

%%  ECONOMIC SYSTEM
%   Probability selling timber
Pselltimber = 1;
%   Baseline Proportion of trees planted for respectively firewood, timber, ntfp (fruits ...):
Eplanting = [.5 .25 .25];

%%  SOCIAL SYSTEM
%   Number of household that have access to this patch of forest
NumberHH = 1;
%   Average Size of household (number of members per households)
SizeHH = 5;
%   Average access rate per household (no access: 0, open access:1)
Access = 1;
%   NB: need to distinguish Access rate for timber, firewood, etc ...

%%  LINGUISTIC SYSTEM
Langmax = 1;

%% OUTPUTS TO BE DISPLAYED ON FIGURE
%           Carbon == 1: Total organic carbon in the forest (TOC)
%           Carbon == 2: Above-ground organic carbon (AGOC)
%           Carbon == 3: Litter organic carbon (LOC)
%           Carbon == 4: Soil organic carbon (SOC)
%           Carbon == 5: Total organic carbon excluding litter (TOC - LOC)
Tcarbon = 1;

%%  STORE INPUT VARIABLES
Physics = [Tmax Lat Long Climmax Landmax Farea Nforestpatches Fregrowth Fsurroundings SoilElements SoilDepth]';
Biology = [Timbermin Timbermax nTimber LMAmin LMAmax nLMA Seedmin Seedmax nSeed]';
Economics = [Pselltimber Eplanting]';
Social = [NumberHH SizeHH Access]';
Practice = [Plantmax Nplant ThinDivmax ThinFreqmax Optimalrestoration Efficient_manager Efficient_monitor]';
Linguistics = [Langmax]';
Outputs = [Tcarbon]';
Tmax = Physics(1,1);
Lat = Physics(2,1);
Long = Physics(3,1);
Climmax = Physics(4,1);
Landmax = Physics(5,1);
Farea = Physics(6,1);
Nforestpatches = Physics(7,1);
Fregrowth = Physics(8,1);
Fsurroundings = Physics(9,1);
SoilElements = Physics(10:13,1);
SoilDepth = Physics(14,1);

%   Biology
Timbermin = Biology(1,1);
Timbermax = Biology(2,1);
nTimber = Biology(3,1);
LMAmin = Biology(4,1);
LMAmax = Biology(5,1);
nLMA = Biology(6,1);
Seedmin = Biology(7,1);
Seedmax = Biology(8,1);
nSeed = Biology(9,1);

%   Practice
Plantmax = Practice(1,1);
Nplant = Practice(2,1);
ThinDivmax = Practice(3,1);
ThinFreqmax = Practice(4,1);
Optimalrestoration = Practice(5,1);
Efficient_manager =  Practice(6,1);
Efficient_monitor =  Practice(7,1);

%   Economy
Pselltimber = Economics(1,1);
Eplanting = Economics(2:4,1);

%   Social
NumberHH = Social(1,1);
SizeHH = Social(2,1);
Access = Social(3,1);

%   Linguistics
Detectionlevelmax = Linguistics(1,1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%   Call a set of parameters

Parameters;
s = 5; %s comes from Parameters: try to do better to call it from Parameters for a parfor loop
%%   Dimensions of the Output matrix of outputs
BCD = zeros(Tmax+1,15,Plantmax*ThinDivmax*ThinFreqmax*Climmax);

%%   Populate the Duration of management
c = clock;
ystart = c(1,1);
yend   = ystart + max(Tmax);
tlimit = yend - ystart;

%%   Populate all necessary matrices and vectors that match when, what and how many PFTs syndromes to plant
[PFTs,nPFTS,PFTby,hsg,hmat,hbymin,smax,S,height] = Dimensions(Timbermin,Timbermax,nTimber,LMAmin,LMAmax,nLMA,Seedmin,Seedmax,nSeed);

%%   Set up the matrix (Hmatrix) that provides all the combinations of harvesting species (1 row = 1 combination of species to thin)
if Optimalrestoration == 0
    Hmatrix = ones(2^nPFTS,nPFTS);
    p = 1;
    for c = 0:nPFTS-1
        Hmatrix(p+1:2*p,nPFTS-c:nPFTS) = [zeros(p,1),Hmatrix(1:p,nPFTS-c+1:nPFTS)];
        p = 2*p;
    end
    ManDivmax = size(Hmatrix,1);
else
    Hmatrix = zeros(ThinDivmax*ThinFreqmax,2);
    for j = 1:ThinDivmax*ThinFreqmax
        Hmatrix(j,1) = mod(floor((j-1)/(ThinFreqmax)),ThinDivmax) + 1 ;
        Hmatrix(j,2) = mod(j-1 + ThinFreqmax*ThinDivmax,ThinFreqmax) + 1 ;
    end
    ManDivmax = size(Hmatrix,1);
end
ManDivmax

%% Preload variables
tic
%[ClimSeries,MAT,MAT0,D,D0] = IPCC(Tmax,Climmax,Lat,Long); %	Defines the IPCC climate projections
toc
Dimmax = Climmax*Landmax*Detectionlevelmax*ManDivmax;
Dimmax
MAT0 = zeros(2,1);
D0 = zeros(2,1);
for i = 1:Dimmax
    
    %%  Defines main external variables (climate, landscape position, management strategy, people's PFT perception abilities, etc ...)
    %   Populate climate type (Arid / Wet)
    k =  mod((i - 1) + Climmax*Landmax*Detectionlevelmax,Climmax) + 1;
    k = 1
    %   Populate position in the catchment (upland / lowland)
    l = mod(floor((i - 1)/(Climmax)),Landmax) + 1;
    l = 1
    %   Populate the management strategy
    m = mod(floor((i - 1)/(Climmax*Landmax*Detectionlevelmax)),ManDivmax) + 1;
    
    
    
    str = mat2str(Hmatrix(m,:));
    title1 = strcat('Clim',int2str(k),'Landscape',int2str(l),'Thin',str);
    title2 = strcat('C',int2str(k),'L',int2str(l),'_',str);
    title2 = regexprep(title2,'[^\w'']','');
    data = load(title1);
    xlswrite(title2,data);
    %copyfile(title1,title2)
end