######################## Create Data ##############################
BCDdata <- function(lower, upper) {

species.tmp <- read.table("Hmatrix.csv" , sep=",") 

BioculturalData <- NULL
PFDsummary <- NULL
AGOCsummary <- NULL
STsummary <- NULL
Dollarsummary <- NULL

for (j in 1:2) {
  for (i in 1:178) { #256
    dataFrame.tmp <- NULL
    l <- paste(species.tmp[i,],collapse="")
    filename <- paste("C1L", j,"_",i,"_",l, sep="")
    #print(paste("Reading file:", filename))
    dataFrame.tmp <- read.table(filename, sep=",")  
    dataFrame.tmp <- dataFrame.tmp[-1,]
    dataFrame.tmp$Year <- 1:100
    dataFrame.tmp$Sp1 <- species.tmp[i,1]
    dataFrame.tmp$Sp2 <- species.tmp[i,2]
    dataFrame.tmp$Sp3 <- species.tmp[i,3]
    dataFrame.tmp$Sp4 <- species.tmp[i,4]
    dataFrame.tmp$Sp5 <- species.tmp[i,5]
    dataFrame.tmp$Sp6 <- species.tmp[i,6]
    dataFrame.tmp$Sp7 <- species.tmp[i,7]
    dataFrame.tmp$Sp8 <- species.tmp[i,8]
    Nspecies <- species.tmp[i,1] + species.tmp[i,2] + species.tmp[i,3] + species.tmp[i,4] + species.tmp[i,5] + species.tmp[i,6] + species.tmp[i,7] + species.tmp[i,8]
    
    dataFrame.tmp$scenario <- i
    
    if (j == "1") {
      dataFrame.tmp$habitat <- "upland"
    } else {
      dataFrame.tmp$habitat <- "lowland"
    }
    
    if (is.null(BioculturalData)) {
      BioculturalData <- dataFrame.tmp
    } else {
      BioculturalData <- rbind(BioculturalData, dataFrame.tmp)
    }
    
  }
}

names(BioculturalData) <- c("PFD",	"AGOC",	"SOC",	"dAGOC",	"dSOC",	"dTOC",	"STD",	"LMA",	"SS",	"LAI",	"Height",	"Water",	"SupplyTimber",	"SupplyFire",	"Dollar", "Year","Sp1", "Sp2", "Sp3", "Sp4", "Sp5", "Sp6", "Sp7", "Sp8", "scenario", "habitat")
BioculturalData$Nspecies <- BioculturalData$Sp1 + BioculturalData$Sp2 + BioculturalData$Sp3 + BioculturalData$Sp4 + BioculturalData$Sp5 + BioculturalData$Sp6 + BioculturalData$Sp7 + BioculturalData$Sp8
BioculturalData$PFDscalled <- BioculturalData$PFD / max(BioculturalData$PFD)
BioculturalData <- BioculturalData[c("habitat","scenario", "Nspecies", "Sp1", "Sp2", "Sp3", "Sp4", "Sp5", "Sp6", "Sp7", "Sp8", "Year", "PFD",	"PFDscalled","AGOC",	"SOC",	"dAGOC",	"dSOC",	"dTOC",	"STD",	"LMA",	"SS",	"LAI",	"Height",	"Water",	"SupplyTimber",	"SupplyFire",	"Dollar")]

############ Summary statistics ##########
sum.ST <- aggregate(SupplyTimber ~ habitat + scenario + Nspecies, BioculturalData, FUN = sum)
sum.ST$SupplyTimber <- sum.ST$SupplyTimber/100
sum.Dollar <- aggregate(Dollar ~ habitat + scenario + Nspecies, BioculturalData, FUN = sum) 
sum.Dollar$Dollar <- sum.Dollar$Dollar/100

mean.PFD <- aggregate(PFD ~ habitat + Nspecies, BioculturalData, FUN = mean) 
mean.AGOC <- aggregate(AGOC ~ habitat + Nspecies, BioculturalData, FUN = mean)
mean.ST <- aggregate(SupplyTimber ~ habitat + Nspecies, sum.ST, FUN = mean)
mean.Dollar <- aggregate(Dollar ~ habitat + Nspecies, sum.Dollar, FUN = mean) 

quantiles.PFD <- aggregate(PFD ~ habitat + Nspecies, BioculturalData, function(x) quantile(x, c(lower, upper))) 
lowerq.PFD <- quantiles.PFD$PFD[,1]
upperq.PFD <- quantiles.PFD$PFD[,2]

quantiles.AGOC <- aggregate(AGOC ~ habitat + Nspecies, BioculturalData, function(x) quantile(x, c(lower, upper))) 
lowerq.AGOC <- quantiles.AGOC$AGOC[,1]
upperq.AGOC <- quantiles.AGOC$AGOC[,2]

quantiles.ST <- aggregate(SupplyTimber ~ habitat + Nspecies, sum.ST, function(x) quantile(x, c(lower, upper))) 
lowerq.ST <- quantiles.ST$SupplyTimber[,1]
upperq.ST <- quantiles.ST$SupplyTimber[,2]

quantiles.Dollar <- aggregate(Dollar ~ habitat + Nspecies, sum.Dollar, function(x) quantile(x, c(lower, upper))) 
lowerq.Dollar <- quantiles.Dollar$Dollar[,1]
upperq.Dollar <- quantiles.Dollar$Dollar[,2]

PFDsummary <- data.frame(mean.PFD, lowerq.PFD, upperq.PFD)
names(PFDsummary) <- c("habitat", "Nspecies", "mean", "lower", "upper")
AGOCsummary <- data.frame(mean.AGOC, lowerq.AGOC, upperq.AGOC)
names(AGOCsummary) <- c("habitat", "Nspecies", "mean", "lower", "upper")
STsummary <- data.frame(mean.ST, lowerq.ST, upperq.ST)
names(STsummary) <- c("habitat", "Nspecies", "mean", "lower", "upper")
Dollarsummary <- data.frame(mean.Dollar, lowerq.Dollar, upperq.Dollar)
names(Dollarsummary) <- c("habitat", "Nspecies", "mean", "lower", "upper")

############ Outputs #############
output <- list()
output$BioculturalData <- BioculturalData
output$PFDsummary <- PFDsummary
output$AGOCsummary <- AGOCsummary
output$STsummary <- STsummary
output$Dollarsummary <- Dollarsummary
return(output)
}

######################### Figure 2 ###############################
plotfig2 <- function(Dataframe, Habitat, graphlabelx = F, graphlabely = F, annotation="", title = F) {

  if (Habitat == "upland") {
    DataFrame.hab <- subset(Dataframe, habitat == "upland")
  } else if (Habitat == "lowland"){
    DataFrame.hab <- subset(Dataframe, habitat == "lowland")
  }
  
p2 <- ggplot(DataFrame.hab, aes(x = PFD, y = AGOC)) + 
  geom_point() +
  scale_x_continuous(expand=c(0,0), limits = c(0,ceiling(max(DataFrame.hab$PFD))), breaks=seq(0,ceiling(max(DataFrame.hab$PFD)),.5)) +
  scale_y_continuous(expand=c(0,0), limits = c(0, round_any(max(DataFrame.hab$AGOC),100, f = ceiling)), breaks=seq(0,round_any(max(DataFrame.hab$AGOC),100, f = ceiling),100)) +
  {if (Habitat == "upland") {
    annotate(geom="text", x= .05, y = round_any(max(DataFrame.hab$AGOC),100, f = ceiling)*95/100, label="a)")
  } else if (Habitat == "lowland") {
    annotate(geom="text", x= .05, y = round_any(max(DataFrame.hab$AGOC),100, f = ceiling)*95/100, label="b)")
  }} + 
  
  {if (title == T){
    
    if (Habitat == "upland"){
      ggtitle("Upland") 
    } else if (Habitat == "lowland"){
      ggtitle("Lowland")} 
  } else {
    ggtitle("   ")}
  } +
  
  theme_bw() +
  theme(text = element_text(size=13), 
        axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_blank(),
        legend.position = c(.22, .30),
        legend.box = "vertical",
        legend.background = element_blank(),
        legend.key = element_blank(),
        legend.text=element_text(size=9),
        legend.key.size = unit(.7, 'lines'),
        plot.title = element_text(hjust = 0.5)
  ) 
  xlab("Plant Functional Trait Diversity \n\ (Shannon Index)")
  ylab(bquote(Mg.ha^-1~CO[2]~eq.))
   
return(p2)
}

######################### Figure 3 ###############################
plotfig3 <- function(Dataframe, Variable, Habitat, graphlabelx = F, graphlabely = F, annotation="", title = F) {
  
  if (Habitat == "upland") {
    Dataframe.hab <- subset(Dataframe, habitat == "upland")
  } else if (Habitat == "lowland") {
    Dataframe.hab <- subset(Dataframe, habitat == "lowland")
  }
  
  if (Variable == "PFD" & Habitat == "upland"){
    fscale = 1
    by = 4
    plabel <- "a)"
    ylabs <- "PFT diversity (Shannon)"
  } else if(Variable == "AGOC" & Habitat == "upland"){
    fscale = 100
    by = 3
    plabel <- "c)"
    ylabs <- bquote(Mg.ha^-1~y^-1~CO[2]~eq.)
  } else if(Variable == "SupplyTimber" & Habitat == "upland"){
    fscale = 1000
    by = 4
    plabel <- "e)"
    ylabs <- bquote(Kg.ha^-1)
  } else if(Variable == "Dollar" & Habitat == "upland"){
    fscale = 1000
    by = 4
    plabel <- "g)"
    ylabs <- bquote(USD.ha^-1~y^-1~CO[2]~eq.)
  } else if(Variable == "PFD" & Habitat == "lowland"){
    fscale = 1
    by = 4
    plabel <- "b)"
    ylabs <- "PFT diversity (Shannon)"
  } else if(Variable == "AGOC" & Habitat == "lowland"){
    fscale = 100
    by = 3
    plabel <- "d)"
    ylabs <- bquote(Mg.ha^-1~y^-1~CO[2]~eq.)
  } else if(Variable == "SupplyTimber" & Habitat == "lowland"){
    fscale = 1000
    by = 4
    plabel <- "f)"
    ylabs <- bquote(Kg.ha^-1)
  } else if(Variable == "Dollar" & Habitat == "lowland"){
    fscale = 1000
    by = 4
    plabel <- "h)"
    ylabs <- bquote(USD.ha^-1~y^-1~CO[2]~eq.)
  } 
  
  yannot <- round_any(max(Dataframe$upper), fscale, f = ceiling) - round_any(max(Dataframe$upper), fscale, f = ceiling)*0.05
  if (max(Dataframe$upper) > 0) {
    yscale <- round_any(max(Dataframe$upper), fscale, f = ceiling)
  } else {
    yscale <- round_any(max(Dataframe$mean), fscale, f = ceiling)
  }
  xannot <- .5
  
    p3 <- ggplot() +
    #ggscatter(Dataframe.hab, x = Dataframe.hab$Nspecies, y = Dataframe.hab$mean,  add = "reg.line",conf.int = TRUE) +
    geom_line(aes(x = Dataframe.hab$Nspecies, y = Dataframe.hab$mean, linetype ="solid"), Dataframe.hab, size=.5) +
    geom_ribbon(aes(x = Dataframe.hab$Nspecies, ymin = Dataframe.hab$lower, ymax = Dataframe.hab$upper), Dataframe.hab, alpha = .2) +
    #geom_point(Dataframe.hab, aes(x = Dataframe.hab$Nspecies, y = ydataframe), size = .5) +
    scale_x_continuous(expand=c(0,0), limits = c(0, 8), breaks = seq(0, 8, 1)) +
    scale_y_continuous(expand=c(0,0), limits = c(0, yscale), breaks = seq(0, yscale, yscale/by)) +
    annotate(geom="text", x = xannot, y = yannot, label = plabel) +
      
    {if (graphlabelx == F){
      labs(x = "")
    } else if (graphlabelx == T) { 
      labs(x = "Number of Species Harvested")
    }} +
    {if (graphlabely == F){
      labs(y = "")
    } else if (graphlabely == T) { 
      labs(y = ylabs)
    }} +
      
    {if (title == T){
      
      if (Habitat == "upland"){
        ggtitle("Upland") 
      } else if (Habitat == "lowland"){
        ggtitle("Lowland")} 
    } else {
      ggtitle("   ")}
    } +
      
    theme_bw() +
    theme(text = element_text(size=13), 
        axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_blank(),
        legend.position = c(.22, .30),
        legend.box = "vertical",
        legend.background = element_blank(),
        legend.key = element_blank(),
        legend.text=element_text(size=9),
        legend.key.size = unit(.7, 'lines'),
        plot.title = element_text(hjust = 0.5)
    )
   
return(p3)
}

######################### Figure 4 ###############################
plotfig4 <- function(Dataframe, Variable, PFT, Habitat, graphlabelx = F, graphlabely = F, annotation="", title = F) {
  
  if (Habitat == "upland") {
    Dataframe.hab <- subset(Dataframe, habitat == "upland")
  } else if (Habitat == "lowland") {
    Dataframe.hab <- subset(Dataframe, habitat == "lowland")
  }
  
  if (Variable == "PFD"){
    ydataframe <- Dataframe.hab$PFD
    yannot <- round_any(max(Dataframe$PFD),1, f = ceiling) - round_any(max(Dataframe$PFD),1, f = ceiling)*0.05
    yscale <- round_any(max(Dataframe$PFD),1, f = ceiling)
    ylabs <- "PFT Diversity (Shannon Index)"
  } else if (Variable == "AGOC"){
    ydataframe <- Dataframe.hab$AGOC
    yannot <- round_any(max(Dataframe$AGOC),100, f = ceiling) - round_any(max(Dataframe$AGOC),100, f = ceiling)*0.05
    yscale <- round_any(max(Dataframe$AGOC),100, f = ceiling)
    ylabs <- "AGOC"
  } else if (Variable == "SupplyTimber"){
    ydataframe <- Dataframe.hab$SupplyTimber
    yannot <- round_any(max(Dataframe$SupplyTimber),1000, f = ceiling) - round_any(max(Dataframe$SupplyTimber),1000, f = ceiling)*0.05
    yscale <- round_any(max(Dataframe$SupplyTimber),1000, f = ceiling)
    ylabs <- "Timber Supply"
  } else if (Variable == "Dollar") {
    ydataframe <- Dataframe.hab$Dollar
    yannot <- round_any(max(Dataframe$Dollar),1000, f = ceiling) - round_any(max(Dataframe$Dollar),1000, f = ceiling)*0.05
    yscale <- round_any(max(Dataframe$Dollar),1000, f = ceiling)
    ylabs <- bquote(USD.ha^-1~CO[2]~eq.)
  }
  
  if (PFT == "LMA" & Habitat == "upland"){
    xdataframe <- Dataframe.hab$LMA
    xannot <- 0.05 + 0.05*0.05
    xscalemin <- 0.05
    xscalemax <- 0.35
    xscaleby <- (xscalemax - xscalemin)/3
    xlabs <- c(as.expression("Leaf Mass per Area (LMA)"," ", bquote(Kg.m^-2)))
    plabel <- "a)"
  } else if(PFT == "STD" & Habitat == "upland"){
    xdataframe <- Dataframe.hab$STD
    xannot <- 400 + 400*0.05
    xscalemin <- 400
    xscalemax <- 1000
    xscaleby <- (xscalemax - xscalemin)/3
    xlabs <- c(as.expression("Specific Timber Density (STD)"," ", bquote(Kg.m^-3)))
    plabel <- "c)"
  } else if(PFT == "SS" & Habitat == "upland"){
    xdataframe <- Dataframe.hab$SS
    xannot <- 1e-07 + 1e-07*0.05
    xscalemin <- 1e-07
    xscalemax <- 1e-04
    xscaleby <- exp(log(xscalemax / xscalemin)/3)
    xlabs <- c(as.expression("Seed size (SS)"," ", bquote(Kg)))
    plabel <- "e)"
  } else if(PFT == "LMA" & Habitat == "lowland"){
    xdataframe <- Dataframe.hab$LMA
    xannot <- 0.05 + 0.05*0.05
    xscalemin <- 0.05
    xscalemax <- 0.35
    xscaleby <- (xscalemax - xscalemin)/3
    xlabs <- c(as.expression("Leaf Mass per Area (LMA)"," ", bquote(Kg.m^-2)))
    plabel <- "b)"
  } else if(PFT == "STD" & Habitat == "lowland"){
    xdataframe <- Dataframe.hab$STD
    xannot <- 400 + 400*0.05
    xscalemin <- 400
    xscalemax <- 1000
    xscaleby <- (xscalemax - xscalemin)/3
    xlabs <- c(as.expression("Specific Timber Density (STD)"," ", bquote(Kg.m^-3)))
    plabel <- "d)"
  } else if(PFT == "SS" & Habitat == "lowland"){
    xdataframe <- Dataframe.hab$SS
    xannot <- 1e-07 + 1e-07*0.05
    xscalemin <- 1e-07
    xscalemax <- 1e-04
    xscaleby <- exp(log(xscalemax / xscalemin)/3)
    xlabs <- c(as.expression("Seed size (SS)"," ", bquote(Kg)))
    plabel <- "f)"
  } 
  
  xannot <- .5
  
  xydataframe <- data.frame(xdata = xdataframe, ydata = ydataframe) 
  
  p4 <- ggplot(xydataframe, aes(x = xydataframe$xdata, y = xydataframe$ydata)) +
    geom_point(size = .5) +
    scale_x_continuous(expand=c(0,0), limits = c(xscalemin,xscalemax), breaks=seq(xscalemin,xscalemax,xscaleby)) + #, trans = "log10"
    scale_y_continuous(expand=c(0,0), limits = c(0, yscale), breaks=seq(0,yscale,yscale/4)) +
    #annotate(geom="text", x = xannot, y = yannot, label = plabel) +
    
    {if (graphlabelx == F){
      labs(x = "")
    } else if (graphlabelx == T) { 
      labs(x = xlabs)
    }} +
    {if (graphlabely == F){
      labs(y = "")
    } else if (graphlabely == T) { 
      labs(y = ylabs)
    }} +
    
    {if (title == T){
      
      if (Habitat == "upland"){
        ggtitle("Upland") 
      } else if (Habitat == "lowland"){
        ggtitle("Lowland")} 
    } else {
      ggtitle("   ")}
    } +
    
    theme_bw() +
    theme(text = element_text(size=13), 
          axis.line = element_line(colour = "black"),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          panel.background = element_blank(),
          panel.border = element_blank(),
          legend.position = c(.22, .30),
          legend.box = "vertical",
          legend.background = element_blank(),
          legend.key = element_blank(),
          legend.text=element_text(size=9),
          legend.key.size = unit(.7, 'lines'),
          plot.title = element_text(hjust = 0.5)
    )
  
  return(p4)
}
